/****************************************************************************
** Meta object code from reading C++ file 'SatellitesConfigDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/plugins/render/satellites/SatellitesConfigDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SatellitesConfigDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble22SatellitesConfigDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::SatellitesConfigDialog::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble22SatellitesConfigDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::SatellitesConfigDialog",
        "dataSourcesReloadRequested",
        "",
        "userDataSourceAdded",
        "source",
        "userDataSourceRemoved",
        "userDataSourcesChanged",
        "activatePluginClicked",
        "setDialogActive",
        "active",
        "reloadDataSources",
        "addDataSource",
        "openDataSource",
        "removeSelectedDataSource",
        "updateButtonState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataSourcesReloadRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userDataSourceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'userDataSourceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'userDataSourcesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activatePluginClicked'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDialogActive'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'reloadDataSources'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'addDataSource'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'openDataSource'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'removeSelectedDataSource'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateButtonState'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SatellitesConfigDialog, qt_meta_tag_ZN6Marble22SatellitesConfigDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::SatellitesConfigDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble22SatellitesConfigDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble22SatellitesConfigDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble22SatellitesConfigDialogE_t>.metaTypes,
    nullptr
} };

void Marble::SatellitesConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SatellitesConfigDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataSourcesReloadRequested(); break;
        case 1: _t->userDataSourceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->userDataSourceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->userDataSourcesChanged(); break;
        case 4: _t->activatePluginClicked(); break;
        case 5: _t->setDialogActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->reloadDataSources(); break;
        case 7: _t->addDataSource(); break;
        case 8: _t->openDataSource(); break;
        case 9: _t->removeSelectedDataSource(); break;
        case 10: _t->updateButtonState(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SatellitesConfigDialog::*)()>(_a, &SatellitesConfigDialog::dataSourcesReloadRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SatellitesConfigDialog::*)(const QString & )>(_a, &SatellitesConfigDialog::userDataSourceAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SatellitesConfigDialog::*)(const QString & )>(_a, &SatellitesConfigDialog::userDataSourceRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SatellitesConfigDialog::*)()>(_a, &SatellitesConfigDialog::userDataSourcesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SatellitesConfigDialog::*)()>(_a, &SatellitesConfigDialog::activatePluginClicked, 4))
            return;
    }
}

const QMetaObject *Marble::SatellitesConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::SatellitesConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble22SatellitesConfigDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Marble::SatellitesConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Marble::SatellitesConfigDialog::dataSourcesReloadRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::SatellitesConfigDialog::userDataSourceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::SatellitesConfigDialog::userDataSourceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::SatellitesConfigDialog::userDataSourcesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::SatellitesConfigDialog::activatePluginClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
