/********************************************************************************
** Form generated from reading UI file 'EditPolylineDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITPOLYLINEDIALOG_H
#define UI_EDITPOLYLINEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "FormattedTextWidget.h"

QT_BEGIN_NAMESPACE

class Ui_UiEditPolylineDialog
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *m_name;
    QTabWidget *tabWidget;
    QWidget *m_descriptionTab;
    QVBoxLayout *verticalLayout_2;
    Marble::FormattedTextWidget *m_formattedTextWidget;
    QWidget *m_styleTab;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QPushButton *m_linesColorButton;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_4;
    QDoubleSpinBox *m_linesWidth;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab;
    QVBoxLayout *verticalLayout_3;
    QTreeView *m_nodeView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UiEditPolylineDialog)
    {
        if (UiEditPolylineDialog->objectName().isEmpty())
            UiEditPolylineDialog->setObjectName("UiEditPolylineDialog");
        UiEditPolylineDialog->resize(357, 390);
        UiEditPolylineDialog->setSizeGripEnabled(false);
        verticalLayout_4 = new QVBoxLayout(UiEditPolylineDialog);
        verticalLayout_4->setObjectName("verticalLayout_4");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(UiEditPolylineDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        m_name = new QLineEdit(UiEditPolylineDialog);
        m_name->setObjectName("m_name");

        horizontalLayout->addWidget(m_name);


        verticalLayout_4->addLayout(horizontalLayout);

        tabWidget = new QTabWidget(UiEditPolylineDialog);
        tabWidget->setObjectName("tabWidget");
        m_descriptionTab = new QWidget();
        m_descriptionTab->setObjectName("m_descriptionTab");
        verticalLayout_2 = new QVBoxLayout(m_descriptionTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_formattedTextWidget = new Marble::FormattedTextWidget(m_descriptionTab);
        m_formattedTextWidget->setObjectName("m_formattedTextWidget");

        verticalLayout_2->addWidget(m_formattedTextWidget);

        tabWidget->addTab(m_descriptionTab, QString());
        m_styleTab = new QWidget();
        m_styleTab->setObjectName("m_styleTab");
        verticalLayout = new QVBoxLayout(m_styleTab);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(m_styleTab);
        groupBox->setObjectName("groupBox");
        horizontalLayout_2 = new QHBoxLayout(groupBox);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        m_linesColorButton = new QPushButton(groupBox);
        m_linesColorButton->setObjectName("m_linesColorButton");
        m_linesColorButton->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_linesColorButton->sizePolicy().hasHeightForWidth());
        m_linesColorButton->setSizePolicy(sizePolicy);
        m_linesColorButton->setMaximumSize(QSize(24, 24));
        m_linesColorButton->setIconSize(QSize(12, 12));

        horizontalLayout_2->addWidget(m_linesColorButton);

        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        horizontalLayout_2->addWidget(label_4);

        m_linesWidth = new QDoubleSpinBox(groupBox);
        m_linesWidth->setObjectName("m_linesWidth");
        m_linesWidth->setDecimals(1);
        m_linesWidth->setMinimum(0.100000000000000);
        m_linesWidth->setMaximum(10.000000000000000);
        m_linesWidth->setSingleStep(0.100000000000000);

        horizontalLayout_2->addWidget(m_linesWidth);

        horizontalSpacer_3 = new QSpacerItem(71, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout->addWidget(groupBox);

        verticalSpacer_2 = new QSpacerItem(248, 190, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        tabWidget->addTab(m_styleTab, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_3 = new QVBoxLayout(tab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_nodeView = new QTreeView(tab);
        m_nodeView->setObjectName("m_nodeView");
        m_nodeView->setRootIsDecorated(false);
        m_nodeView->header()->setStretchLastSection(true);

        verticalLayout_3->addWidget(m_nodeView);

        tabWidget->addTab(tab, QString());

        verticalLayout_4->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(UiEditPolylineDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_4->addWidget(buttonBox);


        retranslateUi(UiEditPolylineDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UiEditPolylineDialog, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(UiEditPolylineDialog);
    } // setupUi

    void retranslateUi(QDialog *UiEditPolylineDialog)
    {
        UiEditPolylineDialog->setWindowTitle(QCoreApplication::translate("UiEditPolylineDialog", "Add path", nullptr));
        label->setText(QCoreApplication::translate("UiEditPolylineDialog", "Name", nullptr));
        m_name->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(m_descriptionTab), QCoreApplication::translate("UiEditPolylineDialog", "Description", nullptr));
        groupBox->setTitle(QCoreApplication::translate("UiEditPolylineDialog", "Lines", nullptr));
        label_3->setText(QCoreApplication::translate("UiEditPolylineDialog", "Color:", nullptr));
        m_linesColorButton->setText(QString());
        label_4->setText(QCoreApplication::translate("UiEditPolylineDialog", "Width:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(m_styleTab), QCoreApplication::translate("UiEditPolylineDialog", "Style, Color", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("UiEditPolylineDialog", "Nodes", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UiEditPolylineDialog: public Ui_UiEditPolylineDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITPOLYLINEDIALOG_H
