/****************************************************************************
** Meta object code from reading C++ file 'GeoDataTreeModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/GeoDataTreeModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GeoDataTreeModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble16GeoDataTreeModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::GeoDataTreeModel::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble16GeoDataTreeModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::GeoDataTreeModel",
        "removed",
        "",
        "GeoDataObject*",
        "object",
        "added",
        "setRootDocument",
        "GeoDataDocument*",
        "document",
        "addFeature",
        "GeoDataContainer*",
        "parent",
        "GeoDataFeature*",
        "feature",
        "row",
        "removeFeatureRow",
        "Marble::GeoDataContainer*",
        "index",
        "removeFeature",
        "updateFeature",
        "addDocument",
        "removeDocument",
        "addTourPrimitive",
        "QModelIndex",
        "GeoDataTourPrimitive*",
        "primitive",
        "removeTourPrimitive",
        "swapTourPrimitives",
        "indexA",
        "indexB"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'removed'
        QtMocHelpers::SignalData<void(GeoDataObject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'added'
        QtMocHelpers::SignalData<void(GeoDataObject *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setRootDocument'
        QtMocHelpers::SlotData<void(GeoDataDocument *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'addFeature'
        QtMocHelpers::SlotData<int(GeoDataContainer *, GeoDataFeature *, int)>(9, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'addFeature'
        QtMocHelpers::SlotData<int(GeoDataContainer *, GeoDataFeature *)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'removeFeatureRow'
        QtMocHelpers::SlotData<bool(Marble::GeoDataContainer *, int)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 16, 11 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'removeFeature'
        QtMocHelpers::SlotData<int(GeoDataFeature *)>(18, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'updateFeature'
        QtMocHelpers::SlotData<void(GeoDataFeature *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'addDocument'
        QtMocHelpers::SlotData<int(GeoDataDocument *)>(20, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'removeDocument'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'removeDocument'
        QtMocHelpers::SlotData<void(GeoDataDocument *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'addTourPrimitive'
        QtMocHelpers::SlotData<int(const QModelIndex &, GeoDataTourPrimitive *, int)>(22, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 23, 11 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'addTourPrimitive'
        QtMocHelpers::SlotData<int(const QModelIndex &, GeoDataTourPrimitive *)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 23, 11 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'removeTourPrimitive'
        QtMocHelpers::SlotData<bool(const QModelIndex &, int)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 23, 11 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'swapTourPrimitives'
        QtMocHelpers::SlotData<bool(const QModelIndex &, int, int)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 23, 11 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GeoDataTreeModel, qt_meta_tag_ZN6Marble16GeoDataTreeModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::GeoDataTreeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16GeoDataTreeModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16GeoDataTreeModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble16GeoDataTreeModelE_t>.metaTypes,
    nullptr
} };

void Marble::GeoDataTreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GeoDataTreeModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removed((*reinterpret_cast<std::add_pointer_t<GeoDataObject*>>(_a[1]))); break;
        case 1: _t->added((*reinterpret_cast<std::add_pointer_t<GeoDataObject*>>(_a[1]))); break;
        case 2: _t->setRootDocument((*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[1]))); break;
        case 3: { int _r = _t->addFeature((*reinterpret_cast<std::add_pointer_t<GeoDataContainer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->addFeature((*reinterpret_cast<std::add_pointer_t<GeoDataContainer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->removeFeatureRow((*reinterpret_cast<std::add_pointer_t<Marble::GeoDataContainer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->removeFeature((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->updateFeature((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1]))); break;
        case 8: { int _r = _t->addDocument((*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->removeDocument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->removeDocument((*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[1]))); break;
        case 11: { int _r = _t->addTourPrimitive((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataTourPrimitive*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->addTourPrimitive((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataTourPrimitive*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->removeTourPrimitive((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->swapTourPrimitives((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GeoDataTreeModel::*)(GeoDataObject * )>(_a, &GeoDataTreeModel::removed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeoDataTreeModel::*)(GeoDataObject * )>(_a, &GeoDataTreeModel::added, 1))
            return;
    }
}

const QMetaObject *Marble::GeoDataTreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::GeoDataTreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16GeoDataTreeModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Marble::GeoDataTreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Marble::GeoDataTreeModel::removed(GeoDataObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::GeoDataTreeModel::added(GeoDataObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
