/****************************************************************************
** Meta object code from reading C++ file 'TextureLayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/layers/TextureLayer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TextureLayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble12TextureLayerE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::TextureLayer::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble12TextureLayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::TextureLayer",
        "tileLevelChanged",
        "",
        "repaintNeeded",
        "setShowRelief",
        "show",
        "setShowSunShading",
        "setShowCityLights",
        "setShowTileId",
        "setProjection",
        "Projection",
        "projection",
        "setNeedsUpdate",
        "setMapTheme",
        "QList<const GeoSceneTextureTileDataset*>",
        "textures",
        "const GeoSceneGroup*",
        "textureLayerSettings",
        "seaFile",
        "landFile",
        "setVolatileCacheLimit",
        "kilobytes",
        "reset",
        "reload",
        "downloadStackedTile",
        "TileId",
        "stackedTileId",
        "requestDelayedRepaint",
        "updateTextureLayers",
        "updateTile",
        "tileId",
        "QImage",
        "tileImage",
        "addGroundOverlays",
        "QModelIndex",
        "parent",
        "first",
        "last",
        "removeGroundOverlays",
        "resetGroundOverlaysCache"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tileLevelChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'repaintNeeded'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setShowRelief'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setShowSunShading'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setShowCityLights'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setShowTileId'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setProjection'
        QtMocHelpers::SlotData<void(Projection)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'setNeedsUpdate'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMapTheme'
        QtMocHelpers::SlotData<void(const QList<const GeoSceneTextureTileDataset*> &, const GeoSceneGroup *, const QString &, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'setVolatileCacheLimit'
        QtMocHelpers::SlotData<void(quint64)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 21 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'downloadStackedTile'
        QtMocHelpers::SlotData<void(const TileId &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'requestDelayedRepaint'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTextureLayers'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTile'
        QtMocHelpers::SlotData<void(const TileId &, const QImage &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Slot 'addGroundOverlays'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { QMetaType::Int, 36 }, { QMetaType::Int, 37 },
        }}),
        // Slot 'removeGroundOverlays'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { QMetaType::Int, 36 }, { QMetaType::Int, 37 },
        }}),
        // Slot 'resetGroundOverlaysCache'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TextureLayer, qt_meta_tag_ZN6Marble12TextureLayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::TextureLayer::staticMetaObject = { {
    QMetaObject::SuperData::link<TileLayer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12TextureLayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12TextureLayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble12TextureLayerE_t>.metaTypes,
    nullptr
} };

void Marble::TextureLayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextureLayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tileLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->repaintNeeded(); break;
        case 2: _t->setShowRelief((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setShowSunShading((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setShowCityLights((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setShowTileId((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setProjection((*reinterpret_cast<std::add_pointer_t<Projection>>(_a[1]))); break;
        case 7: _t->setNeedsUpdate(); break;
        case 8: _t->setMapTheme((*reinterpret_cast<std::add_pointer_t<QList<const GeoSceneTextureTileDataset*>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const GeoSceneGroup*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 9: _t->setVolatileCacheLimit((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 10: _t->reset(); break;
        case 11: _t->reload(); break;
        case 12: _t->downloadStackedTile((*reinterpret_cast<std::add_pointer_t<TileId>>(_a[1]))); break;
        case 13: _t->d->requestDelayedRepaint(); break;
        case 14: _t->d->updateTextureLayers(); break;
        case 15: _t->d->updateTile((*reinterpret_cast<std::add_pointer_t<TileId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QImage>>(_a[2]))); break;
        case 16: _t->d->addGroundOverlays((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 17: _t->d->removeGroundOverlays((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 18: _t->d->resetGroundOverlaysCache(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextureLayer::*)(int )>(_a, &TextureLayer::tileLevelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextureLayer::*)()>(_a, &TextureLayer::repaintNeeded, 1))
            return;
    }
}

const QMetaObject *Marble::TextureLayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::TextureLayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12TextureLayerE_t>.strings))
        return static_cast<void*>(this);
    return TileLayer::qt_metacast(_clname);
}

int Marble::TextureLayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TileLayer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Marble::TextureLayer::tileLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::TextureLayer::repaintNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
