/********************************************************************************
** Form generated from reading UI file 'RoutingPlugin.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ROUTINGPLUGIN_H
#define UI_ROUTINGPLUGIN_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_RoutingPlugin
{
public:
    QGridLayout *gridLayout;
    QProgressBar *progressBar;
    QLabel *instructionIconLabel;
    QLabel *instructionLabel;
    QLabel *followingInstructionIconLabel;
    QToolButton *routingButton;
    QToolButton *gpsButton;
    QToolButton *zoomOutButton;
    QToolButton *zoomInButton;
    QLabel *destinationDistanceLabel;
    QSpacerItem *spacer;

    void setupUi(QWidget *RoutingPlugin)
    {
        if (RoutingPlugin->objectName().isEmpty())
            RoutingPlugin->setObjectName("RoutingPlugin");
        RoutingPlugin->setEnabled(true);
        RoutingPlugin->resize(972, 91);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(RoutingPlugin->sizePolicy().hasHeightForWidth());
        RoutingPlugin->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(RoutingPlugin);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetFixedSize);
        progressBar = new QProgressBar(RoutingPlugin);
        progressBar->setObjectName("progressBar");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(progressBar->sizePolicy().hasHeightForWidth());
        progressBar->setSizePolicy(sizePolicy1);
        progressBar->setMinimumSize(QSize(0, 0));
        progressBar->setMaximum(1000);
        progressBar->setValue(100);
        progressBar->setOrientation(Qt::Vertical);

        gridLayout->addWidget(progressBar, 0, 0, 1, 1);

        instructionIconLabel = new QLabel(RoutingPlugin);
        instructionIconLabel->setObjectName("instructionIconLabel");
        instructionIconLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(instructionIconLabel->sizePolicy().hasHeightForWidth());
        instructionIconLabel->setSizePolicy(sizePolicy);
        instructionIconLabel->setMinimumSize(QSize(64, 64));

        gridLayout->addWidget(instructionIconLabel, 0, 1, 1, 1);

        instructionLabel = new QLabel(RoutingPlugin);
        instructionLabel->setObjectName("instructionLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(instructionLabel->sizePolicy().hasHeightForWidth());
        instructionLabel->setSizePolicy(sizePolicy2);
        instructionLabel->setMinimumSize(QSize(410, 0));
        instructionLabel->setWordWrap(true);

        gridLayout->addWidget(instructionLabel, 0, 3, 1, 1);

        followingInstructionIconLabel = new QLabel(RoutingPlugin);
        followingInstructionIconLabel->setObjectName("followingInstructionIconLabel");
        followingInstructionIconLabel->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(followingInstructionIconLabel->sizePolicy().hasHeightForWidth());
        followingInstructionIconLabel->setSizePolicy(sizePolicy3);
        followingInstructionIconLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(followingInstructionIconLabel, 0, 4, 1, 1);

        routingButton = new QToolButton(RoutingPlugin);
        routingButton->setObjectName("routingButton");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(64);
        sizePolicy4.setVerticalStretch(64);
        sizePolicy4.setHeightForWidth(routingButton->sizePolicy().hasHeightForWidth());
        routingButton->setSizePolicy(sizePolicy4);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/route-guidance.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        routingButton->setIcon(icon);
        routingButton->setIconSize(QSize(64, 64));
        routingButton->setCheckable(true);

        gridLayout->addWidget(routingButton, 0, 6, 1, 1);

        gpsButton = new QToolButton(RoutingPlugin);
        gpsButton->setObjectName("gpsButton");
        sizePolicy4.setHeightForWidth(gpsButton->sizePolicy().hasHeightForWidth());
        gpsButton->setSizePolicy(sizePolicy4);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/gps.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        gpsButton->setIcon(icon1);
        gpsButton->setIconSize(QSize(64, 64));
        gpsButton->setCheckable(true);

        gridLayout->addWidget(gpsButton, 0, 7, 1, 1);

        zoomOutButton = new QToolButton(RoutingPlugin);
        zoomOutButton->setObjectName("zoomOutButton");
        sizePolicy4.setHeightForWidth(zoomOutButton->sizePolicy().hasHeightForWidth());
        zoomOutButton->setSizePolicy(sizePolicy4);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/zoom-out-large.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        zoomOutButton->setIcon(icon2);
        zoomOutButton->setIconSize(QSize(64, 64));
        zoomOutButton->setCheckable(false);
        zoomOutButton->setAutoRepeat(false);

        gridLayout->addWidget(zoomOutButton, 0, 8, 1, 1);

        zoomInButton = new QToolButton(RoutingPlugin);
        zoomInButton->setObjectName("zoomInButton");
        sizePolicy4.setHeightForWidth(zoomInButton->sizePolicy().hasHeightForWidth());
        zoomInButton->setSizePolicy(sizePolicy4);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/icons/zoom-in-large.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        zoomInButton->setIcon(icon3);
        zoomInButton->setIconSize(QSize(64, 64));
        zoomInButton->setCheckable(false);
        zoomInButton->setAutoRepeat(false);

        gridLayout->addWidget(zoomInButton, 0, 9, 1, 1);

        destinationDistanceLabel = new QLabel(RoutingPlugin);
        destinationDistanceLabel->setObjectName("destinationDistanceLabel");
        sizePolicy3.setHeightForWidth(destinationDistanceLabel->sizePolicy().hasHeightForWidth());
        destinationDistanceLabel->setSizePolicy(sizePolicy3);
        destinationDistanceLabel->setMaximumSize(QSize(128, 16777215));
        destinationDistanceLabel->setCursor(QCursor(Qt::CursorShape::ArrowCursor));
        destinationDistanceLabel->setTextFormat(Qt::AutoText);
        destinationDistanceLabel->setAlignment(Qt::AlignCenter);
        destinationDistanceLabel->setWordWrap(true);

        gridLayout->addWidget(destinationDistanceLabel, 0, 5, 1, 1);

        spacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer, 0, 2, 1, 1);


        retranslateUi(RoutingPlugin);

        QMetaObject::connectSlotsByName(RoutingPlugin);
    } // setupUi

    void retranslateUi(QWidget *RoutingPlugin)
    {
        progressBar->setFormat(QString());
        instructionIconLabel->setText(QString());
        instructionLabel->setText(QString());
        followingInstructionIconLabel->setText(QString());
#if QT_CONFIG(tooltip)
        routingButton->setToolTip(QCoreApplication::translate("RoutingPlugin", "Guidance Mode", nullptr));
#endif // QT_CONFIG(tooltip)
        routingButton->setText(QCoreApplication::translate("RoutingPlugin", "R", nullptr));
#if QT_CONFIG(tooltip)
        gpsButton->setToolTip(QCoreApplication::translate("RoutingPlugin", "Toggle GPS", nullptr));
#endif // QT_CONFIG(tooltip)
        gpsButton->setText(QString());
#if QT_CONFIG(tooltip)
        zoomOutButton->setToolTip(QCoreApplication::translate("RoutingPlugin", "Zoom Out", nullptr));
#endif // QT_CONFIG(tooltip)
        zoomOutButton->setText(QCoreApplication::translate("RoutingPlugin", "-", nullptr));
#if QT_CONFIG(tooltip)
        zoomInButton->setToolTip(QCoreApplication::translate("RoutingPlugin", "Zoom In", nullptr));
#endif // QT_CONFIG(tooltip)
        zoomInButton->setText(QCoreApplication::translate("RoutingPlugin", "+", nullptr));
#if QT_CONFIG(tooltip)
        destinationDistanceLabel->setToolTip(QCoreApplication::translate("RoutingPlugin", "total time remaining", nullptr));
#endif // QT_CONFIG(tooltip)
        destinationDistanceLabel->setText(QString());
        (void)RoutingPlugin;
    } // retranslateUi

};

namespace Ui {
    class RoutingPlugin: public Ui_RoutingPlugin {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ROUTINGPLUGIN_H
