/********************************************************************************
** Form generated from reading UI file 'MarbleCloudSyncSettingsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MARBLECLOUDSYNCSETTINGSWIDGET_H
#define UI_MARBLECLOUDSYNCSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MarbleCloudSyncSettingsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_enableSync;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_syncRoutes;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *kcfg_syncBookmarks;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *button_syncNow;
    QLabel *labelLastSync;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *labelServer;
    QLineEdit *kcfg_owncloudServer;
    QLabel *labelUsername;
    QLineEdit *kcfg_owncloudUsername;
    QLabel *labelPassword;
    QLineEdit *kcfg_owncloudPassword;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *testLoginButton;
    QLabel *cloudSyncStatus;

    void setupUi(QWidget *MarbleCloudSyncSettingsWidget)
    {
        if (MarbleCloudSyncSettingsWidget->objectName().isEmpty())
            MarbleCloudSyncSettingsWidget->setObjectName("MarbleCloudSyncSettingsWidget");
        MarbleCloudSyncSettingsWidget->resize(392, 256);
        verticalLayout = new QVBoxLayout(MarbleCloudSyncSettingsWidget);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_enableSync = new QCheckBox(MarbleCloudSyncSettingsWidget);
        kcfg_enableSync->setObjectName("kcfg_enableSync");

        verticalLayout->addWidget(kcfg_enableSync);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setSizeConstraint(QLayout::SetDefaultConstraint);
        horizontalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        kcfg_syncRoutes = new QCheckBox(MarbleCloudSyncSettingsWidget);
        kcfg_syncRoutes->setObjectName("kcfg_syncRoutes");
        kcfg_syncRoutes->setEnabled(false);
        kcfg_syncRoutes->setChecked(true);

        horizontalLayout_2->addWidget(kcfg_syncRoutes);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        kcfg_syncBookmarks = new QCheckBox(MarbleCloudSyncSettingsWidget);
        kcfg_syncBookmarks->setObjectName("kcfg_syncBookmarks");
        kcfg_syncBookmarks->setEnabled(false);
        kcfg_syncBookmarks->setChecked(true);

        horizontalLayout->addWidget(kcfg_syncBookmarks);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        button_syncNow = new QPushButton(MarbleCloudSyncSettingsWidget);
        button_syncNow->setObjectName("button_syncNow");
        button_syncNow->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(button_syncNow->sizePolicy().hasHeightForWidth());
        button_syncNow->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(button_syncNow);


        verticalLayout->addLayout(horizontalLayout);

        labelLastSync = new QLabel(MarbleCloudSyncSettingsWidget);
        labelLastSync->setObjectName("labelLastSync");
        labelLastSync->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout->addWidget(labelLastSync);

        groupBox = new QGroupBox(MarbleCloudSyncSettingsWidget);
        groupBox->setObjectName("groupBox");
        groupBox->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        labelServer = new QLabel(groupBox);
        labelServer->setObjectName("labelServer");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelServer);

        kcfg_owncloudServer = new QLineEdit(groupBox);
        kcfg_owncloudServer->setObjectName("kcfg_owncloudServer");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_owncloudServer);

        labelUsername = new QLabel(groupBox);
        labelUsername->setObjectName("labelUsername");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelUsername);

        kcfg_owncloudUsername = new QLineEdit(groupBox);
        kcfg_owncloudUsername->setObjectName("kcfg_owncloudUsername");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_owncloudUsername);

        labelPassword = new QLabel(groupBox);
        labelPassword->setObjectName("labelPassword");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelPassword);

        kcfg_owncloudPassword = new QLineEdit(groupBox);
        kcfg_owncloudPassword->setObjectName("kcfg_owncloudPassword");
        kcfg_owncloudPassword->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_owncloudPassword);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        testLoginButton = new QPushButton(groupBox);
        testLoginButton->setObjectName("testLoginButton");

        horizontalLayout_3->addWidget(testLoginButton);

        cloudSyncStatus = new QLabel(groupBox);
        cloudSyncStatus->setObjectName("cloudSyncStatus");

        horizontalLayout_3->addWidget(cloudSyncStatus);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);


        verticalLayout->addWidget(groupBox);


        retranslateUi(MarbleCloudSyncSettingsWidget);
        QObject::connect(kcfg_enableSync, &QCheckBox::toggled, groupBox, &QGroupBox::setEnabled);
        QObject::connect(kcfg_enableSync, &QCheckBox::toggled, kcfg_syncRoutes, &QCheckBox::setEnabled);
        QObject::connect(kcfg_enableSync, &QCheckBox::toggled, kcfg_syncBookmarks, &QCheckBox::setEnabled);
        QObject::connect(kcfg_syncBookmarks, &QCheckBox::toggled, button_syncNow, &QPushButton::setEnabled);
        QObject::connect(kcfg_enableSync, &QCheckBox::toggled, kcfg_syncRoutes, &QCheckBox::setChecked);
        QObject::connect(kcfg_enableSync, &QCheckBox::toggled, kcfg_syncBookmarks, &QCheckBox::setChecked);

        QMetaObject::connectSlotsByName(MarbleCloudSyncSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *MarbleCloudSyncSettingsWidget)
    {
        kcfg_enableSync->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Enable synchronization", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_syncRoutes->setWhatsThis(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Allows you to store routes in owncloud. Each route must be uploaded/downloaded manually.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_syncRoutes->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Enable route synchronization", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_syncBookmarks->setWhatsThis(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Automatically sync all bookmarks to the server.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_syncBookmarks->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Enable bookmark synchronization", nullptr));
        button_syncNow->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Sync now", nullptr));
        labelLastSync->setText(QString());
        groupBox->setTitle(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Credentials", nullptr));
        labelServer->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Server:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_owncloudServer->setWhatsThis(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Remote server URL, e.g. myserver.com/owncloud", nullptr));
#endif // QT_CONFIG(whatsthis)
        labelUsername->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Username:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_owncloudUsername->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        labelPassword->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Password:", nullptr));
        testLoginButton->setText(QCoreApplication::translate("MarbleCloudSyncSettingsWidget", "Test Login", nullptr));
        cloudSyncStatus->setText(QString());
        (void)MarbleCloudSyncSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class MarbleCloudSyncSettingsWidget: public Ui_MarbleCloudSyncSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MARBLECLOUDSYNCSETTINGSWIDGET_H
