/****************************************************************************
** Meta object code from reading C++ file 'RoutingWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/routing/RoutingWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RoutingWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble13RoutingWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::RoutingWidget::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble13RoutingWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::RoutingWidget",
        "openRoute",
        "",
        "saveRoute",
        "uploadToCloud",
        "openCloudRoutesDialog",
        "addInputWidget",
        "retrieveRoute",
        "activateItem",
        "QModelIndex",
        "index",
        "handleSearchResult",
        "RoutingInputWidget*",
        "widget",
        "centerOnInputWidget",
        "activatePlacemark",
        "insertInputWidget",
        "removeInputWidget",
        "updateRouteState",
        "RoutingManager::State",
        "state",
        "requestMapPosition",
        "enabled",
        "retrieveSelectedPoint",
        "GeoDataCoordinates",
        "coordinates",
        "adjustSearchButton",
        "pointSelectionCanceled",
        "configureProfile",
        "updateProgress",
        "updateAlternativeRoutes",
        "selectFirstProfile",
        "showDirections",
        "setRoutingProfile",
        "updateActiveRoutingProfile",
        "updateCloudSyncButtons",
        "openCloudRoute",
        "identifier",
        "updateUploadProgress",
        "sent",
        "total",
        "centerOn",
        "seekTourToStart",
        "initializeTour",
        "clearTour",
        "toggleRoutePlay",
        "handlePlanetChange"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'openRoute'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveRoute'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'uploadToCloud'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openCloudRoutesDialog'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addInputWidget'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'retrieveRoute'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activateItem'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'handleSearchResult'
        QtMocHelpers::SlotData<void(RoutingInputWidget *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'centerOnInputWidget'
        QtMocHelpers::SlotData<void(RoutingInputWidget *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'activatePlacemark'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'insertInputWidget'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'removeInputWidget'
        QtMocHelpers::SlotData<void(RoutingInputWidget *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'removeInputWidget'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'updateRouteState'
        QtMocHelpers::SlotData<void(RoutingManager::State)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'requestMapPosition'
        QtMocHelpers::SlotData<void(RoutingInputWidget *, bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'retrieveSelectedPoint'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'adjustSearchButton'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pointSelectionCanceled'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureProfile'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateProgress'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAlternativeRoutes'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectFirstProfile'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showDirections'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setRoutingProfile'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'updateActiveRoutingProfile'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCloudSyncButtons'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openCloudRoute'
        QtMocHelpers::SlotData<void(const QString &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'updateUploadProgress'
        QtMocHelpers::SlotData<void(qint64, qint64)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 39 }, { QMetaType::LongLong, 40 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'seekTourToStart'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'initializeTour'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearTour'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleRoutePlay'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handlePlanetChange'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RoutingWidget, qt_meta_tag_ZN6Marble13RoutingWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::RoutingWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13RoutingWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13RoutingWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble13RoutingWidgetE_t>.metaTypes,
    nullptr
} };

void Marble::RoutingWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RoutingWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openRoute(); break;
        case 1: _t->saveRoute(); break;
        case 2: _t->uploadToCloud(); break;
        case 3: _t->openCloudRoutesDialog(); break;
        case 4: _t->addInputWidget(); break;
        case 5: _t->retrieveRoute(); break;
        case 6: _t->activateItem((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 7: _t->handleSearchResult((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1]))); break;
        case 8: _t->centerOnInputWidget((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1]))); break;
        case 9: _t->activatePlacemark((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->insertInputWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->removeInputWidget((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1]))); break;
        case 12: _t->removeInputWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->updateRouteState((*reinterpret_cast<std::add_pointer_t<RoutingManager::State>>(_a[1]))); break;
        case 14: _t->requestMapPosition((*reinterpret_cast<std::add_pointer_t<RoutingInputWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->retrieveSelectedPoint((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 16: _t->adjustSearchButton(); break;
        case 17: _t->pointSelectionCanceled(); break;
        case 18: _t->configureProfile(); break;
        case 19: _t->updateProgress(); break;
        case 20: _t->updateAlternativeRoutes(); break;
        case 21: _t->selectFirstProfile(); break;
        case 22: _t->showDirections(); break;
        case 23: _t->setRoutingProfile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->updateActiveRoutingProfile(); break;
        case 25: _t->updateCloudSyncButtons(); break;
        case 26: _t->openCloudRoute((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->updateUploadProgress((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 28: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 29: _t->seekTourToStart(); break;
        case 30: _t->initializeTour(); break;
        case 31: _t->clearTour(); break;
        case 32: _t->toggleRoutePlay(); break;
        case 33: _t->handlePlanetChange(); break;
        default: ;
        }
    }
}

const QMetaObject *Marble::RoutingWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::RoutingWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13RoutingWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Marble::RoutingWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 34;
    }
    return _id;
}
QT_WARNING_POP
