/****************************************************************************
** Meta object code from reading C++ file 'DownloadQueueSet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/DownloadQueueSet.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DownloadQueueSet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble16DownloadQueueSetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::DownloadQueueSet::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble16DownloadQueueSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::DownloadQueueSet",
        "jobAdded",
        "",
        "jobRemoved",
        "jobRetry",
        "jobFinished",
        "data",
        "destinationFileName",
        "id",
        "jobRedirected",
        "QUrl",
        "newSourceUrl",
        "DownloadUsage",
        "progressChanged",
        "active",
        "queued",
        "finishJob",
        "HttpJob*",
        "job",
        "redirectJob",
        "retryOrBlacklistJob",
        "errorCode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'jobAdded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jobRemoved'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jobRetry'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jobFinished'
        QtMocHelpers::SignalData<void(const QByteArray &, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 6 }, { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'jobRedirected'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &, const QString &, DownloadUsage)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { 0x80000000 | 12, 2 },
        }}),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void(int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
        // Slot 'finishJob'
        QtMocHelpers::SlotData<void(HttpJob *, const QByteArray &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QByteArray, 6 },
        }}),
        // Slot 'redirectJob'
        QtMocHelpers::SlotData<void(HttpJob *, const QUrl &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'retryOrBlacklistJob'
        QtMocHelpers::SlotData<void(HttpJob *, const int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Int, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DownloadQueueSet, qt_meta_tag_ZN6Marble16DownloadQueueSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::DownloadQueueSet::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16DownloadQueueSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16DownloadQueueSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble16DownloadQueueSetE_t>.metaTypes,
    nullptr
} };

void Marble::DownloadQueueSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DownloadQueueSet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->jobAdded(); break;
        case 1: _t->jobRemoved(); break;
        case 2: _t->jobRetry(); break;
        case 3: _t->jobFinished((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->jobRedirected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<DownloadUsage>>(_a[4]))); break;
        case 5: _t->progressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->finishJob((*reinterpret_cast<std::add_pointer_t<HttpJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 7: _t->redirectJob((*reinterpret_cast<std::add_pointer_t<HttpJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 8: _t->retryOrBlacklistJob((*reinterpret_cast<std::add_pointer_t<HttpJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DownloadQueueSet::*)()>(_a, &DownloadQueueSet::jobAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DownloadQueueSet::*)()>(_a, &DownloadQueueSet::jobRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DownloadQueueSet::*)()>(_a, &DownloadQueueSet::jobRetry, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DownloadQueueSet::*)(const QByteArray & , const QString & , const QString & )>(_a, &DownloadQueueSet::jobFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DownloadQueueSet::*)(const QUrl & , const QString & , const QString & , DownloadUsage )>(_a, &DownloadQueueSet::jobRedirected, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DownloadQueueSet::*)(int , int )>(_a, &DownloadQueueSet::progressChanged, 5))
            return;
    }
}

const QMetaObject *Marble::DownloadQueueSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::DownloadQueueSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16DownloadQueueSetE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::DownloadQueueSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Marble::DownloadQueueSet::jobAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::DownloadQueueSet::jobRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::DownloadQueueSet::jobRetry()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::DownloadQueueSet::jobFinished(const QByteArray & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Marble::DownloadQueueSet::jobRedirected(const QUrl & _t1, const QString & _t2, const QString & _t3, DownloadUsage _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void Marble::DownloadQueueSet::progressChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
