/********************************************************************************
** Form generated from reading UI file 'MarbleNavigator.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MARBLENAVIGATOR_H
#define UI_MARBLENAVIGATOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSlider>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MarbleNavigator
{
public:
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout;
    QFrame *m_pSpacerFrame;
    QToolButton *moveUpButton;
    QToolButton *moveLeftButton;
    QToolButton *goHomeButton;
    QToolButton *moveRightButton;
    QToolButton *moveDownButton;
    QToolButton *zoomInButton;
    QSlider *zoomSlider;
    QToolButton *zoomOutButton;

    void setupUi(QWidget *MarbleNavigator)
    {
        if (MarbleNavigator->objectName().isEmpty())
            MarbleNavigator->setObjectName("MarbleNavigator");
        MarbleNavigator->resize(249, 473);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MarbleNavigator->sizePolicy().hasHeightForWidth());
        MarbleNavigator->setSizePolicy(sizePolicy);
        hboxLayout = new QHBoxLayout(MarbleNavigator);
#ifndef Q_OS_MACOS
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        gridLayout = new QGridLayout();
#ifndef Q_OS_MACOS
        gridLayout->setSpacing(6);
#endif
#ifndef Q_OS_MACOS
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        m_pSpacerFrame = new QFrame(MarbleNavigator);
        m_pSpacerFrame->setObjectName("m_pSpacerFrame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_pSpacerFrame->sizePolicy().hasHeightForWidth());
        m_pSpacerFrame->setSizePolicy(sizePolicy1);
        m_pSpacerFrame->setMinimumSize(QSize(16, 0));
        m_pSpacerFrame->setFrameShape(QFrame::NoFrame);
        m_pSpacerFrame->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(m_pSpacerFrame, 6, 1, 1, 1);

        moveUpButton = new QToolButton(MarbleNavigator);
        moveUpButton->setObjectName("moveUpButton");
        const QIcon icon = QIcon(QString::fromUtf8(":/icons/arrow-up.png"));
        moveUpButton->setIcon(icon);

        gridLayout->addWidget(moveUpButton, 0, 1, 1, 1);

        moveLeftButton = new QToolButton(MarbleNavigator);
        moveLeftButton->setObjectName("moveLeftButton");
        const QIcon icon1 = QIcon(QString::fromUtf8(":/icons/arrow-left.png"));
        moveLeftButton->setIcon(icon1);

        gridLayout->addWidget(moveLeftButton, 1, 0, 1, 1);

        goHomeButton = new QToolButton(MarbleNavigator);
        goHomeButton->setObjectName("goHomeButton");
        const QIcon icon2 = QIcon(QString::fromUtf8(":/icons/go-home.png"));
        goHomeButton->setIcon(icon2);

        gridLayout->addWidget(goHomeButton, 1, 1, 1, 1);

        moveRightButton = new QToolButton(MarbleNavigator);
        moveRightButton->setObjectName("moveRightButton");
        const QIcon icon3 = QIcon(QString::fromUtf8(":/icons/arrow-right.png"));
        moveRightButton->setIcon(icon3);

        gridLayout->addWidget(moveRightButton, 1, 2, 1, 1);

        moveDownButton = new QToolButton(MarbleNavigator);
        moveDownButton->setObjectName("moveDownButton");
        const QIcon icon4 = QIcon(QString::fromUtf8(":/icons/arrow-down.png"));
        moveDownButton->setIcon(icon4);

        gridLayout->addWidget(moveDownButton, 2, 1, 1, 1);

        zoomInButton = new QToolButton(MarbleNavigator);
        zoomInButton->setObjectName("zoomInButton");
        const QIcon icon5 = QIcon(QString::fromUtf8(":/icons/zoom-in.png"));
        zoomInButton->setIcon(icon5);

        gridLayout->addWidget(zoomInButton, 3, 1, 1, 1);

        zoomSlider = new QSlider(MarbleNavigator);
        zoomSlider->setObjectName("zoomSlider");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(zoomSlider->sizePolicy().hasHeightForWidth());
        zoomSlider->setSizePolicy(sizePolicy2);
        zoomSlider->setMinimum(1000);
        zoomSlider->setMaximum(2500);
        zoomSlider->setValue(1050);
        zoomSlider->setSliderPosition(1050);
        zoomSlider->setOrientation(Qt::Vertical);
        zoomSlider->setTickPosition(QSlider::TicksAbove);
        zoomSlider->setTickInterval(100);

        gridLayout->addWidget(zoomSlider, 4, 1, 1, 1);

        zoomOutButton = new QToolButton(MarbleNavigator);
        zoomOutButton->setObjectName("zoomOutButton");
        const QIcon icon6 = QIcon(QString::fromUtf8(":/icons/zoom-out.png"));
        zoomOutButton->setIcon(icon6);

        gridLayout->addWidget(zoomOutButton, 5, 1, 1, 1);


        hboxLayout->addLayout(gridLayout);


        retranslateUi(MarbleNavigator);

        QMetaObject::connectSlotsByName(MarbleNavigator);
    } // setupUi

    void retranslateUi(QWidget *MarbleNavigator)
    {
#if QT_CONFIG(tooltip)
        moveUpButton->setToolTip(QCoreApplication::translate("MarbleNavigator", "Up", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        moveUpButton->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Tilts the globe's axis towards the user.", nullptr));
#endif // QT_CONFIG(whatsthis)
        moveUpButton->setText(QCoreApplication::translate("MarbleNavigator", "\342\200\246", nullptr));
#if QT_CONFIG(tooltip)
        moveLeftButton->setToolTip(QCoreApplication::translate("MarbleNavigator", "Left", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        moveLeftButton->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Rotates the globe counterclockwise around its axis.", nullptr));
#endif // QT_CONFIG(whatsthis)
        moveLeftButton->setText(QCoreApplication::translate("MarbleNavigator", "\342\200\246", nullptr));
#if QT_CONFIG(shortcut)
        moveLeftButton->setShortcut(QCoreApplication::translate("MarbleNavigator", "Left", nullptr));
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        goHomeButton->setToolTip(QCoreApplication::translate("MarbleNavigator", "Reset View", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        goHomeButton->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Click this button to restore the original zoom level and view angle.", nullptr));
#endif // QT_CONFIG(whatsthis)
        goHomeButton->setText(QCoreApplication::translate("MarbleNavigator", "\342\200\246", nullptr));
#if QT_CONFIG(shortcut)
        goHomeButton->setShortcut(QCoreApplication::translate("MarbleNavigator", "Home", nullptr));
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        moveRightButton->setToolTip(QCoreApplication::translate("MarbleNavigator", "Right", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        moveRightButton->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Rotates the globe clockwise around its axis.", nullptr));
#endif // QT_CONFIG(whatsthis)
        moveRightButton->setText(QCoreApplication::translate("MarbleNavigator", "\342\200\246", nullptr));
#if QT_CONFIG(shortcut)
        moveRightButton->setShortcut(QCoreApplication::translate("MarbleNavigator", "Right", nullptr));
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        moveDownButton->setToolTip(QCoreApplication::translate("MarbleNavigator", "Down", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        moveDownButton->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Tilts the globe's axis away from the user.", nullptr));
#endif // QT_CONFIG(whatsthis)
        moveDownButton->setText(QCoreApplication::translate("MarbleNavigator", "\342\200\246", nullptr));
#if QT_CONFIG(tooltip)
        zoomInButton->setToolTip(QCoreApplication::translate("MarbleNavigator", "Zoom In", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        zoomInButton->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Zoom in by pressing this button to see more detail.", nullptr));
#endif // QT_CONFIG(whatsthis)
        zoomInButton->setText(QCoreApplication::translate("MarbleNavigator", "\342\200\246", nullptr));
#if QT_CONFIG(shortcut)
        zoomInButton->setShortcut(QCoreApplication::translate("MarbleNavigator", "+", nullptr));
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        zoomSlider->setToolTip(QCoreApplication::translate("MarbleNavigator", "Zoom Slider", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        zoomSlider->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Use this slider to adjust the zoom level of the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        zoomOutButton->setToolTip(QCoreApplication::translate("MarbleNavigator", "Zoom Out", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        zoomOutButton->setWhatsThis(QCoreApplication::translate("MarbleNavigator", "Zoom out by pressing this button to see less detail.", nullptr));
#endif // QT_CONFIG(whatsthis)
        zoomOutButton->setText(QCoreApplication::translate("MarbleNavigator", "\342\200\246", nullptr));
#if QT_CONFIG(shortcut)
        zoomOutButton->setShortcut(QCoreApplication::translate("MarbleNavigator", "-", nullptr));
#endif // QT_CONFIG(shortcut)
        (void)MarbleNavigator;
    } // retranslateUi

};

namespace Ui {
    class MarbleNavigator: public Ui_MarbleNavigator {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MARBLENAVIGATOR_H
