/********************************************************************************
** Form generated from reading UI file 'EditPlacemarkDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITPLACEMARKDIALOG_H
#define UI_EDITPLACEMARKDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "FormattedTextWidget.h"
#include "PlacemarkEditHeader.h"

QT_BEGIN_NAMESPACE

class Ui_UiEditPlacemarkDialog
{
public:
    QAction *m_actionBold;
    QAction *m_actionItalics;
    QAction *m_actionUnderlined;
    QAction *m_actionAddImage;
    QAction *m_actionAddLink;
    QVBoxLayout *verticalLayout;
    Marble::PlacemarkEditHeader *m_header;
    QTabWidget *tabWidget;
    QWidget *m_descriptionTab;
    QVBoxLayout *verticalLayout_3;
    Marble::FormattedTextWidget *m_formattedTextWidget;
    QCheckBox *m_isBalloonVisible;
    QWidget *style_color_tab;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    QPushButton *m_labelButton;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *m_labelScaleField;
    QDoubleSpinBox *m_labelScale;
    QSpacerItem *horizontalSpacer_4;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_4;
    QHBoxLayout *horizontalLayout_11;
    QLabel *m_iconColorField;
    QPushButton *m_iconButton;
    QSpacerItem *horizontalSpacer_14;
    QHBoxLayout *horizontalLayout_12;
    QLabel *m_iconScaleField;
    QDoubleSpinBox *m_iconScale;
    QSpacerItem *horizontalSpacer_15;
    QCheckBox *m_isPlacemarkVisible;
    QSpacerItem *verticalSpacer_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UiEditPlacemarkDialog)
    {
        if (UiEditPlacemarkDialog->objectName().isEmpty())
            UiEditPlacemarkDialog->setObjectName("UiEditPlacemarkDialog");
        UiEditPlacemarkDialog->resize(677, 372);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(UiEditPlacemarkDialog->sizePolicy().hasHeightForWidth());
        UiEditPlacemarkDialog->setSizePolicy(sizePolicy);
        m_actionBold = new QAction(UiEditPlacemarkDialog);
        m_actionBold->setObjectName("m_actionBold");
        m_actionBold->setCheckable(true);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/format-text-bold.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionBold->setIcon(icon);
        m_actionItalics = new QAction(UiEditPlacemarkDialog);
        m_actionItalics->setObjectName("m_actionItalics");
        m_actionItalics->setCheckable(true);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/format-text-italic.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionItalics->setIcon(icon1);
        m_actionUnderlined = new QAction(UiEditPlacemarkDialog);
        m_actionUnderlined->setObjectName("m_actionUnderlined");
        m_actionUnderlined->setCheckable(true);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/format-text-underline.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionUnderlined->setIcon(icon2);
        m_actionAddImage = new QAction(UiEditPlacemarkDialog);
        m_actionAddImage->setObjectName("m_actionAddImage");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/icons/insert-image.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionAddImage->setIcon(icon3);
        m_actionAddLink = new QAction(UiEditPlacemarkDialog);
        m_actionAddLink->setObjectName("m_actionAddLink");
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/icons/insert-link.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionAddLink->setIcon(icon4);
        verticalLayout = new QVBoxLayout(UiEditPlacemarkDialog);
        verticalLayout->setObjectName("verticalLayout");
        m_header = new Marble::PlacemarkEditHeader(UiEditPlacemarkDialog);
        m_header->setObjectName("m_header");

        verticalLayout->addWidget(m_header);

        tabWidget = new QTabWidget(UiEditPlacemarkDialog);
        tabWidget->setObjectName("tabWidget");
        QFont font;
        font.setPointSize(10);
        tabWidget->setFont(font);
        m_descriptionTab = new QWidget();
        m_descriptionTab->setObjectName("m_descriptionTab");
        verticalLayout_3 = new QVBoxLayout(m_descriptionTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_formattedTextWidget = new Marble::FormattedTextWidget(m_descriptionTab);
        m_formattedTextWidget->setObjectName("m_formattedTextWidget");

        verticalLayout_3->addWidget(m_formattedTextWidget);

        m_isBalloonVisible = new QCheckBox(m_descriptionTab);
        m_isBalloonVisible->setObjectName("m_isBalloonVisible");

        verticalLayout_3->addWidget(m_isBalloonVisible);

        tabWidget->addTab(m_descriptionTab, QString());
        style_color_tab = new QWidget();
        style_color_tab->setObjectName("style_color_tab");
        verticalLayout_2 = new QVBoxLayout(style_color_tab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(style_color_tab);
        groupBox->setObjectName("groupBox");
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        QFont font1;
        font1.setPointSize(9);
        label_4->setFont(font1);

        horizontalLayout_2->addWidget(label_4);

        m_labelButton = new QPushButton(groupBox);
        m_labelButton->setObjectName("m_labelButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_labelButton->sizePolicy().hasHeightForWidth());
        m_labelButton->setSizePolicy(sizePolicy1);
        m_labelButton->setMaximumSize(QSize(24, 24));
        m_labelButton->setIconSize(QSize(12, 12));

        horizontalLayout_2->addWidget(m_labelButton);


        horizontalLayout->addLayout(horizontalLayout_2);

        horizontalSpacer_3 = new QSpacerItem(13, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_labelScaleField = new QLabel(groupBox);
        m_labelScaleField->setObjectName("m_labelScaleField");
        m_labelScaleField->setEnabled(true);

        horizontalLayout_3->addWidget(m_labelScaleField);

        m_labelScale = new QDoubleSpinBox(groupBox);
        m_labelScale->setObjectName("m_labelScale");
        m_labelScale->setEnabled(true);
        m_labelScale->setDecimals(1);
        m_labelScale->setMinimum(0.100000000000000);
        m_labelScale->setMaximum(8.000000000000000);

        horizontalLayout_3->addWidget(m_labelScale);


        horizontalLayout->addLayout(horizontalLayout_3);

        horizontalSpacer_4 = new QSpacerItem(96, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(style_color_tab);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_4 = new QHBoxLayout(groupBox_2);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        m_iconColorField = new QLabel(groupBox_2);
        m_iconColorField->setObjectName("m_iconColorField");
        m_iconColorField->setEnabled(false);
        m_iconColorField->setFont(font1);

        horizontalLayout_11->addWidget(m_iconColorField);

        m_iconButton = new QPushButton(groupBox_2);
        m_iconButton->setObjectName("m_iconButton");
        m_iconButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(m_iconButton->sizePolicy().hasHeightForWidth());
        m_iconButton->setSizePolicy(sizePolicy1);
        m_iconButton->setMaximumSize(QSize(24, 24));
        m_iconButton->setIconSize(QSize(12, 12));

        horizontalLayout_11->addWidget(m_iconButton);


        horizontalLayout_4->addLayout(horizontalLayout_11);

        horizontalSpacer_14 = new QSpacerItem(13, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_14);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        m_iconScaleField = new QLabel(groupBox_2);
        m_iconScaleField->setObjectName("m_iconScaleField");
        m_iconScaleField->setEnabled(true);

        horizontalLayout_12->addWidget(m_iconScaleField);

        m_iconScale = new QDoubleSpinBox(groupBox_2);
        m_iconScale->setObjectName("m_iconScale");
        m_iconScale->setEnabled(true);
        m_iconScale->setDecimals(1);
        m_iconScale->setMinimum(0.100000000000000);
        m_iconScale->setMaximum(8.000000000000000);

        horizontalLayout_12->addWidget(m_iconScale);


        horizontalLayout_4->addLayout(horizontalLayout_12);

        horizontalSpacer_15 = new QSpacerItem(96, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_15);


        verticalLayout_2->addWidget(groupBox_2);

        m_isPlacemarkVisible = new QCheckBox(style_color_tab);
        m_isPlacemarkVisible->setObjectName("m_isPlacemarkVisible");

        verticalLayout_2->addWidget(m_isPlacemarkVisible);

        verticalSpacer_3 = new QSpacerItem(298, 44, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);

        tabWidget->addTab(style_color_tab, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(UiEditPlacemarkDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(UiEditPlacemarkDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UiEditPlacemarkDialog, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(UiEditPlacemarkDialog);
    } // setupUi

    void retranslateUi(QDialog *UiEditPlacemarkDialog)
    {
        UiEditPlacemarkDialog->setWindowTitle(QCoreApplication::translate("UiEditPlacemarkDialog", "Edit placemark", nullptr));
        m_actionBold->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Bold", nullptr));
#if QT_CONFIG(tooltip)
        m_actionBold->setToolTip(QCoreApplication::translate("UiEditPlacemarkDialog", "Bold", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionItalics->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Italics", nullptr));
#if QT_CONFIG(tooltip)
        m_actionItalics->setToolTip(QCoreApplication::translate("UiEditPlacemarkDialog", "Italics", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionUnderlined->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Underlined", nullptr));
#if QT_CONFIG(tooltip)
        m_actionUnderlined->setToolTip(QCoreApplication::translate("UiEditPlacemarkDialog", "Underlined", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionAddImage->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Add image", nullptr));
#if QT_CONFIG(tooltip)
        m_actionAddImage->setToolTip(QCoreApplication::translate("UiEditPlacemarkDialog", "Add image", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionAddLink->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Add link", nullptr));
#if QT_CONFIG(tooltip)
        m_actionAddLink->setToolTip(QCoreApplication::translate("UiEditPlacemarkDialog", "Add link", nullptr));
#endif // QT_CONFIG(tooltip)
        m_isBalloonVisible->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Show Balloon Popup", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(m_descriptionTab), QCoreApplication::translate("UiEditPlacemarkDialog", "Description", nullptr));
        groupBox->setTitle(QCoreApplication::translate("UiEditPlacemarkDialog", "Label", nullptr));
        label_4->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Color:", nullptr));
        m_labelButton->setText(QString());
        m_labelScaleField->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Scale:", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("UiEditPlacemarkDialog", "Icon", nullptr));
        m_iconColorField->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Color:", nullptr));
        m_iconButton->setText(QString());
        m_iconScaleField->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Scale:", nullptr));
        m_isPlacemarkVisible->setText(QCoreApplication::translate("UiEditPlacemarkDialog", "Show placemark", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(style_color_tab), QCoreApplication::translate("UiEditPlacemarkDialog", "Style, Color", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UiEditPlacemarkDialog: public Ui_UiEditPlacemarkDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITPLACEMARKDIALOG_H
