/********************************************************************************
** Form generated from reading UI file 'MapQuestConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAPQUESTCONFIGWIDGET_H
#define UI_MAPQUESTCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MapQuestConfigWidget
{
public:
    QFormLayout *formLayout;
    QLabel *appKeyLabel;
    QLineEdit *appKey;
    QLabel *label;
    QComboBox *preference;
    QCheckBox *noMotorways;
    QCheckBox *noTollways;
    QCheckBox *noFerries;
    QLabel *label_2;
    QComboBox *ascending;
    QLabel *label_3;
    QComboBox *descending;
    QLabel *label_4;

    void setupUi(QWidget *MapQuestConfigWidget)
    {
        if (MapQuestConfigWidget->objectName().isEmpty())
            MapQuestConfigWidget->setObjectName("MapQuestConfigWidget");
        MapQuestConfigWidget->resize(352, 237);
        formLayout = new QFormLayout(MapQuestConfigWidget);
        formLayout->setObjectName("formLayout");
        appKeyLabel = new QLabel(MapQuestConfigWidget);
        appKeyLabel->setObjectName("appKeyLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, appKeyLabel);

        appKey = new QLineEdit(MapQuestConfigWidget);
        appKey->setObjectName("appKey");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, appKey);

        label = new QLabel(MapQuestConfigWidget);
        label->setObjectName("label");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        preference = new QComboBox(MapQuestConfigWidget);
        preference->setObjectName("preference");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, preference);

        noMotorways = new QCheckBox(MapQuestConfigWidget);
        noMotorways->setObjectName("noMotorways");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, noMotorways);

        noTollways = new QCheckBox(MapQuestConfigWidget);
        noTollways->setObjectName("noTollways");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, noTollways);

        noFerries = new QCheckBox(MapQuestConfigWidget);
        noFerries->setObjectName("noFerries");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, noFerries);

        label_2 = new QLabel(MapQuestConfigWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_2);

        ascending = new QComboBox(MapQuestConfigWidget);
        ascending->setObjectName("ascending");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, ascending);

        label_3 = new QLabel(MapQuestConfigWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_3);

        descending = new QComboBox(MapQuestConfigWidget);
        descending->setObjectName("descending");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, descending);

        label_4 = new QLabel(MapQuestConfigWidget);
        label_4->setObjectName("label_4");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy);
        label_4->setWordWrap(true);
        label_4->setOpenExternalLinks(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, label_4);

#if QT_CONFIG(shortcut)
        appKeyLabel->setBuddy(appKey);
        label->setBuddy(preference);
        label_2->setBuddy(ascending);
        label_3->setBuddy(descending);
#endif // QT_CONFIG(shortcut)

        retranslateUi(MapQuestConfigWidget);

        QMetaObject::connectSlotsByName(MapQuestConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *MapQuestConfigWidget)
    {
        appKeyLabel->setText(QCoreApplication::translate("MapQuestConfigWidget", "AppKey", nullptr));
        label->setText(QCoreApplication::translate("MapQuestConfigWidget", "Preference:", nullptr));
        noMotorways->setText(QCoreApplication::translate("MapQuestConfigWidget", "Avoid motorways", nullptr));
        noTollways->setText(QCoreApplication::translate("MapQuestConfigWidget", "Avoid tollways", nullptr));
        noFerries->setText(QCoreApplication::translate("MapQuestConfigWidget", "Avoid ferries", nullptr));
        label_2->setText(QCoreApplication::translate("MapQuestConfigWidget", "Ascending slope:", nullptr));
        label_3->setText(QCoreApplication::translate("MapQuestConfigWidget", "Descending slope:", nullptr));
        label_4->setText(QCoreApplication::translate("MapQuestConfigWidget", "An AppKey is required for MapQuest routing to work. You can register one <a href=\"https://developer.mapquest.com/plan_purchase/steps/business_edition/business_edition_free/register\">here</a>.", nullptr));
        (void)MapQuestConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class MapQuestConfigWidget: public Ui_MapQuestConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAPQUESTCONFIGWIDGET_H
