/********************************************************************************
** Form generated from reading UI file 'TimeControlWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TIMECONTROLWIDGET_H
#define UI_TIMECONTROLWIDGET_H

#include <QtCore/QDate>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_TimeControlWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *time;
    QGridLayout *gridLayout;
    QLabel *newLabel;
    QLabel *refreshIntervalLabel;
    QSpinBox *refreshIntervalSpinBox;
    QToolButton *nowToolButton;
    QDateTimeEdit *newDateTimeEdit;
    QDateTimeEdit *currentDateTimeEdit;
    QLabel *currentLabel;
    QGroupBox *timeSpeed;
    QHBoxLayout *horizontalLayout_5;
    QSlider *speedSlider;
    QLabel *speedLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TimeControlWidget)
    {
        if (TimeControlWidget->objectName().isEmpty())
            TimeControlWidget->setObjectName("TimeControlWidget");
        TimeControlWidget->resize(421, 247);
        verticalLayout = new QVBoxLayout(TimeControlWidget);
        verticalLayout->setObjectName("verticalLayout");
        time = new QGroupBox(TimeControlWidget);
        time->setObjectName("time");
        gridLayout = new QGridLayout(time);
        gridLayout->setObjectName("gridLayout");
        newLabel = new QLabel(time);
        newLabel->setObjectName("newLabel");

        gridLayout->addWidget(newLabel, 1, 0, 1, 1);

        refreshIntervalLabel = new QLabel(time);
        refreshIntervalLabel->setObjectName("refreshIntervalLabel");

        gridLayout->addWidget(refreshIntervalLabel, 2, 0, 1, 1);

        refreshIntervalSpinBox = new QSpinBox(time);
        refreshIntervalSpinBox->setObjectName("refreshIntervalSpinBox");
        refreshIntervalSpinBox->setMinimum(1);
        refreshIntervalSpinBox->setMaximum(9999);

        gridLayout->addWidget(refreshIntervalSpinBox, 2, 1, 1, 1);

        nowToolButton = new QToolButton(time);
        nowToolButton->setObjectName("nowToolButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(2);
        sizePolicy.setHeightForWidth(nowToolButton->sizePolicy().hasHeightForWidth());
        nowToolButton->setSizePolicy(sizePolicy);

        gridLayout->addWidget(nowToolButton, 1, 2, 1, 1);

        newDateTimeEdit = new QDateTimeEdit(time);
        newDateTimeEdit->setObjectName("newDateTimeEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(newDateTimeEdit->sizePolicy().hasHeightForWidth());
        newDateTimeEdit->setSizePolicy(sizePolicy1);
        newDateTimeEdit->setDate(QDate(2010, 1, 1));
        newDateTimeEdit->setCalendarPopup(true);

        gridLayout->addWidget(newDateTimeEdit, 1, 1, 1, 1);

        currentDateTimeEdit = new QDateTimeEdit(time);
        currentDateTimeEdit->setObjectName("currentDateTimeEdit");
        currentDateTimeEdit->setEnabled(true);
        sizePolicy1.setHeightForWidth(currentDateTimeEdit->sizePolicy().hasHeightForWidth());
        currentDateTimeEdit->setSizePolicy(sizePolicy1);
        currentDateTimeEdit->setFocusPolicy(Qt::NoFocus);
        currentDateTimeEdit->setFrame(true);
        currentDateTimeEdit->setReadOnly(true);
        currentDateTimeEdit->setButtonSymbols(QAbstractSpinBox::NoButtons);
        currentDateTimeEdit->setKeyboardTracking(false);

        gridLayout->addWidget(currentDateTimeEdit, 0, 1, 1, 1);

        currentLabel = new QLabel(time);
        currentLabel->setObjectName("currentLabel");
        currentLabel->setEnabled(true);

        gridLayout->addWidget(currentLabel, 0, 0, 1, 1);


        verticalLayout->addWidget(time);

        timeSpeed = new QGroupBox(TimeControlWidget);
        timeSpeed->setObjectName("timeSpeed");
        horizontalLayout_5 = new QHBoxLayout(timeSpeed);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        speedSlider = new QSlider(timeSpeed);
        speedSlider->setObjectName("speedSlider");
        speedSlider->setMinimum(-100);
        speedSlider->setMaximum(100);
        speedSlider->setSingleStep(1);
        speedSlider->setPageStep(20);
        speedSlider->setValue(1);
        speedSlider->setSliderPosition(1);
        speedSlider->setOrientation(Qt::Horizontal);
        speedSlider->setTickPosition(QSlider::NoTicks);

        horizontalLayout_5->addWidget(speedSlider);

        speedLabel = new QLabel(timeSpeed);
        speedLabel->setObjectName("speedLabel");

        horizontalLayout_5->addWidget(speedLabel);


        verticalLayout->addWidget(timeSpeed);

        buttonBox = new QDialogButtonBox(TimeControlWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        newLabel->setBuddy(newDateTimeEdit);
        refreshIntervalLabel->setBuddy(refreshIntervalSpinBox);
        currentLabel->setBuddy(currentDateTimeEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(TimeControlWidget);

        QMetaObject::connectSlotsByName(TimeControlWidget);
    } // setupUi

    void retranslateUi(QDialog *TimeControlWidget)
    {
        TimeControlWidget->setWindowTitle(QCoreApplication::translate("TimeControlWidget", "Time Control", nullptr));
        time->setTitle(QCoreApplication::translate("TimeControlWidget", "Time", nullptr));
        newLabel->setText(QCoreApplication::translate("TimeControlWidget", "&New date and time:", nullptr));
        refreshIntervalLabel->setText(QCoreApplication::translate("TimeControlWidget", "Refresh &interval:", nullptr));
        refreshIntervalSpinBox->setSuffix(QCoreApplication::translate("TimeControlWidget", " seconds", nullptr));
        nowToolButton->setText(QCoreApplication::translate("TimeControlWidget", "Now", nullptr));
        currentLabel->setText(QCoreApplication::translate("TimeControlWidget", "Current &date and time:", nullptr));
        timeSpeed->setTitle(QCoreApplication::translate("TimeControlWidget", "Time Speed", nullptr));
        speedLabel->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class TimeControlWidget: public Ui_TimeControlWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TIMECONTROLWIDGET_H
