/****************************************************************************
** Meta object code from reading C++ file 'QtMarbleConfigDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/QtMarbleConfigDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QtMarbleConfigDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble20QtMarbleConfigDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::QtMarbleConfigDialog::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble20QtMarbleConfigDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::QtMarbleConfigDialog",
        "settingsChanged",
        "",
        "clearVolatileCacheClicked",
        "clearPersistentCacheClicked",
        "syncNowClicked",
        "disableSyncNow",
        "enableSyncNow",
        "updateLastSync",
        "readSettings",
        "updateCloudSyncStatus",
        "status",
        "writeSettings",
        "syncSettings",
        "updateCloudSyncCredentials"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearVolatileCacheClicked'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearPersistentCacheClicked'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncNowClicked'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'disableSyncNow'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableSyncNow'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateLastSync'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateCloudSyncStatus'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'writeSettings'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'syncSettings'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCloudSyncCredentials'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QtMarbleConfigDialog, qt_meta_tag_ZN6Marble20QtMarbleConfigDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::QtMarbleConfigDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble20QtMarbleConfigDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble20QtMarbleConfigDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble20QtMarbleConfigDialogE_t>.metaTypes,
    nullptr
} };

void Marble::QtMarbleConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QtMarbleConfigDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->clearVolatileCacheClicked(); break;
        case 2: _t->clearPersistentCacheClicked(); break;
        case 3: _t->syncNowClicked(); break;
        case 4: _t->disableSyncNow(); break;
        case 5: _t->enableSyncNow(); break;
        case 6: _t->updateLastSync(); break;
        case 7: _t->readSettings(); break;
        case 8: _t->updateCloudSyncStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->writeSettings(); break;
        case 10: _t->syncSettings(); break;
        case 11: _t->updateCloudSyncCredentials(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QtMarbleConfigDialog::*)()>(_a, &QtMarbleConfigDialog::settingsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QtMarbleConfigDialog::*)()>(_a, &QtMarbleConfigDialog::clearVolatileCacheClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QtMarbleConfigDialog::*)()>(_a, &QtMarbleConfigDialog::clearPersistentCacheClicked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QtMarbleConfigDialog::*)()>(_a, &QtMarbleConfigDialog::syncNowClicked, 3))
            return;
    }
}

const QMetaObject *Marble::QtMarbleConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::QtMarbleConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble20QtMarbleConfigDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Marble::QtMarbleConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Marble::QtMarbleConfigDialog::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::QtMarbleConfigDialog::clearVolatileCacheClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::QtMarbleConfigDialog::clearPersistentCacheClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::QtMarbleConfigDialog::syncNowClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
