/********************************************************************************
** Form generated from reading UI file 'WebPopupWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WEBPOPUPWIDGET_H
#define UI_WEBPOPUPWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include "MarbleWebView.h"

QT_BEGIN_NAMESPACE

class Ui_WebPopupWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *titleText;
    QToolButton *goBackButton;
    QToolButton *printButton;
    QToolButton *hideButton;
    MarbleWebView *webView;

    void setupUi(QWidget *WebPopupWidget)
    {
        if (WebPopupWidget->objectName().isEmpty())
            WebPopupWidget->setObjectName("WebPopupWidget");
        WebPopupWidget->resize(400, 300);
        gridLayout = new QGridLayout(WebPopupWidget);
        gridLayout->setObjectName("gridLayout");
        titleText = new QLabel(WebPopupWidget);
        titleText->setObjectName("titleText");

        gridLayout->addWidget(titleText, 0, 1, 1, 1);

        goBackButton = new QToolButton(WebPopupWidget);
        goBackButton->setObjectName("goBackButton");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/marble/webpopup/icon-arrow-back.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        goBackButton->setIcon(icon);
        goBackButton->setAutoRaise(true);

        gridLayout->addWidget(goBackButton, 0, 0, 1, 1);

        printButton = new QToolButton(WebPopupWidget);
        printButton->setObjectName("printButton");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/marble/webpopup/icon-print.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        printButton->setIcon(icon1);
        printButton->setAutoRaise(true);

        gridLayout->addWidget(printButton, 0, 2, 1, 1);

        hideButton = new QToolButton(WebPopupWidget);
        hideButton->setObjectName("hideButton");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/marble/webpopup/icon-remove.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        hideButton->setIcon(icon2);
        hideButton->setPopupMode(QToolButton::DelayedPopup);
        hideButton->setAutoRaise(true);
        hideButton->setArrowType(Qt::NoArrow);

        gridLayout->addWidget(hideButton, 0, 3, 1, 1);

        webView = new MarbleWebView(WebPopupWidget);
        webView->setObjectName("webView");

        gridLayout->addWidget(webView, 1, 0, 1, 4);


        retranslateUi(WebPopupWidget);

        QMetaObject::connectSlotsByName(WebPopupWidget);
    } // setupUi

    void retranslateUi(QWidget *WebPopupWidget)
    {
        titleText->setText(QString());
        goBackButton->setText(QString());
        printButton->setText(QString());
        hideButton->setText(QString());
        (void)WebPopupWidget;
    } // retranslateUi

};

namespace Ui {
    class WebPopupWidget: public Ui_WebPopupWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WEBPOPUPWIDGET_H
