/********************************************************************************
** Form generated from reading UI file 'OverviewMapConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OVERVIEWMAPCONFIGWIDGET_H
#define UI_OVERVIEWMAPCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_OverviewMapConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QComboBox *m_planetComboBox;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *m_fileChooserButton;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *m_widthBox;
    QLabel *label_2;
    QSpinBox *m_heightBox;
    QSpacerItem *horizontalSpacer;
    QTableWidget *m_tableWidget;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *label_4;
    QPushButton *m_colorChooserButton;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *OverviewMapConfigWidget)
    {
        if (OverviewMapConfigWidget->objectName().isEmpty())
            OverviewMapConfigWidget->setObjectName("OverviewMapConfigWidget");
        OverviewMapConfigWidget->resize(494, 398);
        verticalLayout = new QVBoxLayout(OverviewMapConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(OverviewMapConfigWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        m_planetComboBox = new QComboBox(groupBox);
        m_planetComboBox->setObjectName("m_planetComboBox");

        horizontalLayout_2->addWidget(m_planetComboBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        m_fileChooserButton = new QToolButton(groupBox);
        m_fileChooserButton->setObjectName("m_fileChooserButton");
        m_fileChooserButton->setMinimumSize(QSize(166, 83));

        verticalLayout_2->addWidget(m_fileChooserButton);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        m_widthBox = new QSpinBox(groupBox);
        m_widthBox->setObjectName("m_widthBox");
        m_widthBox->setMinimum(32);
        m_widthBox->setMaximum(512);
        m_widthBox->setSingleStep(1);
        m_widthBox->setValue(256);

        horizontalLayout->addWidget(m_widthBox);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        m_heightBox = new QSpinBox(groupBox);
        m_heightBox->setObjectName("m_heightBox");
        m_heightBox->setMinimum(16);
        m_heightBox->setMaximum(256);
        m_heightBox->setValue(128);

        horizontalLayout->addWidget(m_heightBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        m_tableWidget = new QTableWidget(groupBox);
        if (m_tableWidget->columnCount() < 2)
            m_tableWidget->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        m_tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        m_tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        m_tableWidget->setObjectName("m_tableWidget");
        m_tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        m_tableWidget->setSelectionMode(QAbstractItemView::SingleSelection);
        m_tableWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        m_tableWidget->horizontalHeader()->setMinimumSectionSize(128);
        m_tableWidget->horizontalHeader()->setDefaultSectionSize(128);
        m_tableWidget->horizontalHeader()->setStretchLastSection(true);
        m_tableWidget->verticalHeader()->setVisible(false);
        m_tableWidget->verticalHeader()->setMinimumSectionSize(64);
        m_tableWidget->verticalHeader()->setDefaultSectionSize(64);

        verticalLayout_2->addWidget(m_tableWidget);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(OverviewMapConfigWidget);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        m_colorChooserButton = new QPushButton(groupBox_2);
        m_colorChooserButton->setObjectName("m_colorChooserButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_colorChooserButton->sizePolicy().hasHeightForWidth());
        m_colorChooserButton->setSizePolicy(sizePolicy);
        m_colorChooserButton->setMinimumSize(QSize(30, 25));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_colorChooserButton);


        verticalLayout->addWidget(groupBox_2);

        m_buttonBox = new QDialogButtonBox(OverviewMapConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(m_buttonBox);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(m_planetComboBox);
        label->setBuddy(m_widthBox);
        label_4->setBuddy(m_colorChooserButton);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OverviewMapConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, OverviewMapConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, OverviewMapConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(OverviewMapConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *OverviewMapConfigWidget)
    {
        OverviewMapConfigWidget->setWindowTitle(QCoreApplication::translate("OverviewMapConfigWidget", "Configure Overview Map", nullptr));
        groupBox->setTitle(QCoreApplication::translate("OverviewMapConfigWidget", "Map &Image", nullptr));
        label_3->setText(QCoreApplication::translate("OverviewMapConfigWidget", "&Planet:", nullptr));
        m_fileChooserButton->setText(QString());
        label->setText(QCoreApplication::translate("OverviewMapConfigWidget", "&Size:", nullptr));
        label_2->setText(QCoreApplication::translate("OverviewMapConfigWidget", "x", nullptr));
        QTableWidgetItem *___qtablewidgetitem = m_tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("OverviewMapConfigWidget", "Preview", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = m_tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("OverviewMapConfigWidget", "Filename", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("OverviewMapConfigWidget", "C&olors", nullptr));
        label_4->setText(QCoreApplication::translate("OverviewMapConfigWidget", "Position I&ndicator:", nullptr));
        m_colorChooserButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class OverviewMapConfigWidget: public Ui_OverviewMapConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OVERVIEWMAPCONFIGWIDGET_H
