/****************************************************************************
** Meta object code from reading C++ file 'PlaybackItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/PlaybackItem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PlaybackItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble12PlaybackItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::PlaybackItem::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble12PlaybackItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::PlaybackItem",
        "finished",
        "",
        "centerOn",
        "GeoDataCoordinates",
        "coordinates",
        "paused",
        "progressChanged",
        "seconds",
        "balloonShown",
        "GeoDataPlacemark*",
        "balloonHidden",
        "updated",
        "GeoDataFeature*",
        "added",
        "GeoDataContainer*",
        "parent",
        "feature",
        "row",
        "removed",
        "const GeoDataFeature*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'centerOn'
        QtMocHelpers::SignalData<void(const GeoDataCoordinates &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'paused'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void(double)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 8 },
        }}),
        // Signal 'balloonShown'
        QtMocHelpers::SignalData<void(GeoDataPlacemark *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'balloonHidden'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void(GeoDataFeature *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Signal 'added'
        QtMocHelpers::SignalData<void(GeoDataContainer *, GeoDataFeature *, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 13, 17 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void(const GeoDataFeature *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlaybackItem, qt_meta_tag_ZN6Marble12PlaybackItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::PlaybackItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12PlaybackItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12PlaybackItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble12PlaybackItemE_t>.metaTypes,
    nullptr
} };

void Marble::PlaybackItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaybackItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished(); break;
        case 1: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 2: _t->paused(); break;
        case 3: _t->progressChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->balloonShown((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark*>>(_a[1]))); break;
        case 5: _t->balloonHidden(); break;
        case 6: _t->updated((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1]))); break;
        case 7: _t->added((*reinterpret_cast<std::add_pointer_t<GeoDataContainer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->removed((*reinterpret_cast<std::add_pointer_t<const GeoDataFeature*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)()>(_a, &PlaybackItem::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)(const GeoDataCoordinates & )>(_a, &PlaybackItem::centerOn, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)()>(_a, &PlaybackItem::paused, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)(double )>(_a, &PlaybackItem::progressChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)(GeoDataPlacemark * )>(_a, &PlaybackItem::balloonShown, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)()>(_a, &PlaybackItem::balloonHidden, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)(GeoDataFeature * )>(_a, &PlaybackItem::updated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)(GeoDataContainer * , GeoDataFeature * , int )>(_a, &PlaybackItem::added, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackItem::*)(const GeoDataFeature * )>(_a, &PlaybackItem::removed, 8))
            return;
    }
}

const QMetaObject *Marble::PlaybackItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::PlaybackItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12PlaybackItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::PlaybackItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Marble::PlaybackItem::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::PlaybackItem::centerOn(const GeoDataCoordinates & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::PlaybackItem::paused()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::PlaybackItem::progressChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::PlaybackItem::balloonShown(GeoDataPlacemark * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::PlaybackItem::balloonHidden()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Marble::PlaybackItem::updated(GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Marble::PlaybackItem::added(GeoDataContainer * _t1, GeoDataFeature * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void Marble::PlaybackItem::removed(const GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
