/********************************************************************************
** Form generated from reading UI file 'BookmarkManagerDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOOKMARKMANAGERDIALOG_H
#define UI_BOOKMARKMANAGERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_UiBookmarkManagerDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *importButton;
    QPushButton *exportButton;
    QSpacerItem *horizontalSpacer_3;
    QSplitter *splitter;
    QWidget *layoutWidget;
    QGridLayout *foldersGridLayout;
    QLabel *foldersLabel;
    QPushButton *newFolderButton;
    QPushButton *renameFolderButton;
    QPushButton *removeFolderButton;
    QSpacerItem *horizontalSpacer_2;
    QTreeView *foldersTreeView;
    QWidget *layoutWidget1;
    QGridLayout *bookmarksGridLayout;
    QLabel *bookmarkLabel;
    QListView *bookmarksListView;
    QSpacerItem *horizontalSpacer;
    QPushButton *editBookmarkButton;
    QPushButton *removeBookmarkButton;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UiBookmarkManagerDialog)
    {
        if (UiBookmarkManagerDialog->objectName().isEmpty())
            UiBookmarkManagerDialog->setObjectName("UiBookmarkManagerDialog");
        UiBookmarkManagerDialog->resize(419, 262);
        verticalLayout = new QVBoxLayout(UiBookmarkManagerDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        importButton = new QPushButton(UiBookmarkManagerDialog);
        importButton->setObjectName("importButton");
        importButton->setEnabled(true);

        horizontalLayout->addWidget(importButton);

        exportButton = new QPushButton(UiBookmarkManagerDialog);
        exportButton->setObjectName("exportButton");
        exportButton->setEnabled(true);

        horizontalLayout->addWidget(exportButton);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout);

        splitter = new QSplitter(UiBookmarkManagerDialog);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        foldersGridLayout = new QGridLayout(layoutWidget);
        foldersGridLayout->setObjectName("foldersGridLayout");
        foldersGridLayout->setContentsMargins(0, 0, 0, 0);
        foldersLabel = new QLabel(layoutWidget);
        foldersLabel->setObjectName("foldersLabel");

        foldersGridLayout->addWidget(foldersLabel, 0, 0, 1, 1);

        newFolderButton = new QPushButton(layoutWidget);
        newFolderButton->setObjectName("newFolderButton");
        newFolderButton->setEnabled(true);

        foldersGridLayout->addWidget(newFolderButton, 2, 0, 1, 1);

        renameFolderButton = new QPushButton(layoutWidget);
        renameFolderButton->setObjectName("renameFolderButton");

        foldersGridLayout->addWidget(renameFolderButton, 2, 1, 1, 1);

        removeFolderButton = new QPushButton(layoutWidget);
        removeFolderButton->setObjectName("removeFolderButton");
        removeFolderButton->setEnabled(true);

        foldersGridLayout->addWidget(removeFolderButton, 2, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(18, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        foldersGridLayout->addItem(horizontalSpacer_2, 2, 3, 1, 1);

        foldersTreeView = new QTreeView(layoutWidget);
        foldersTreeView->setObjectName("foldersTreeView");

        foldersGridLayout->addWidget(foldersTreeView, 1, 0, 1, 4);

        splitter->addWidget(layoutWidget);
        layoutWidget1 = new QWidget(splitter);
        layoutWidget1->setObjectName("layoutWidget1");
        bookmarksGridLayout = new QGridLayout(layoutWidget1);
        bookmarksGridLayout->setObjectName("bookmarksGridLayout");
        bookmarksGridLayout->setContentsMargins(0, 0, 0, 0);
        bookmarkLabel = new QLabel(layoutWidget1);
        bookmarkLabel->setObjectName("bookmarkLabel");

        bookmarksGridLayout->addWidget(bookmarkLabel, 0, 0, 1, 1);

        bookmarksListView = new QListView(layoutWidget1);
        bookmarksListView->setObjectName("bookmarksListView");

        bookmarksGridLayout->addWidget(bookmarksListView, 1, 0, 1, 3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        bookmarksGridLayout->addItem(horizontalSpacer, 2, 0, 1, 1);

        editBookmarkButton = new QPushButton(layoutWidget1);
        editBookmarkButton->setObjectName("editBookmarkButton");

        bookmarksGridLayout->addWidget(editBookmarkButton, 2, 1, 1, 1);

        removeBookmarkButton = new QPushButton(layoutWidget1);
        removeBookmarkButton->setObjectName("removeBookmarkButton");
        removeBookmarkButton->setEnabled(true);

        bookmarksGridLayout->addWidget(removeBookmarkButton, 2, 2, 1, 1);

        splitter->addWidget(layoutWidget1);

        verticalLayout->addWidget(splitter);

        buttonBox = new QDialogButtonBox(UiBookmarkManagerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(UiBookmarkManagerDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, UiBookmarkManagerDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UiBookmarkManagerDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(UiBookmarkManagerDialog);
    } // setupUi

    void retranslateUi(QDialog *UiBookmarkManagerDialog)
    {
        UiBookmarkManagerDialog->setWindowTitle(QCoreApplication::translate("UiBookmarkManagerDialog", "Bookmark Manager", nullptr));
        importButton->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Import Bookmarks\342\200\246", nullptr));
        exportButton->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Export Bookmarks\342\200\246", nullptr));
        foldersLabel->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Folders", nullptr));
        newFolderButton->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "New\342\200\246", nullptr));
        renameFolderButton->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Rename\342\200\246", nullptr));
        removeFolderButton->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Delete", nullptr));
        bookmarkLabel->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Bookmarks", nullptr));
        editBookmarkButton->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Edit", nullptr));
        removeBookmarkButton->setText(QCoreApplication::translate("UiBookmarkManagerDialog", "Delete", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UiBookmarkManagerDialog: public Ui_UiBookmarkManagerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BOOKMARKMANAGERDIALOG_H
