/********************************************************************************
** Form generated from reading UI file 'MarbleViewSettingsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MARBLEVIEWSETTINGSWIDGET_H
#define UI_MARBLEVIEWSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MarbleViewSettingsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_units;
    QGridLayout *gridLayout;
    QLabel *label_distanceUnit;
    QComboBox *kcfg_distanceUnit;
    QLabel *label_angleUnit;
    QComboBox *kcfg_angleUnit;
    QGroupBox *groupBox_mapQuality;
    QGridLayout *gridLayout1;
    QLabel *label_stillQuality;
    QComboBox *kcfg_stillQuality;
    QLabel *label_animationQuality;
    QComboBox *kcfg_animationQuality;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_textLabels;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label_labelLocalization;
    QComboBox *kcfg_labelLocalization;
    QHBoxLayout *hboxLayout1;
    QLabel *label_mapFont;
    QFontComboBox *kcfg_mapFont;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *MarbleViewSettingsWidget)
    {
        if (MarbleViewSettingsWidget->objectName().isEmpty())
            MarbleViewSettingsWidget->setObjectName("MarbleViewSettingsWidget");
        MarbleViewSettingsWidget->resize(541, 430);
        verticalLayout = new QVBoxLayout(MarbleViewSettingsWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox_units = new QGroupBox(MarbleViewSettingsWidget);
        groupBox_units->setObjectName("groupBox_units");
        gridLayout = new QGridLayout(groupBox_units);
        gridLayout->setObjectName("gridLayout");
        label_distanceUnit = new QLabel(groupBox_units);
        label_distanceUnit->setObjectName("label_distanceUnit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_distanceUnit->sizePolicy().hasHeightForWidth());
        label_distanceUnit->setSizePolicy(sizePolicy);
        label_distanceUnit->setMinimumSize(QSize(118, 0));

        gridLayout->addWidget(label_distanceUnit, 0, 0, 1, 1);

        kcfg_distanceUnit = new QComboBox(groupBox_units);
        kcfg_distanceUnit->addItem(QString());
        kcfg_distanceUnit->addItem(QString());
        kcfg_distanceUnit->addItem(QString());
        kcfg_distanceUnit->setObjectName("kcfg_distanceUnit");
        kcfg_distanceUnit->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_distanceUnit->sizePolicy().hasHeightForWidth());
        kcfg_distanceUnit->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(kcfg_distanceUnit, 0, 1, 1, 1);

        label_angleUnit = new QLabel(groupBox_units);
        label_angleUnit->setObjectName("label_angleUnit");
        sizePolicy.setHeightForWidth(label_angleUnit->sizePolicy().hasHeightForWidth());
        label_angleUnit->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_angleUnit, 1, 0, 1, 1);

        kcfg_angleUnit = new QComboBox(groupBox_units);
        kcfg_angleUnit->addItem(QString());
        kcfg_angleUnit->addItem(QString());
        kcfg_angleUnit->addItem(QString());
        kcfg_angleUnit->setObjectName("kcfg_angleUnit");
        kcfg_angleUnit->setEnabled(true);

        gridLayout->addWidget(kcfg_angleUnit, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBox_units);

        groupBox_mapQuality = new QGroupBox(MarbleViewSettingsWidget);
        groupBox_mapQuality->setObjectName("groupBox_mapQuality");
        gridLayout1 = new QGridLayout(groupBox_mapQuality);
        gridLayout1->setObjectName("gridLayout1");
        label_stillQuality = new QLabel(groupBox_mapQuality);
        label_stillQuality->setObjectName("label_stillQuality");
        sizePolicy.setHeightForWidth(label_stillQuality->sizePolicy().hasHeightForWidth());
        label_stillQuality->setSizePolicy(sizePolicy);
        label_stillQuality->setMinimumSize(QSize(118, 0));

        gridLayout1->addWidget(label_stillQuality, 0, 0, 1, 1);

        kcfg_stillQuality = new QComboBox(groupBox_mapQuality);
        kcfg_stillQuality->addItem(QString());
        kcfg_stillQuality->addItem(QString());
        kcfg_stillQuality->addItem(QString());
        kcfg_stillQuality->addItem(QString());
        kcfg_stillQuality->addItem(QString());
        kcfg_stillQuality->setObjectName("kcfg_stillQuality");

        gridLayout1->addWidget(kcfg_stillQuality, 0, 1, 1, 1);

        label_animationQuality = new QLabel(groupBox_mapQuality);
        label_animationQuality->setObjectName("label_animationQuality");
        sizePolicy.setHeightForWidth(label_animationQuality->sizePolicy().hasHeightForWidth());
        label_animationQuality->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(label_animationQuality, 1, 0, 1, 1);

        kcfg_animationQuality = new QComboBox(groupBox_mapQuality);
        kcfg_animationQuality->addItem(QString());
        kcfg_animationQuality->addItem(QString());
        kcfg_animationQuality->addItem(QString());
        kcfg_animationQuality->addItem(QString());
        kcfg_animationQuality->addItem(QString());
        kcfg_animationQuality->setObjectName("kcfg_animationQuality");

        gridLayout1->addWidget(kcfg_animationQuality, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout1->addItem(verticalSpacer, 2, 0, 1, 1);


        verticalLayout->addWidget(groupBox_mapQuality);

        groupBox_textLabels = new QGroupBox(MarbleViewSettingsWidget);
        groupBox_textLabels->setObjectName("groupBox_textLabels");
        vboxLayout = new QVBoxLayout(groupBox_textLabels);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_labelLocalization = new QLabel(groupBox_textLabels);
        label_labelLocalization->setObjectName("label_labelLocalization");
        sizePolicy.setHeightForWidth(label_labelLocalization->sizePolicy().hasHeightForWidth());
        label_labelLocalization->setSizePolicy(sizePolicy);
        label_labelLocalization->setMinimumSize(QSize(118, 0));

        hboxLayout->addWidget(label_labelLocalization);

        kcfg_labelLocalization = new QComboBox(groupBox_textLabels);
        kcfg_labelLocalization->addItem(QString());
        kcfg_labelLocalization->addItem(QString());
        kcfg_labelLocalization->addItem(QString());
        kcfg_labelLocalization->setObjectName("kcfg_labelLocalization");
        kcfg_labelLocalization->setEnabled(false);

        hboxLayout->addWidget(kcfg_labelLocalization);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_mapFont = new QLabel(groupBox_textLabels);
        label_mapFont->setObjectName("label_mapFont");
        sizePolicy.setHeightForWidth(label_mapFont->sizePolicy().hasHeightForWidth());
        label_mapFont->setSizePolicy(sizePolicy);
        label_mapFont->setMinimumSize(QSize(118, 0));

        hboxLayout1->addWidget(label_mapFont);

        kcfg_mapFont = new QFontComboBox(groupBox_textLabels);
        kcfg_mapFont->setObjectName("kcfg_mapFont");

        hboxLayout1->addWidget(kcfg_mapFont);


        vboxLayout->addLayout(hboxLayout1);


        verticalLayout->addWidget(groupBox_textLabels);

        spacerItem = new QSpacerItem(446, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label_distanceUnit->setBuddy(kcfg_distanceUnit);
        label_angleUnit->setBuddy(kcfg_angleUnit);
        label_stillQuality->setBuddy(kcfg_stillQuality);
        label_animationQuality->setBuddy(kcfg_animationQuality);
        label_labelLocalization->setBuddy(kcfg_labelLocalization);
        label_mapFont->setBuddy(kcfg_mapFont);
#endif // QT_CONFIG(shortcut)

        retranslateUi(MarbleViewSettingsWidget);

        kcfg_stillQuality->setCurrentIndex(3);
        kcfg_animationQuality->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(MarbleViewSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *MarbleViewSettingsWidget)
    {
        groupBox_units->setTitle(QCoreApplication::translate("MarbleViewSettingsWidget", "&Units", nullptr));
        label_distanceUnit->setText(QCoreApplication::translate("MarbleViewSettingsWidget", "&Distance:", nullptr));
        kcfg_distanceUnit->setItemText(0, QCoreApplication::translate("MarbleViewSettingsWidget", "Kilometer, Meter", nullptr));
        kcfg_distanceUnit->setItemText(1, QCoreApplication::translate("MarbleViewSettingsWidget", "Miles, Feet", nullptr));
        kcfg_distanceUnit->setItemText(2, QCoreApplication::translate("MarbleViewSettingsWidget", "Nautical miles, Knots", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_distanceUnit->setToolTip(QCoreApplication::translate("MarbleViewSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The unit that gets used to measure altitude, lengths and distances (e.g. km, mi, ft).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_angleUnit->setText(QCoreApplication::translate("MarbleViewSettingsWidget", "An&gle:", nullptr));
        kcfg_angleUnit->setItemText(0, QCoreApplication::translate("MarbleViewSettingsWidget", "Degree (DMS)", nullptr));
        kcfg_angleUnit->setItemText(1, QCoreApplication::translate("MarbleViewSettingsWidget", "Degree (Decimal)", nullptr));
        kcfg_angleUnit->setItemText(2, QCoreApplication::translate("MarbleViewSettingsWidget", "Universal Transverse Mercator (UTM)", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_angleUnit->setToolTip(QCoreApplication::translate("MarbleViewSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Specifies the notation of angles in coordinates: By default the Degree-Minute-Second notation (e.g. 54\302\26030'00\" ) gets used. As an alternative you can choose decimal degrees (e.g. 54.5\302\260).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_mapQuality->setTitle(QCoreApplication::translate("MarbleViewSettingsWidget", "Map &Quality", nullptr));
        label_stillQuality->setText(QCoreApplication::translate("MarbleViewSettingsWidget", "&Still image:", nullptr));
        kcfg_stillQuality->setItemText(0, QCoreApplication::translate("MarbleViewSettingsWidget", "Outline Quality", nullptr));
        kcfg_stillQuality->setItemText(1, QCoreApplication::translate("MarbleViewSettingsWidget", "Low Quality", nullptr));
        kcfg_stillQuality->setItemText(2, QCoreApplication::translate("MarbleViewSettingsWidget", "Normal", nullptr));
        kcfg_stillQuality->setItemText(3, QCoreApplication::translate("MarbleViewSettingsWidget", "High Quality", nullptr));
        kcfg_stillQuality->setItemText(4, QCoreApplication::translate("MarbleViewSettingsWidget", "Print Quality", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_stillQuality->setToolTip(QCoreApplication::translate("MarbleViewSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Specifies the map quality that gets displayed while there is no user input. Usually this allows for high map quality as speed is no concern.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_animationQuality->setText(QCoreApplication::translate("MarbleViewSettingsWidget", "During &animations:", nullptr));
        kcfg_animationQuality->setItemText(0, QCoreApplication::translate("MarbleViewSettingsWidget", "Outline Quality", nullptr));
        kcfg_animationQuality->setItemText(1, QCoreApplication::translate("MarbleViewSettingsWidget", "Low Quality", nullptr));
        kcfg_animationQuality->setItemText(2, QCoreApplication::translate("MarbleViewSettingsWidget", "Normal", nullptr));
        kcfg_animationQuality->setItemText(3, QCoreApplication::translate("MarbleViewSettingsWidget", "High Quality", nullptr));
        kcfg_animationQuality->setItemText(4, QCoreApplication::translate("MarbleViewSettingsWidget", "Print Quality", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_animationQuality->setToolTip(QCoreApplication::translate("MarbleViewSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Specifies the map quality that gets displayed during map animations (e.g. while dragging the globe). </p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Especially on slow machines it is advisable to set this option to \"low quality\" as this will give better speed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_textLabels->setTitle(QCoreApplication::translate("MarbleViewSettingsWidget", "&Text Labels", nullptr));
        label_labelLocalization->setText(QCoreApplication::translate("MarbleViewSettingsWidget", "&Place names:", nullptr));
        kcfg_labelLocalization->setItemText(0, QCoreApplication::translate("MarbleViewSettingsWidget", "Custom & Native Language", nullptr));
        kcfg_labelLocalization->setItemText(1, QCoreApplication::translate("MarbleViewSettingsWidget", "Custom Language", nullptr));
        kcfg_labelLocalization->setItemText(2, QCoreApplication::translate("MarbleViewSettingsWidget", "Native Language", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_labelLocalization->setToolTip(QCoreApplication::translate("MarbleViewSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Places often have different names in different languages. The label on the map can show the name in the user's language. Alternatively it can display the name in the official language and glyphs of that place. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_mapFont->setText(QCoreApplication::translate("MarbleViewSettingsWidget", "Default map &font:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_mapFont->setToolTip(QCoreApplication::translate("MarbleViewSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The default font that gets used on the map.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)MarbleViewSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class MarbleViewSettingsWidget: public Ui_MarbleViewSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MARBLEVIEWSETTINGSWIDGET_H
