/********************************************************************************
** Form generated from reading UI file 'MarbleTimeSettingsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MARBLETIMESETTINGSWIDGET_H
#define UI_MARBLETIMESETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MarbleTimeSettingsWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *timeZone;
    QVBoxLayout *verticalLayout;
    QRadioButton *kcfg_utc;
    QRadioButton *kcfg_systemTimezone;
    QHBoxLayout *hboxLayout;
    QRadioButton *kcfg_customTimezone;
    QComboBox *kcfg_chosenTimezone;
    QGroupBox *whenMarbleStarts;
    QVBoxLayout *verticalLayout_4;
    QRadioButton *kcfg_systemTime;
    QRadioButton *kcfg_lastSessionTime;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *MarbleTimeSettingsWidget)
    {
        if (MarbleTimeSettingsWidget->objectName().isEmpty())
            MarbleTimeSettingsWidget->setObjectName("MarbleTimeSettingsWidget");
        MarbleTimeSettingsWidget->resize(485, 305);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MarbleTimeSettingsWidget->sizePolicy().hasHeightForWidth());
        MarbleTimeSettingsWidget->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(MarbleTimeSettingsWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        timeZone = new QGroupBox(MarbleTimeSettingsWidget);
        timeZone->setObjectName("timeZone");
        verticalLayout = new QVBoxLayout(timeZone);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_utc = new QRadioButton(timeZone);
        kcfg_utc->setObjectName("kcfg_utc");
        kcfg_utc->setChecked(false);

        verticalLayout->addWidget(kcfg_utc);

        kcfg_systemTimezone = new QRadioButton(timeZone);
        kcfg_systemTimezone->setObjectName("kcfg_systemTimezone");
        kcfg_systemTimezone->setChecked(true);

        verticalLayout->addWidget(kcfg_systemTimezone);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        kcfg_customTimezone = new QRadioButton(timeZone);
        kcfg_customTimezone->setObjectName("kcfg_customTimezone");

        hboxLayout->addWidget(kcfg_customTimezone);

        kcfg_chosenTimezone = new QComboBox(timeZone);
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->addItem(QString());
        kcfg_chosenTimezone->setObjectName("kcfg_chosenTimezone");
        kcfg_chosenTimezone->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_chosenTimezone->sizePolicy().hasHeightForWidth());
        kcfg_chosenTimezone->setSizePolicy(sizePolicy1);

        hboxLayout->addWidget(kcfg_chosenTimezone);


        verticalLayout->addLayout(hboxLayout);


        verticalLayout_2->addWidget(timeZone);

        whenMarbleStarts = new QGroupBox(MarbleTimeSettingsWidget);
        whenMarbleStarts->setObjectName("whenMarbleStarts");
        verticalLayout_4 = new QVBoxLayout(whenMarbleStarts);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kcfg_systemTime = new QRadioButton(whenMarbleStarts);
        kcfg_systemTime->setObjectName("kcfg_systemTime");
        kcfg_systemTime->setChecked(true);

        verticalLayout_4->addWidget(kcfg_systemTime);

        kcfg_lastSessionTime = new QRadioButton(whenMarbleStarts);
        kcfg_lastSessionTime->setObjectName("kcfg_lastSessionTime");

        verticalLayout_4->addWidget(kcfg_lastSessionTime);


        verticalLayout_2->addWidget(whenMarbleStarts);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(MarbleTimeSettingsWidget);
        QObject::connect(kcfg_customTimezone, &QRadioButton::toggled, kcfg_chosenTimezone, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(MarbleTimeSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *MarbleTimeSettingsWidget)
    {
        timeZone->setTitle(QCoreApplication::translate("MarbleTimeSettingsWidget", "Time Zone", nullptr));
        kcfg_utc->setText(QCoreApplication::translate("MarbleTimeSettingsWidget", "UTC", nullptr));
        kcfg_systemTimezone->setText(QCoreApplication::translate("MarbleTimeSettingsWidget", "System time zone", nullptr));
        kcfg_customTimezone->setText(QCoreApplication::translate("MarbleTimeSettingsWidget", "Choose Time zone", nullptr));
        kcfg_chosenTimezone->setItemText(0, QCoreApplication::translate("MarbleTimeSettingsWidget", "Universal Time Coordinated", nullptr));
        kcfg_chosenTimezone->setItemText(1, QCoreApplication::translate("MarbleTimeSettingsWidget", "European Central Time", nullptr));
        kcfg_chosenTimezone->setItemText(2, QCoreApplication::translate("MarbleTimeSettingsWidget", "Eastern European Time", nullptr));
        kcfg_chosenTimezone->setItemText(3, QCoreApplication::translate("MarbleTimeSettingsWidget", "Egypt Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(4, QCoreApplication::translate("MarbleTimeSettingsWidget", "Eastern African Time", nullptr));
        kcfg_chosenTimezone->setItemText(5, QCoreApplication::translate("MarbleTimeSettingsWidget", "Middle East Time", nullptr));
        kcfg_chosenTimezone->setItemText(6, QCoreApplication::translate("MarbleTimeSettingsWidget", "Near East Time", nullptr));
        kcfg_chosenTimezone->setItemText(7, QCoreApplication::translate("MarbleTimeSettingsWidget", "Pakistan Lahore Time", nullptr));
        kcfg_chosenTimezone->setItemText(8, QCoreApplication::translate("MarbleTimeSettingsWidget", "India Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(9, QCoreApplication::translate("MarbleTimeSettingsWidget", "Bangladesh Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(10, QCoreApplication::translate("MarbleTimeSettingsWidget", "Vietnam Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(11, QCoreApplication::translate("MarbleTimeSettingsWidget", "China Taiwan Time", nullptr));
        kcfg_chosenTimezone->setItemText(12, QCoreApplication::translate("MarbleTimeSettingsWidget", "Japan Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(13, QCoreApplication::translate("MarbleTimeSettingsWidget", "Australia Central Time", nullptr));
        kcfg_chosenTimezone->setItemText(14, QCoreApplication::translate("MarbleTimeSettingsWidget", "Australia Eastern Time", nullptr));
        kcfg_chosenTimezone->setItemText(15, QCoreApplication::translate("MarbleTimeSettingsWidget", "Solomon Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(16, QCoreApplication::translate("MarbleTimeSettingsWidget", "New Zealand Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(17, QCoreApplication::translate("MarbleTimeSettingsWidget", "Midway Islands Time", nullptr));
        kcfg_chosenTimezone->setItemText(18, QCoreApplication::translate("MarbleTimeSettingsWidget", "Hawaii Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(19, QCoreApplication::translate("MarbleTimeSettingsWidget", "Alaska Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(20, QCoreApplication::translate("MarbleTimeSettingsWidget", "Pacific Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(21, QCoreApplication::translate("MarbleTimeSettingsWidget", "Phoenix Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(22, QCoreApplication::translate("MarbleTimeSettingsWidget", "Mountain Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(23, QCoreApplication::translate("MarbleTimeSettingsWidget", "Central Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(24, QCoreApplication::translate("MarbleTimeSettingsWidget", "Eastern Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(25, QCoreApplication::translate("MarbleTimeSettingsWidget", "Indiana Eastern Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(26, QCoreApplication::translate("MarbleTimeSettingsWidget", "Puerto Rico and US Virgin Islands Time", nullptr));
        kcfg_chosenTimezone->setItemText(27, QCoreApplication::translate("MarbleTimeSettingsWidget", "Canada Newfoundland Time", nullptr));
        kcfg_chosenTimezone->setItemText(28, QCoreApplication::translate("MarbleTimeSettingsWidget", "Argentina Standard Time", nullptr));
        kcfg_chosenTimezone->setItemText(29, QCoreApplication::translate("MarbleTimeSettingsWidget", "Brazil Eastern Time", nullptr));
        kcfg_chosenTimezone->setItemText(30, QCoreApplication::translate("MarbleTimeSettingsWidget", "Central African Time", nullptr));

        whenMarbleStarts->setTitle(QCoreApplication::translate("MarbleTimeSettingsWidget", "When Marble starts", nullptr));
        kcfg_systemTime->setText(QCoreApplication::translate("MarbleTimeSettingsWidget", "Load system time", nullptr));
        kcfg_lastSessionTime->setText(QCoreApplication::translate("MarbleTimeSettingsWidget", "Load last session time", nullptr));
        (void)MarbleTimeSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class MarbleTimeSettingsWidget: public Ui_MarbleTimeSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MARBLETIMESETTINGSWIDGET_H
