/****************************************************************************
** Meta object code from reading C++ file 'GpsdPositionProviderPlugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/plugins/positionprovider/gpsd/GpsdPositionProviderPlugin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GpsdPositionProviderPlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble26GpsdPositionProviderPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::GpsdPositionProviderPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble26GpsdPositionProviderPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::GpsdPositionProviderPlugin",
        "update",
        "",
        "gps_data_t",
        "data"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'update'
        QtMocHelpers::SlotData<void(gps_data_t)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GpsdPositionProviderPlugin, qt_meta_tag_ZN6Marble26GpsdPositionProviderPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::GpsdPositionProviderPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<PositionProviderPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble26GpsdPositionProviderPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble26GpsdPositionProviderPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble26GpsdPositionProviderPluginE_t>.metaTypes,
    nullptr
} };

void Marble::GpsdPositionProviderPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GpsdPositionProviderPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->update((*reinterpret_cast<std::add_pointer_t<gps_data_t>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Marble::GpsdPositionProviderPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::GpsdPositionProviderPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble26GpsdPositionProviderPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.kde.Marble.PositionProviderPluginInterface/1.02"))
        return static_cast< Marble::PositionProviderPluginInterface*>(this);
    return PositionProviderPlugin::qt_metacast(_clname);
}

int Marble::GpsdPositionProviderPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PositionProviderPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
using namespace Marble;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_GpsdPositionProviderPlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x29,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'G',  'p',  's',  'd',  'P',  'o', 
    's',  'i',  't',  'i',  'o',  'n',  'P',  'r', 
    'o',  'v',  'i',  'd',  'e',  'r',  'P',  'l', 
    'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x78,  0x1a,  'G',  'p',  's',  'd',  'P', 
    'o',  's',  'i',  't',  'i',  'o',  'n',  'P', 
    'r',  'o',  'v',  'i',  'd',  'e',  'r',  'P', 
    'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(Marble::GpsdPositionProviderPlugin, GpsdPositionProviderPlugin, qt_pluginMetaDataV2_GpsdPositionProviderPlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_GpsdPositionProviderPlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x29,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'G',  'p',  's',  'd',  'P',  'o', 
    's',  'i',  't',  'i',  'o',  'n',  'P',  'r', 
    'o',  'v',  'i',  'd',  'e',  'r',  'P',  'l', 
    'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x78,  0x1a,  'G',  'p',  's',  'd',  'P', 
    'o',  's',  'i',  't',  'i',  'o',  'n',  'P', 
    'r',  'o',  'v',  'i',  'd',  'e',  'r',  'P', 
    'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(Marble::GpsdPositionProviderPlugin, GpsdPositionProviderPlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
