/****************************************************************************
** Meta object code from reading C++ file 'TourWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/TourWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TourWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble10TourWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::TourWidget::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble10TourWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::TourWidget",
        "featureUpdated",
        "",
        "GeoDataFeature*",
        "feature",
        "featureAdded",
        "GeoDataContainer*",
        "parent",
        "row",
        "featureRemoved",
        "const GeoDataFeature*",
        "startPlaying",
        "pausePlaying",
        "togglePlaying",
        "stopPlaying",
        "handleSliderMove",
        "setHighlightedItemIndex",
        "index",
        "moveUp",
        "moveDown",
        "addFlyTo",
        "addWait",
        "addSoundCue",
        "addPlacemark",
        "addRemovePlacemark",
        "addChangePlacemark",
        "deleteSelected",
        "updateDuration",
        "finishAddingItem",
        "stopLooping",
        "openFile",
        "createTour",
        "saveTour",
        "saveTourAs",
        "captureTour",
        "updateButtonsStates",
        "mapCenterOn",
        "QModelIndex",
        "handlePlaybackProgress",
        "position"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'featureUpdated'
        QtMocHelpers::SignalData<void(GeoDataFeature *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'featureAdded'
        QtMocHelpers::SignalData<void(GeoDataContainer *, GeoDataFeature *, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 3, 4 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'featureRemoved'
        QtMocHelpers::SignalData<void(const GeoDataFeature *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Slot 'startPlaying'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pausePlaying'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'togglePlaying'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopPlaying'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleSliderMove'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setHighlightedItemIndex'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'moveUp'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveDown'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addFlyTo'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addWait'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addSoundCue'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addPlacemark'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addRemovePlacemark'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addChangePlacemark'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteSelected'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDuration'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'finishAddingItem'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopLooping'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createTour'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveTour'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveTourAs'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'captureTour'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateButtonsStates'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mapCenterOn'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 17 },
        }}),
        // Slot 'handlePlaybackProgress'
        QtMocHelpers::SlotData<void(const double)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TourWidget, qt_meta_tag_ZN6Marble10TourWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::TourWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TourWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TourWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble10TourWidgetE_t>.metaTypes,
    nullptr
} };

void Marble::TourWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TourWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->featureUpdated((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1]))); break;
        case 1: _t->featureAdded((*reinterpret_cast<std::add_pointer_t<GeoDataContainer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->featureRemoved((*reinterpret_cast<std::add_pointer_t<const GeoDataFeature*>>(_a[1]))); break;
        case 3: _t->startPlaying(); break;
        case 4: _t->pausePlaying(); break;
        case 5: _t->togglePlaying(); break;
        case 6: _t->stopPlaying(); break;
        case 7: _t->handleSliderMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setHighlightedItemIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->moveUp(); break;
        case 10: _t->moveDown(); break;
        case 11: _t->addFlyTo(); break;
        case 12: _t->addWait(); break;
        case 13: _t->addSoundCue(); break;
        case 14: _t->addPlacemark(); break;
        case 15: _t->addRemovePlacemark(); break;
        case 16: _t->addChangePlacemark(); break;
        case 17: _t->deleteSelected(); break;
        case 18: _t->updateDuration(); break;
        case 19: _t->finishAddingItem(); break;
        case 20: _t->stopLooping(); break;
        case 21: _t->d->openFile(); break;
        case 22: _t->d->createTour(); break;
        case 23: _t->d->saveTour(); break;
        case 24: _t->d->saveTourAs(); break;
        case 25: _t->d->captureTour(); break;
        case 26: _t->d->updateButtonsStates(); break;
        case 27: _t->d->mapCenterOn((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 28: _t->d->handlePlaybackProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TourWidget::*)(GeoDataFeature * )>(_a, &TourWidget::featureUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourWidget::*)(GeoDataContainer * , GeoDataFeature * , int )>(_a, &TourWidget::featureAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourWidget::*)(const GeoDataFeature * )>(_a, &TourWidget::featureRemoved, 2))
            return;
    }
}

const QMetaObject *Marble::TourWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::TourWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TourWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Marble::TourWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void Marble::TourWidget::featureUpdated(GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::TourWidget::featureAdded(GeoDataContainer * _t1, GeoDataFeature * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Marble::TourWidget::featureRemoved(const GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
