/********************************************************************************
** Form generated from reading UI file 'AprsConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APRSCONFIGWIDGET_H
#define UI_APRSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AprsConfigWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QTabWidget *tabWidget;
    QWidget *Display;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_3;
    QLineEdit *m_fadetime;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_5;
    QLineEdit *m_hidetime;
    QWidget *Internet;
    QVBoxLayout *verticalLayout;
    QGroupBox *m_informationGroupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *m_internetBox;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label;
    QLineEdit *m_serverName;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_2;
    QLineEdit *m_serverPort;
    QCheckBox *m_tcpipdump;
    QWidget *Device;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *m_serialBox;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_4;
    QLineEdit *m_ttyName;
    QCheckBox *m_ttydump;
    QWidget *tab;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_8;
    QCheckBox *m_useFile;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_6;
    QLineEdit *m_fileName;
    QCheckBox *m_filedump;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *AprsConfigWidget)
    {
        if (AprsConfigWidget->objectName().isEmpty())
            AprsConfigWidget->setObjectName("AprsConfigWidget");
        AprsConfigWidget->resize(364, 414);
        verticalLayout_3 = new QVBoxLayout(AprsConfigWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        tabWidget = new QTabWidget(AprsConfigWidget);
        tabWidget->setObjectName("tabWidget");
        Display = new QWidget();
        Display->setObjectName("Display");
        verticalLayout_6 = new QVBoxLayout(Display);
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_3 = new QLabel(Display);
        label_3->setObjectName("label_3");
        label_3->setMinimumSize(QSize(250, 0));

        horizontalLayout_6->addWidget(label_3);

        m_fadetime = new QLineEdit(Display);
        m_fadetime->setObjectName("m_fadetime");

        horizontalLayout_6->addWidget(m_fadetime);


        verticalLayout_6->addLayout(horizontalLayout_6);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        label_5 = new QLabel(Display);
        label_5->setObjectName("label_5");
        label_5->setMinimumSize(QSize(250, 0));

        horizontalLayout_8->addWidget(label_5);

        m_hidetime = new QLineEdit(Display);
        m_hidetime->setObjectName("m_hidetime");

        horizontalLayout_8->addWidget(m_hidetime);


        verticalLayout_6->addLayout(horizontalLayout_8);

        tabWidget->addTab(Display, QString());
        Internet = new QWidget();
        Internet->setObjectName("Internet");
        verticalLayout = new QVBoxLayout(Internet);
        verticalLayout->setObjectName("verticalLayout");
        m_informationGroupBox = new QGroupBox(Internet);
        m_informationGroupBox->setObjectName("m_informationGroupBox");
        verticalLayout_2 = new QVBoxLayout(m_informationGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_internetBox = new QCheckBox(m_informationGroupBox);
        m_internetBox->setObjectName("m_internetBox");
        m_internetBox->setChecked(true);

        verticalLayout_2->addWidget(m_internetBox);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label = new QLabel(m_informationGroupBox);
        label->setObjectName("label");
        label->setMinimumSize(QSize(50, 0));

        horizontalLayout_4->addWidget(label);

        m_serverName = new QLineEdit(m_informationGroupBox);
        m_serverName->setObjectName("m_serverName");

        horizontalLayout_4->addWidget(m_serverName);


        verticalLayout_2->addLayout(horizontalLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_2 = new QLabel(m_informationGroupBox);
        label_2->setObjectName("label_2");
        label_2->setMinimumSize(QSize(50, 0));

        horizontalLayout_5->addWidget(label_2);

        m_serverPort = new QLineEdit(m_informationGroupBox);
        m_serverPort->setObjectName("m_serverPort");

        horizontalLayout_5->addWidget(m_serverPort);


        verticalLayout_2->addLayout(horizontalLayout_5);

        m_tcpipdump = new QCheckBox(m_informationGroupBox);
        m_tcpipdump->setObjectName("m_tcpipdump");

        verticalLayout_2->addWidget(m_tcpipdump);


        verticalLayout->addWidget(m_informationGroupBox);

        tabWidget->addTab(Internet, QString());
        Device = new QWidget();
        Device->setObjectName("Device");
        verticalLayout_5 = new QVBoxLayout(Device);
        verticalLayout_5->setObjectName("verticalLayout_5");
        groupBox = new QGroupBox(Device);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        verticalLayout_4 = new QVBoxLayout(groupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        m_serialBox = new QCheckBox(groupBox);
        m_serialBox->setObjectName("m_serialBox");

        verticalLayout_4->addWidget(m_serialBox);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        label_4->setMinimumSize(QSize(50, 0));

        horizontalLayout_7->addWidget(label_4);

        m_ttyName = new QLineEdit(groupBox);
        m_ttyName->setObjectName("m_ttyName");

        horizontalLayout_7->addWidget(m_ttyName);


        verticalLayout_4->addLayout(horizontalLayout_7);

        m_ttydump = new QCheckBox(groupBox);
        m_ttydump->setObjectName("m_ttydump");

        verticalLayout_4->addWidget(m_ttydump);


        verticalLayout_5->addWidget(groupBox);

        tabWidget->addTab(Device, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_7 = new QVBoxLayout(tab);
        verticalLayout_7->setObjectName("verticalLayout_7");
        groupBox_2 = new QGroupBox(tab);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_8 = new QVBoxLayout(groupBox_2);
        verticalLayout_8->setObjectName("verticalLayout_8");
        m_useFile = new QCheckBox(groupBox_2);
        m_useFile->setObjectName("m_useFile");

        verticalLayout_8->addWidget(m_useFile);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");
        label_6->setMinimumSize(QSize(50, 0));

        horizontalLayout_9->addWidget(label_6);

        m_fileName = new QLineEdit(groupBox_2);
        m_fileName->setObjectName("m_fileName");

        horizontalLayout_9->addWidget(m_fileName);


        verticalLayout_8->addLayout(horizontalLayout_9);

        m_filedump = new QCheckBox(groupBox_2);
        m_filedump->setObjectName("m_filedump");

        verticalLayout_8->addWidget(m_filedump);


        verticalLayout_7->addWidget(groupBox_2);

        tabWidget->addTab(tab, QString());

        verticalLayout_3->addWidget(tabWidget);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        m_buttonBox = new QDialogButtonBox(AprsConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(m_buttonBox);


        retranslateUi(AprsConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, AprsConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, AprsConfigWidget, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AprsConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *AprsConfigWidget)
    {
        AprsConfigWidget->setWindowTitle(QCoreApplication::translate("AprsConfigWidget", "APRS Plugin", nullptr));
        label_3->setText(QCoreApplication::translate("AprsConfigWidget", "Fade data older than (minutes)", nullptr));
        m_fadetime->setText(QCoreApplication::translate("AprsConfigWidget", "10", nullptr));
        label_5->setText(QCoreApplication::translate("AprsConfigWidget", "Do not show data older than (minutes)", nullptr));
        m_hidetime->setText(QCoreApplication::translate("AprsConfigWidget", "10", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Display), QCoreApplication::translate("AprsConfigWidget", "Display", nullptr));
#if QT_CONFIG(tooltip)
        m_informationGroupBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        m_informationGroupBox->setTitle(QCoreApplication::translate("AprsConfigWidget", "APRS Data Sources", nullptr));
#if QT_CONFIG(tooltip)
        m_internetBox->setToolTip(QCoreApplication::translate("AprsConfigWidget", "Should information be gathered from the Internet APRS data source?", nullptr));
#endif // QT_CONFIG(tooltip)
        m_internetBox->setText(QCoreApplication::translate("AprsConfigWidget", "Collect data from an APRS Internet server", nullptr));
        label->setText(QCoreApplication::translate("AprsConfigWidget", "Server", nullptr));
        m_serverName->setText(QCoreApplication::translate("AprsConfigWidget", "rotate.aprs.net", nullptr));
        label_2->setText(QCoreApplication::translate("AprsConfigWidget", "Port", nullptr));
        m_serverPort->setText(QCoreApplication::translate("AprsConfigWidget", "10253", nullptr));
        m_tcpipdump->setText(QCoreApplication::translate("AprsConfigWidget", "Dump TCP/IP records to the debug stream", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Internet), QCoreApplication::translate("AprsConfigWidget", "Internet", nullptr));
        groupBox->setTitle(QCoreApplication::translate("AprsConfigWidget", "TNC Terminal Port", nullptr));
#if QT_CONFIG(tooltip)
        m_serialBox->setToolTip(QCoreApplication::translate("AprsConfigWidget", "Should information be gathered from a serial port?", nullptr));
#endif // QT_CONFIG(tooltip)
        m_serialBox->setText(QCoreApplication::translate("AprsConfigWidget", "Collect data from a serial TNC (In Text Mode)", nullptr));
        label_4->setText(QCoreApplication::translate("AprsConfigWidget", "TTY", nullptr));
        m_ttyName->setText(QCoreApplication::translate("AprsConfigWidget", "/dev/ttyUSB0", nullptr));
        m_ttydump->setText(QCoreApplication::translate("AprsConfigWidget", "Dump TTY records to the debug stream", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Device), QCoreApplication::translate("AprsConfigWidget", "Device", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("AprsConfigWidget", "File", nullptr));
#if QT_CONFIG(tooltip)
        m_useFile->setToolTip(QCoreApplication::translate("AprsConfigWidget", "Should information be gathered from a file?", nullptr));
#endif // QT_CONFIG(tooltip)
        m_useFile->setText(QCoreApplication::translate("AprsConfigWidget", "Collect data from a file", nullptr));
        label_6->setText(QCoreApplication::translate("AprsConfigWidget", "File", nullptr));
        m_fileName->setText(QString());
        m_filedump->setText(QCoreApplication::translate("AprsConfigWidget", "Dump file records to the debug stream", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("AprsConfigWidget", "File", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AprsConfigWidget: public Ui_AprsConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_APRSCONFIGWIDGET_H
