/********************************************************************************
** Form generated from reading UI file 'FileViewWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILEVIEWWIDGET_H
#define UI_FILEVIEWWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_FileViewWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTreeView *m_treeView;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QPushButton *m_saveButton;
    QPushButton *m_closeButton;

    void setupUi(QWidget *FileViewWidget)
    {
        if (FileViewWidget->objectName().isEmpty())
            FileViewWidget->setObjectName("FileViewWidget");
        FileViewWidget->resize(229, 282);
        verticalLayout = new QVBoxLayout(FileViewWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_treeView = new QTreeView(FileViewWidget);
        m_treeView->setObjectName("m_treeView");
        m_treeView->setEditTriggers(QAbstractItemView::EditKeyPressed);
        m_treeView->setIconSize(QSize(16, 16));
        m_treeView->setTextElideMode(Qt::ElideLeft);
        m_treeView->header()->setCascadingSectionResizes(false);
        m_treeView->header()->setDefaultSectionSize(200);
        m_treeView->header()->setStretchLastSection(false);

        verticalLayout->addWidget(m_treeView);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        m_saveButton = new QPushButton(FileViewWidget);
        m_saveButton->setObjectName("m_saveButton");
        m_saveButton->setEnabled(false);

        hboxLayout->addWidget(m_saveButton);

        m_closeButton = new QPushButton(FileViewWidget);
        m_closeButton->setObjectName("m_closeButton");
        m_closeButton->setEnabled(false);

        hboxLayout->addWidget(m_closeButton);


        verticalLayout->addLayout(hboxLayout);


        retranslateUi(FileViewWidget);

        QMetaObject::connectSlotsByName(FileViewWidget);
    } // setupUi

    void retranslateUi(QWidget *FileViewWidget)
    {
        FileViewWidget->setWindowTitle(QCoreApplication::translate("FileViewWidget", "File View", nullptr));
        m_saveButton->setText(QCoreApplication::translate("FileViewWidget", "&Save", nullptr));
        m_closeButton->setText(QCoreApplication::translate("FileViewWidget", "&Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FileViewWidget: public Ui_FileViewWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FILEVIEWWIDGET_H
