/********************************************************************************
** Form generated from reading UI file 'WeatherConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WEATHERCONFIGWIDGET_H
#define UI_WEATHERCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_WeatherConfigWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *m_informationGroupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *m_weatherConditionBox;
    QCheckBox *m_temperatureBox;
    QCheckBox *m_windDirectionBox;
    QCheckBox *m_windSpeedBox;
    QGroupBox *m_unitsGroupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *m_temperatureLabel;
    QComboBox *m_temperatureComboBox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *m_windSpeedLabel;
    QComboBox *m_windSpeedComboBox;
    QHBoxLayout *horizontalLayout_3;
    QLabel *m_pressureLabel;
    QComboBox *m_pressureComboBox;
    QGroupBox *m_miscGroupBox;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *m_onlyFavoritesBox;
    QHBoxLayout *horizontalLayout_4;
    QLabel *m_updateIntervalLabel;
    QSpinBox *m_updateIntervalBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *WeatherConfigWidget)
    {
        if (WeatherConfigWidget->objectName().isEmpty())
            WeatherConfigWidget->setObjectName("WeatherConfigWidget");
        WeatherConfigWidget->resize(364, 414);
        verticalLayout_3 = new QVBoxLayout(WeatherConfigWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_informationGroupBox = new QGroupBox(WeatherConfigWidget);
        m_informationGroupBox->setObjectName("m_informationGroupBox");
        verticalLayout_2 = new QVBoxLayout(m_informationGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_weatherConditionBox = new QCheckBox(m_informationGroupBox);
        m_weatherConditionBox->setObjectName("m_weatherConditionBox");

        verticalLayout_2->addWidget(m_weatherConditionBox);

        m_temperatureBox = new QCheckBox(m_informationGroupBox);
        m_temperatureBox->setObjectName("m_temperatureBox");

        verticalLayout_2->addWidget(m_temperatureBox);

        m_windDirectionBox = new QCheckBox(m_informationGroupBox);
        m_windDirectionBox->setObjectName("m_windDirectionBox");

        verticalLayout_2->addWidget(m_windDirectionBox);

        m_windSpeedBox = new QCheckBox(m_informationGroupBox);
        m_windSpeedBox->setObjectName("m_windSpeedBox");

        verticalLayout_2->addWidget(m_windSpeedBox);


        verticalLayout_3->addWidget(m_informationGroupBox);

        m_unitsGroupBox = new QGroupBox(WeatherConfigWidget);
        m_unitsGroupBox->setObjectName("m_unitsGroupBox");
        verticalLayout = new QVBoxLayout(m_unitsGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_temperatureLabel = new QLabel(m_unitsGroupBox);
        m_temperatureLabel->setObjectName("m_temperatureLabel");

        horizontalLayout->addWidget(m_temperatureLabel);

        m_temperatureComboBox = new QComboBox(m_unitsGroupBox);
        m_temperatureComboBox->addItem(QString());
        m_temperatureComboBox->addItem(QString());
        m_temperatureComboBox->setObjectName("m_temperatureComboBox");

        horizontalLayout->addWidget(m_temperatureComboBox);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_windSpeedLabel = new QLabel(m_unitsGroupBox);
        m_windSpeedLabel->setObjectName("m_windSpeedLabel");

        horizontalLayout_2->addWidget(m_windSpeedLabel);

        m_windSpeedComboBox = new QComboBox(m_unitsGroupBox);
        m_windSpeedComboBox->addItem(QString());
        m_windSpeedComboBox->addItem(QString());
        m_windSpeedComboBox->addItem(QString());
        m_windSpeedComboBox->addItem(QString());
        m_windSpeedComboBox->addItem(QString());
        m_windSpeedComboBox->setObjectName("m_windSpeedComboBox");

        horizontalLayout_2->addWidget(m_windSpeedComboBox);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_pressureLabel = new QLabel(m_unitsGroupBox);
        m_pressureLabel->setObjectName("m_pressureLabel");

        horizontalLayout_3->addWidget(m_pressureLabel);

        m_pressureComboBox = new QComboBox(m_unitsGroupBox);
        m_pressureComboBox->addItem(QString());
        m_pressureComboBox->addItem(QString());
        m_pressureComboBox->addItem(QString());
        m_pressureComboBox->addItem(QString());
        m_pressureComboBox->addItem(QString());
        m_pressureComboBox->setObjectName("m_pressureComboBox");

        horizontalLayout_3->addWidget(m_pressureComboBox);


        verticalLayout->addLayout(horizontalLayout_3);


        verticalLayout_3->addWidget(m_unitsGroupBox);

        m_miscGroupBox = new QGroupBox(WeatherConfigWidget);
        m_miscGroupBox->setObjectName("m_miscGroupBox");
        verticalLayout_4 = new QVBoxLayout(m_miscGroupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        m_onlyFavoritesBox = new QCheckBox(m_miscGroupBox);
        m_onlyFavoritesBox->setObjectName("m_onlyFavoritesBox");

        verticalLayout_4->addWidget(m_onlyFavoritesBox);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        m_updateIntervalLabel = new QLabel(m_miscGroupBox);
        m_updateIntervalLabel->setObjectName("m_updateIntervalLabel");

        horizontalLayout_4->addWidget(m_updateIntervalLabel);

        m_updateIntervalBox = new QSpinBox(m_miscGroupBox);
        m_updateIntervalBox->setObjectName("m_updateIntervalBox");
        m_updateIntervalBox->setMinimum(1);
        m_updateIntervalBox->setMaximum(24);

        horizontalLayout_4->addWidget(m_updateIntervalBox);


        verticalLayout_4->addLayout(horizontalLayout_4);


        verticalLayout_3->addWidget(m_miscGroupBox);

        verticalSpacer = new QSpacerItem(20, 80, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        m_buttonBox = new QDialogButtonBox(WeatherConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(m_buttonBox);


        retranslateUi(WeatherConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, WeatherConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, WeatherConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(WeatherConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *WeatherConfigWidget)
    {
        WeatherConfigWidget->setWindowTitle(QCoreApplication::translate("WeatherConfigWidget", "Configure Weather Plugin", nullptr));
#if QT_CONFIG(tooltip)
        m_informationGroupBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        m_informationGroupBox->setTitle(QCoreApplication::translate("WeatherConfigWidget", "Information", nullptr));
#if QT_CONFIG(tooltip)
        m_weatherConditionBox->setToolTip(QCoreApplication::translate("WeatherConfigWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\\np, li { white-space: pre-wrap; }\\n</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Here you can choose if you want the weather condition to be shown (for example, clouds or clear sky.) Marble will only show the condition if this information is available.</p></body></html>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_weatherConditionBox->setText(QCoreApplication::translate("WeatherConfigWidget", "Weather condition", nullptr));
#if QT_CONFIG(tooltip)
        m_temperatureBox->setToolTip(QCoreApplication::translate("WeatherConfigWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\\np, li { white-space: pre-wrap; }\\n</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Selects if you want the temperature to be shown. The temperature will only be shown for the stations it is available for.</p></body></html>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_temperatureBox->setText(QCoreApplication::translate("WeatherConfigWidget", "Temperature", nullptr));
#if QT_CONFIG(tooltip)
        m_windDirectionBox->setToolTip(QCoreApplication::translate("WeatherConfigWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\\np, li { white-space: pre-wrap; }\\n</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Select if you want the wind direction to be shown. The wind direction will only be shown if it is available for the particular station.</p></body></html>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_windDirectionBox->setText(QCoreApplication::translate("WeatherConfigWidget", "Wind direction", nullptr));
#if QT_CONFIG(tooltip)
        m_windSpeedBox->setToolTip(QCoreApplication::translate("WeatherConfigWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\\np, li { white-space: pre-wrap; }\\n</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Select if you want the wind speed to be shown. The wind speed will only be shown if it is available for the particular station.</p></body></html>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_windSpeedBox->setText(QCoreApplication::translate("WeatherConfigWidget", "Wind speed", nullptr));
        m_unitsGroupBox->setTitle(QCoreApplication::translate("WeatherConfigWidget", "Units", nullptr));
        m_temperatureLabel->setText(QCoreApplication::translate("WeatherConfigWidget", "Temperature", nullptr));
        m_temperatureComboBox->setItemText(0, QCoreApplication::translate("WeatherConfigWidget", "Celsius", nullptr));
        m_temperatureComboBox->setItemText(1, QCoreApplication::translate("WeatherConfigWidget", "Fahrenheit", nullptr));

#if QT_CONFIG(tooltip)
        m_temperatureComboBox->setToolTip(QCoreApplication::translate("WeatherConfigWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\\np, li { white-space: pre-wrap; }\\n</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The unit used to measure the temperature.</p></body></html>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_windSpeedLabel->setText(QCoreApplication::translate("WeatherConfigWidget", "Wind speed", nullptr));
        m_windSpeedComboBox->setItemText(0, QCoreApplication::translate("WeatherConfigWidget", "Kilometers per hour", nullptr));
        m_windSpeedComboBox->setItemText(1, QCoreApplication::translate("WeatherConfigWidget", "Miles per hour", nullptr));
        m_windSpeedComboBox->setItemText(2, QCoreApplication::translate("WeatherConfigWidget", "Meters per second", nullptr));
        m_windSpeedComboBox->setItemText(3, QCoreApplication::translate("WeatherConfigWidget", "Knots", nullptr));
        m_windSpeedComboBox->setItemText(4, QCoreApplication::translate("WeatherConfigWidget", "Beaufort", nullptr));

#if QT_CONFIG(tooltip)
        m_windSpeedComboBox->setToolTip(QCoreApplication::translate("WeatherConfigWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\\np, li { white-space: pre-wrap; }\\n</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The unit used to measure the wind speed.</p></body></html>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_pressureLabel->setText(QCoreApplication::translate("WeatherConfigWidget", "Pressure", nullptr));
        m_pressureComboBox->setItemText(0, QCoreApplication::translate("WeatherConfigWidget", "Hecto Pascals", nullptr));
        m_pressureComboBox->setItemText(1, QCoreApplication::translate("WeatherConfigWidget", "Kilo Pascals", nullptr));
        m_pressureComboBox->setItemText(2, QCoreApplication::translate("WeatherConfigWidget", "Bars", nullptr));
        m_pressureComboBox->setItemText(3, QCoreApplication::translate("WeatherConfigWidget", "Millimeters of Mercury", nullptr));
        m_pressureComboBox->setItemText(4, QCoreApplication::translate("WeatherConfigWidget", "Inches of Mercury", nullptr));

#if QT_CONFIG(tooltip)
        m_pressureComboBox->setToolTip(QCoreApplication::translate("WeatherConfigWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\\np, li { white-space: pre-wrap; }\\n</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The unit used to measure the air pressure.</p></body></html>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_miscGroupBox->setTitle(QCoreApplication::translate("WeatherConfigWidget", "Miscellaneous", nullptr));
        m_onlyFavoritesBox->setText(QCoreApplication::translate("WeatherConfigWidget", "Show only favorite items", nullptr));
        m_updateIntervalLabel->setText(QCoreApplication::translate("WeatherConfigWidget", "Weather update interval", nullptr));
        m_updateIntervalBox->setSuffix(QCoreApplication::translate("WeatherConfigWidget", " hours", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WeatherConfigWidget: public Ui_WeatherConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WEATHERCONFIGWIDGET_H
