/****************************************************************************
** Meta object code from reading C++ file 'CloudSyncManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/cloudsync/CloudSyncManager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CloudSyncManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble16CloudSyncManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::CloudSyncManager::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble16CloudSyncManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::CloudSyncManager",
        "workOfflineChanged",
        "",
        "workOffline",
        "syncEnabledChanged",
        "enabled",
        "owncloudUsernameChanged",
        "username",
        "owncloudPasswordChanged",
        "password",
        "owncloudServerChanged",
        "server",
        "statusChanged",
        "status",
        "apiUrlChanged",
        "QUrl",
        "url",
        "routeSyncManagerChanged",
        "bookmarkSyncManagerChanged",
        "syncEnabled",
        "owncloudUsername",
        "owncloudPassword",
        "owncloudServer",
        "apiUrl",
        "bookmarkSyncManager",
        "BookmarkSyncManager*",
        "routeSyncManager",
        "RouteSyncManager*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'workOfflineChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'syncEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'owncloudUsernameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'owncloudPasswordChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'owncloudServerChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'apiUrlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'routeSyncManagerChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bookmarkSyncManagerChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'workOffline'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'syncEnabled'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'owncloudUsername'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'owncloudPassword'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'owncloudServer'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'apiUrl'
        QtMocHelpers::PropertyData<QUrl>(23, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'bookmarkSyncManager'
        QtMocHelpers::PropertyData<BookmarkSyncManager*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'routeSyncManager'
        QtMocHelpers::PropertyData<RouteSyncManager*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CloudSyncManager, qt_meta_tag_ZN6Marble16CloudSyncManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::CloudSyncManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16CloudSyncManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16CloudSyncManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble16CloudSyncManagerE_t>.metaTypes,
    nullptr
} };

void Marble::CloudSyncManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CloudSyncManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->workOfflineChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->syncEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->owncloudUsernameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->owncloudPasswordChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->owncloudServerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->apiUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->routeSyncManagerChanged(); break;
        case 8: _t->bookmarkSyncManagerChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)(bool )>(_a, &CloudSyncManager::workOfflineChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)(bool )>(_a, &CloudSyncManager::syncEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)(const QString & )>(_a, &CloudSyncManager::owncloudUsernameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)(const QString & )>(_a, &CloudSyncManager::owncloudPasswordChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)(const QString & )>(_a, &CloudSyncManager::owncloudServerChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)(const QString & )>(_a, &CloudSyncManager::statusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)(const QUrl & )>(_a, &CloudSyncManager::apiUrlChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)()>(_a, &CloudSyncManager::routeSyncManagerChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CloudSyncManager::*)()>(_a, &CloudSyncManager::bookmarkSyncManagerChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->workOffline(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSyncEnabled(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->owncloudUsername(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->owncloudPassword(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->owncloudServer(); break;
        case 5: *reinterpret_cast<QUrl*>(_v) = _t->apiUrl(); break;
        case 6: *reinterpret_cast<BookmarkSyncManager**>(_v) = _t->bookmarkSyncManager(); break;
        case 7: *reinterpret_cast<RouteSyncManager**>(_v) = _t->routeSyncManager(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWorkOffline(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSyncEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setOwncloudUsername(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setOwncloudPassword(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setOwncloudServer(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::CloudSyncManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::CloudSyncManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16CloudSyncManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::CloudSyncManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Marble::CloudSyncManager::workOfflineChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::CloudSyncManager::syncEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::CloudSyncManager::owncloudUsernameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::CloudSyncManager::owncloudPasswordChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::CloudSyncManager::owncloudServerChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::CloudSyncManager::statusChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Marble::CloudSyncManager::apiUrlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Marble::CloudSyncManager::routeSyncManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Marble::CloudSyncManager::bookmarkSyncManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
