/****************************************************************************
** Meta object code from reading C++ file 'AbstractWeatherService.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/plugins/render/weather/AbstractWeatherService.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractWeatherService.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble22AbstractWeatherServiceE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::AbstractWeatherService::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble22AbstractWeatherServiceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::AbstractWeatherService",
        "requestedDownload",
        "",
        "QUrl",
        "url",
        "type",
        "AbstractDataPluginItem*",
        "item",
        "createdItems",
        "QList<AbstractDataPluginItem*>",
        "items",
        "downloadDescriptionFileRequested",
        "setFavoriteItems",
        "favorite",
        "favoriteItems",
        "getAdditionalItems",
        "GeoDataLatLonAltBox",
        "box",
        "number",
        "getItem",
        "id",
        "parseFile",
        "file"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestedDownload'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &, AbstractDataPluginItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'createdItems'
        QtMocHelpers::SignalData<void(const QList<AbstractDataPluginItem*> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'downloadDescriptionFileRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'setFavoriteItems'
        QtMocHelpers::SlotData<void(const QStringList &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 13 },
        }}),
        // Slot 'favoriteItems'
        QtMocHelpers::SlotData<QStringList() const>(14, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'getAdditionalItems'
        QtMocHelpers::SlotData<void(const GeoDataLatLonAltBox &, qint32)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'getAdditionalItems'
        QtMocHelpers::SlotData<void(const GeoDataLatLonAltBox &)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'getItem'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'parseFile'
        QtMocHelpers::SlotData<void(const QByteArray &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractWeatherService, qt_meta_tag_ZN6Marble22AbstractWeatherServiceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::AbstractWeatherService::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble22AbstractWeatherServiceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble22AbstractWeatherServiceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble22AbstractWeatherServiceE_t>.metaTypes,
    nullptr
} };

void Marble::AbstractWeatherService::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractWeatherService *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestedDownload((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<AbstractDataPluginItem*>>(_a[3]))); break;
        case 1: _t->createdItems((*reinterpret_cast<std::add_pointer_t<QList<AbstractDataPluginItem*>>>(_a[1]))); break;
        case 2: _t->downloadDescriptionFileRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->setFavoriteItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: { QStringList _r = _t->favoriteItems();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->getAdditionalItems((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonAltBox>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 6: _t->getAdditionalItems((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonAltBox>>(_a[1]))); break;
        case 7: _t->getItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->parseFile((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractDataPluginItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<AbstractDataPluginItem*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractWeatherService::*)(const QUrl & , const QString & , AbstractDataPluginItem * )>(_a, &AbstractWeatherService::requestedDownload, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWeatherService::*)(const QList<AbstractDataPluginItem*> & )>(_a, &AbstractWeatherService::createdItems, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWeatherService::*)(const QUrl & )>(_a, &AbstractWeatherService::downloadDescriptionFileRequested, 2))
            return;
    }
}

const QMetaObject *Marble::AbstractWeatherService::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::AbstractWeatherService::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble22AbstractWeatherServiceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::AbstractWeatherService::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Marble::AbstractWeatherService::requestedDownload(const QUrl & _t1, const QString & _t2, AbstractDataPluginItem * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Marble::AbstractWeatherService::createdItems(const QList<AbstractDataPluginItem*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::AbstractWeatherService::downloadDescriptionFileRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
