/****************************************************************************
** Meta object code from reading C++ file 'MergeItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/cloudsync/MergeItem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MergeItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble9MergeItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MergeItem::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble9MergeItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MergeItem",
        "pathAChanged",
        "",
        "pathBChanged",
        "placemarkAChanged",
        "placemarkBChanged",
        "nameAChanged",
        "nameBChanged",
        "descriptionAChanged",
        "descriptionBChanged",
        "actionAChanged",
        "actionBChanged",
        "resolutionChanged",
        "pathA",
        "pathB",
        "placemarkA",
        "GeoDataPlacemark",
        "placemarkB",
        "nameA",
        "nameB",
        "descriptionA",
        "descriptionB",
        "actionA",
        "MergeItem::Action",
        "actionB",
        "resolution",
        "MergeItem::Resolution"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pathAChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pathBChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'placemarkAChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'placemarkBChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameAChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameBChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionAChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionBChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionAChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionBChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resolutionChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pathA'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'pathB'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'placemarkA'
        QtMocHelpers::PropertyData<GeoDataPlacemark>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'placemarkB'
        QtMocHelpers::PropertyData<GeoDataPlacemark>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'nameA'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'nameB'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'descriptionA'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'descriptionB'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'actionA'
        QtMocHelpers::PropertyData<MergeItem::Action>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'actionB'
        QtMocHelpers::PropertyData<MergeItem::Action>(24, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'resolution'
        QtMocHelpers::PropertyData<MergeItem::Resolution>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MergeItem, qt_meta_tag_ZN6Marble9MergeItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MergeItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9MergeItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9MergeItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble9MergeItemE_t>.metaTypes,
    nullptr
} };

void Marble::MergeItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MergeItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pathAChanged(); break;
        case 1: _t->pathBChanged(); break;
        case 2: _t->placemarkAChanged(); break;
        case 3: _t->placemarkBChanged(); break;
        case 4: _t->nameAChanged(); break;
        case 5: _t->nameBChanged(); break;
        case 6: _t->descriptionAChanged(); break;
        case 7: _t->descriptionBChanged(); break;
        case 8: _t->actionAChanged(); break;
        case 9: _t->actionBChanged(); break;
        case 10: _t->resolutionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::pathAChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::pathBChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::placemarkAChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::placemarkBChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::nameAChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::nameBChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::descriptionAChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::descriptionBChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::actionAChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::actionBChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeItem::*)()>(_a, &MergeItem::resolutionChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->pathA(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->pathB(); break;
        case 2: *reinterpret_cast<GeoDataPlacemark*>(_v) = _t->placemarkA(); break;
        case 3: *reinterpret_cast<GeoDataPlacemark*>(_v) = _t->placemarkB(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->nameA(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->nameB(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->descriptionA(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->descriptionB(); break;
        case 8: *reinterpret_cast<MergeItem::Action*>(_v) = _t->actionA(); break;
        case 9: *reinterpret_cast<MergeItem::Action*>(_v) = _t->actionB(); break;
        case 10: *reinterpret_cast<MergeItem::Resolution*>(_v) = _t->resolution(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPathA(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPathB(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setPlacemarkA(*reinterpret_cast<GeoDataPlacemark*>(_v)); break;
        case 3: _t->setPlacemarkB(*reinterpret_cast<GeoDataPlacemark*>(_v)); break;
        case 8: _t->setActionA(*reinterpret_cast<MergeItem::Action*>(_v)); break;
        case 9: _t->setActionB(*reinterpret_cast<MergeItem::Action*>(_v)); break;
        case 10: _t->setResolution(*reinterpret_cast<MergeItem::Resolution*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::MergeItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MergeItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9MergeItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::MergeItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Marble::MergeItem::pathAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::MergeItem::pathBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::MergeItem::placemarkAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::MergeItem::placemarkBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::MergeItem::nameAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Marble::MergeItem::nameBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Marble::MergeItem::descriptionAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Marble::MergeItem::descriptionBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Marble::MergeItem::actionAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Marble::MergeItem::actionBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Marble::MergeItem::resolutionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
