/****************************************************************************
** Meta object code from reading C++ file 'AnimatedUpdateTrack.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.07.80/src/lib/marble/AnimatedUpdateTrack.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AnimatedUpdateTrack.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble19AnimatedUpdateTrackE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::AnimatedUpdateTrack::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble19AnimatedUpdateTrackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::AnimatedUpdateTrack",
        "balloonHidden",
        "",
        "balloonShown",
        "GeoDataPlacemark*",
        "updated",
        "GeoDataFeature*",
        "added",
        "GeoDataContainer*",
        "parent",
        "feature",
        "row",
        "removed",
        "const GeoDataFeature*",
        "playSlot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'balloonHidden'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'balloonShown'
        QtMocHelpers::SignalData<void(GeoDataPlacemark *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'updated'
        QtMocHelpers::SignalData<void(GeoDataFeature *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'added'
        QtMocHelpers::SignalData<void(GeoDataContainer *, GeoDataFeature *, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 6, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void(const GeoDataFeature *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 10 },
        }}),
        // Slot 'playSlot'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AnimatedUpdateTrack, qt_meta_tag_ZN6Marble19AnimatedUpdateTrackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::AnimatedUpdateTrack::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19AnimatedUpdateTrackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19AnimatedUpdateTrackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble19AnimatedUpdateTrackE_t>.metaTypes,
    nullptr
} };

void Marble::AnimatedUpdateTrack::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AnimatedUpdateTrack *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->balloonHidden(); break;
        case 1: _t->balloonShown((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark*>>(_a[1]))); break;
        case 2: _t->updated((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1]))); break;
        case 3: _t->added((*reinterpret_cast<std::add_pointer_t<GeoDataContainer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->removed((*reinterpret_cast<std::add_pointer_t<const GeoDataFeature*>>(_a[1]))); break;
        case 5: _t->playSlot(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AnimatedUpdateTrack::*)()>(_a, &AnimatedUpdateTrack::balloonHidden, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnimatedUpdateTrack::*)(GeoDataPlacemark * )>(_a, &AnimatedUpdateTrack::balloonShown, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnimatedUpdateTrack::*)(GeoDataFeature * )>(_a, &AnimatedUpdateTrack::updated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnimatedUpdateTrack::*)(GeoDataContainer * , GeoDataFeature * , int )>(_a, &AnimatedUpdateTrack::added, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnimatedUpdateTrack::*)(const GeoDataFeature * )>(_a, &AnimatedUpdateTrack::removed, 4))
            return;
    }
}

const QMetaObject *Marble::AnimatedUpdateTrack::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::AnimatedUpdateTrack::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble19AnimatedUpdateTrackE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::AnimatedUpdateTrack::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Marble::AnimatedUpdateTrack::balloonHidden()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::AnimatedUpdateTrack::balloonShown(GeoDataPlacemark * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::AnimatedUpdateTrack::updated(GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::AnimatedUpdateTrack::added(GeoDataContainer * _t1, GeoDataFeature * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Marble::AnimatedUpdateTrack::removed(const GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
