/********************************************************************************
** Form generated from reading UI file 'RoutingWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ROUTINGWIDGET_H
#define UI_ROUTINGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_RoutingWidget
{
public:
    QVBoxLayout *routingLayout;
    QScrollArea *scrollArea;
    QWidget *inputListWidget;
    QVBoxLayout *inputLayout;
    QHBoxLayout *horizontalLayout;
    QComboBox *routingProfileComboBox;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *searchButton;
    QSpacerItem *horizontalSpacer_2;
    QLabel *resultLabel;
    QPushButton *showInstructionsButton;
    QHBoxLayout *toolBarLayout;
    QListView *directionsListView;
    QHBoxLayout *horizontalLayout_3;
    QComboBox *routeComboBox;

    void setupUi(QWidget *RoutingWidget)
    {
        if (RoutingWidget->objectName().isEmpty())
            RoutingWidget->setObjectName("RoutingWidget");
        RoutingWidget->resize(284, 414);
        routingLayout = new QVBoxLayout(RoutingWidget);
        routingLayout->setObjectName("routingLayout");
        scrollArea = new QScrollArea(RoutingWidget);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        inputListWidget = new QWidget();
        inputListWidget->setObjectName("inputListWidget");
        inputLayout = new QVBoxLayout(inputListWidget);
        inputLayout->setSpacing(0);
        inputLayout->setContentsMargins(0, 0, 0, 0);
        inputLayout->setObjectName("inputLayout");
        inputLayout->setAlignment(Qt::AlignTop);
        scrollArea->setWidget(inputListWidget);

        routingLayout->addWidget(scrollArea);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        routingProfileComboBox = new QComboBox(RoutingWidget);
        routingProfileComboBox->addItem(QString());
        routingProfileComboBox->addItem(QString());
        routingProfileComboBox->addItem(QString());
        routingProfileComboBox->addItem(QString());
        routingProfileComboBox->setObjectName("routingProfileComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(routingProfileComboBox->sizePolicy().hasHeightForWidth());
        routingProfileComboBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(routingProfileComboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        routingLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        searchButton = new QPushButton(RoutingWidget);
        searchButton->setObjectName("searchButton");

        horizontalLayout_2->addWidget(searchButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        resultLabel = new QLabel(RoutingWidget);
        resultLabel->setObjectName("resultLabel");

        horizontalLayout_2->addWidget(resultLabel);

        showInstructionsButton = new QPushButton(RoutingWidget);
        showInstructionsButton->setObjectName("showInstructionsButton");
        showInstructionsButton->setCheckable(false);

        horizontalLayout_2->addWidget(showInstructionsButton);


        routingLayout->addLayout(horizontalLayout_2);

        toolBarLayout = new QHBoxLayout();
        toolBarLayout->setObjectName("toolBarLayout");

        routingLayout->addLayout(toolBarLayout);

        directionsListView = new QListView(RoutingWidget);
        directionsListView->setObjectName("directionsListView");
        directionsListView->setMinimumSize(QSize(0, 0));
        directionsListView->setAlternatingRowColors(true);
        directionsListView->setResizeMode(QListView::Adjust);
        directionsListView->setWordWrap(true);

        routingLayout->addWidget(directionsListView);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        routeComboBox = new QComboBox(RoutingWidget);
        routeComboBox->setObjectName("routeComboBox");

        horizontalLayout_3->addWidget(routeComboBox);


        routingLayout->addLayout(horizontalLayout_3);


        retranslateUi(RoutingWidget);

        QMetaObject::connectSlotsByName(RoutingWidget);
    } // setupUi

    void retranslateUi(QWidget *RoutingWidget)
    {
        routingProfileComboBox->setItemText(0, QCoreApplication::translate("RoutingWidget", "Car (fastest)", nullptr));
        routingProfileComboBox->setItemText(1, QCoreApplication::translate("RoutingWidget", "Car (shortest)", nullptr));
        routingProfileComboBox->setItemText(2, QCoreApplication::translate("RoutingWidget", "Bicycle", nullptr));
        routingProfileComboBox->setItemText(3, QCoreApplication::translate("RoutingWidget", "Pedestrian", nullptr));

        searchButton->setText(QCoreApplication::translate("RoutingWidget", "Search", nullptr));
        resultLabel->setText(QCoreApplication::translate("RoutingWidget", "No results.", nullptr));
        showInstructionsButton->setText(QCoreApplication::translate("RoutingWidget", "Show Details", nullptr));
#if QT_CONFIG(tooltip)
        routeComboBox->setToolTip(QCoreApplication::translate("RoutingWidget", "Choose alternative routes", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)RoutingWidget;
    } // retranslateUi

};

namespace Ui {
    class RoutingWidget: public Ui_RoutingWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ROUTINGWIDGET_H
