/********************************************************************************
** Form generated from reading UI file 'AddLinkDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDLINKDIALOG_H
#define UI_ADDLINKDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_UiAddLinkDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *m_urlLabel;
    QLineEdit *m_url;
    QLabel *m_nameLabel;
    QLineEdit *m_name;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UiAddLinkDialog)
    {
        if (UiAddLinkDialog->objectName().isEmpty())
            UiAddLinkDialog->setObjectName("UiAddLinkDialog");
        UiAddLinkDialog->resize(350, 72);
        verticalLayout = new QVBoxLayout(UiAddLinkDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_urlLabel = new QLabel(UiAddLinkDialog);
        m_urlLabel->setObjectName("m_urlLabel");

        horizontalLayout->addWidget(m_urlLabel);

        m_url = new QLineEdit(UiAddLinkDialog);
        m_url->setObjectName("m_url");

        horizontalLayout->addWidget(m_url);

        m_nameLabel = new QLabel(UiAddLinkDialog);
        m_nameLabel->setObjectName("m_nameLabel");

        horizontalLayout->addWidget(m_nameLabel);

        m_name = new QLineEdit(UiAddLinkDialog);
        m_name->setObjectName("m_name");

        horizontalLayout->addWidget(m_name);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(UiAddLinkDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(UiAddLinkDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UiAddLinkDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(UiAddLinkDialog);
    } // setupUi

    void retranslateUi(QDialog *UiAddLinkDialog)
    {
        UiAddLinkDialog->setWindowTitle(QCoreApplication::translate("UiAddLinkDialog", "Add link", nullptr));
        m_urlLabel->setText(QCoreApplication::translate("UiAddLinkDialog", "URL:", nullptr));
        m_nameLabel->setText(QCoreApplication::translate("UiAddLinkDialog", "Name:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UiAddLinkDialog: public Ui_UiAddLinkDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDLINKDIALOG_H
