/********************************************************************************
** Form generated from reading UI file 'OpenRouteServiceConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENROUTESERVICECONFIGWIDGET_H
#define UI_OPENROUTESERVICECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRouteServiceConfigWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *preference;
    QCheckBox *noMotorways;
    QCheckBox *noTollways;
    QCheckBox *noFerries;

    void setupUi(QWidget *OpenRouteServiceConfigWidget)
    {
        if (OpenRouteServiceConfigWidget->objectName().isEmpty())
            OpenRouteServiceConfigWidget->setObjectName("OpenRouteServiceConfigWidget");
        OpenRouteServiceConfigWidget->resize(339, 150);
        formLayout = new QFormLayout(OpenRouteServiceConfigWidget);
        formLayout->setObjectName("formLayout");
        label = new QLabel(OpenRouteServiceConfigWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        preference = new QComboBox(OpenRouteServiceConfigWidget);
        preference->setObjectName("preference");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, preference);

        noMotorways = new QCheckBox(OpenRouteServiceConfigWidget);
        noMotorways->setObjectName("noMotorways");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, noMotorways);

        noTollways = new QCheckBox(OpenRouteServiceConfigWidget);
        noTollways->setObjectName("noTollways");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, noTollways);

        noFerries = new QCheckBox(OpenRouteServiceConfigWidget);
        noFerries->setObjectName("noFerries");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, noFerries);


        retranslateUi(OpenRouteServiceConfigWidget);

        QMetaObject::connectSlotsByName(OpenRouteServiceConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *OpenRouteServiceConfigWidget)
    {
        label->setText(QCoreApplication::translate("OpenRouteServiceConfigWidget", "Preference:", nullptr));
        noMotorways->setText(QCoreApplication::translate("OpenRouteServiceConfigWidget", "Avoid motorways", nullptr));
        noTollways->setText(QCoreApplication::translate("OpenRouteServiceConfigWidget", "Avoid tollways", nullptr));
        noFerries->setText(QCoreApplication::translate("OpenRouteServiceConfigWidget", "Avoid ferries", nullptr));
        (void)OpenRouteServiceConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class OpenRouteServiceConfigWidget: public Ui_OpenRouteServiceConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENROUTESERVICECONFIGWIDGET_H
