/********************************************************************************
** Form generated from reading UI file 'MovieCaptureDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOVIECAPTUREDIALOG_H
#define UI_MOVIECAPTUREDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_MovieCaptureDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QHBoxLayout *horisontalLayout;
    QLineEdit *destinationEdit;
    QPushButton *openButton;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QSpinBox *fpsSpin;
    QSlider *fpsSlider;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *MovieCaptureDialog)
    {
        if (MovieCaptureDialog->objectName().isEmpty())
            MovieCaptureDialog->setObjectName("MovieCaptureDialog");
        MovieCaptureDialog->resize(364, 213);
        verticalLayout = new QVBoxLayout(MovieCaptureDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(MovieCaptureDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        horisontalLayout = new QHBoxLayout();
        horisontalLayout->setObjectName("horisontalLayout");
        destinationEdit = new QLineEdit(MovieCaptureDialog);
        destinationEdit->setObjectName("destinationEdit");
        destinationEdit->setReadOnly(true);

        horisontalLayout->addWidget(destinationEdit);

        openButton = new QPushButton(MovieCaptureDialog);
        openButton->setObjectName("openButton");

        horisontalLayout->addWidget(openButton);


        verticalLayout->addLayout(horisontalLayout);

        groupBox = new QGroupBox(MovieCaptureDialog);
        groupBox->setObjectName("groupBox");
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        fpsSpin = new QSpinBox(groupBox);
        fpsSpin->setObjectName("fpsSpin");
        fpsSpin->setMinimum(1);
        fpsSpin->setMaximum(60);
        fpsSpin->setValue(30);

        verticalLayout_3->addWidget(fpsSpin);

        fpsSlider = new QSlider(groupBox);
        fpsSlider->setObjectName("fpsSlider");
        fpsSlider->setMinimum(1);
        fpsSlider->setMaximum(60);
        fpsSlider->setValue(30);
        fpsSlider->setOrientation(Qt::Horizontal);

        verticalLayout_3->addWidget(fpsSlider);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(MovieCaptureDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(destinationEdit, openButton);
        QWidget::setTabOrder(openButton, fpsSpin);
        QWidget::setTabOrder(fpsSpin, fpsSlider);

        retranslateUi(MovieCaptureDialog);

        QMetaObject::connectSlotsByName(MovieCaptureDialog);
    } // setupUi

    void retranslateUi(QDialog *MovieCaptureDialog)
    {
        MovieCaptureDialog->setWindowTitle(QCoreApplication::translate("MovieCaptureDialog", "Movie Recording", nullptr));
        label->setText(QCoreApplication::translate("MovieCaptureDialog", "Destination video:", nullptr));
        openButton->setText(QCoreApplication::translate("MovieCaptureDialog", "Open\342\200\246", nullptr));
        groupBox->setTitle(QCoreApplication::translate("MovieCaptureDialog", "FPS (frames per second)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MovieCaptureDialog: public Ui_MovieCaptureDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MOVIECAPTUREDIALOG_H
