/********************************************************************************
** Form generated from reading UI file 'EclipsesConfigDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ECLIPSESCONFIGDIALOG_H
#define UI_ECLIPSESCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_EclipsesConfigDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidgetView;
    QWidget *tabView;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBoxOptions;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *checkBoxEnableLunarEclipses;
    QCheckBox *checkBoxShowEclipseControlWidget;
    QGroupBox *groupBoxVisualization;
    QGridLayout *gridLayout;
    QCheckBox *checkBoxShowNorthernPenumbra;
    QCheckBox *checkBoxShowUmbra;
    QCheckBox *checkBoxShowMaximum;
    QCheckBox *checkBoxShowCentralLine;
    QCheckBox *checkBoxShowFullPenumbra;
    QCheckBox *checkBoxShowSunBoundaries;
    QCheckBox *checkBoxShowSouthernPenumbra;
    QCheckBox *checkBoxShow60MagPenumbra;
    QSpacerItem *verticalSpacer;
    QWidget *tabReminder;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *checkBoxRemind;
    QSpacerItem *verticalSpacer2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EclipsesConfigDialog)
    {
        if (EclipsesConfigDialog->objectName().isEmpty())
            EclipsesConfigDialog->setObjectName("EclipsesConfigDialog");
        EclipsesConfigDialog->setWindowModality(Qt::WindowModal);
        EclipsesConfigDialog->resize(527, 329);
        EclipsesConfigDialog->setModal(false);
        verticalLayout = new QVBoxLayout(EclipsesConfigDialog);
        verticalLayout->setObjectName("verticalLayout");
        tabWidgetView = new QTabWidget(EclipsesConfigDialog);
        tabWidgetView->setObjectName("tabWidgetView");
        tabView = new QWidget();
        tabView->setObjectName("tabView");
        verticalLayout_2 = new QVBoxLayout(tabView);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBoxOptions = new QGroupBox(tabView);
        groupBoxOptions->setObjectName("groupBoxOptions");
        verticalLayout_5 = new QVBoxLayout(groupBoxOptions);
        verticalLayout_5->setObjectName("verticalLayout_5");
        checkBoxEnableLunarEclipses = new QCheckBox(groupBoxOptions);
        checkBoxEnableLunarEclipses->setObjectName("checkBoxEnableLunarEclipses");
        checkBoxEnableLunarEclipses->setEnabled(true);

        verticalLayout_5->addWidget(checkBoxEnableLunarEclipses);

        checkBoxShowEclipseControlWidget = new QCheckBox(groupBoxOptions);
        checkBoxShowEclipseControlWidget->setObjectName("checkBoxShowEclipseControlWidget");
        checkBoxShowEclipseControlWidget->setEnabled(false);

        verticalLayout_5->addWidget(checkBoxShowEclipseControlWidget);


        verticalLayout_2->addWidget(groupBoxOptions);

        groupBoxVisualization = new QGroupBox(tabView);
        groupBoxVisualization->setObjectName("groupBoxVisualization");
        groupBoxVisualization->setCheckable(false);
        gridLayout = new QGridLayout(groupBoxVisualization);
        gridLayout->setObjectName("gridLayout");
        checkBoxShowNorthernPenumbra = new QCheckBox(groupBoxVisualization);
        checkBoxShowNorthernPenumbra->setObjectName("checkBoxShowNorthernPenumbra");
        checkBoxShowNorthernPenumbra->setChecked(false);

        gridLayout->addWidget(checkBoxShowNorthernPenumbra, 6, 0, 1, 1);

        checkBoxShowUmbra = new QCheckBox(groupBoxVisualization);
        checkBoxShowUmbra->setObjectName("checkBoxShowUmbra");
        checkBoxShowUmbra->setChecked(false);

        gridLayout->addWidget(checkBoxShowUmbra, 2, 0, 1, 1);

        checkBoxShowMaximum = new QCheckBox(groupBoxVisualization);
        checkBoxShowMaximum->setObjectName("checkBoxShowMaximum");
        checkBoxShowMaximum->setChecked(false);

        gridLayout->addWidget(checkBoxShowMaximum, 0, 0, 1, 1);

        checkBoxShowCentralLine = new QCheckBox(groupBoxVisualization);
        checkBoxShowCentralLine->setObjectName("checkBoxShowCentralLine");
        checkBoxShowCentralLine->setChecked(false);

        gridLayout->addWidget(checkBoxShowCentralLine, 0, 1, 1, 1);

        checkBoxShowFullPenumbra = new QCheckBox(groupBoxVisualization);
        checkBoxShowFullPenumbra->setObjectName("checkBoxShowFullPenumbra");
        checkBoxShowFullPenumbra->setChecked(false);

        gridLayout->addWidget(checkBoxShowFullPenumbra, 2, 1, 1, 1);

        checkBoxShowSunBoundaries = new QCheckBox(groupBoxVisualization);
        checkBoxShowSunBoundaries->setObjectName("checkBoxShowSunBoundaries");
        checkBoxShowSunBoundaries->setChecked(false);

        gridLayout->addWidget(checkBoxShowSunBoundaries, 6, 1, 1, 1);

        checkBoxShowSouthernPenumbra = new QCheckBox(groupBoxVisualization);
        checkBoxShowSouthernPenumbra->setObjectName("checkBoxShowSouthernPenumbra");
        checkBoxShowSouthernPenumbra->setChecked(false);

        gridLayout->addWidget(checkBoxShowSouthernPenumbra, 5, 0, 1, 1);

        checkBoxShow60MagPenumbra = new QCheckBox(groupBoxVisualization);
        checkBoxShow60MagPenumbra->setObjectName("checkBoxShow60MagPenumbra");
        checkBoxShow60MagPenumbra->setChecked(false);

        gridLayout->addWidget(checkBoxShow60MagPenumbra, 5, 1, 1, 1);


        verticalLayout_2->addWidget(groupBoxVisualization);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        tabWidgetView->addTab(tabView, QString());
        tabReminder = new QWidget();
        tabReminder->setObjectName("tabReminder");
        verticalLayout_3 = new QVBoxLayout(tabReminder);
        verticalLayout_3->setObjectName("verticalLayout_3");
        checkBoxRemind = new QCheckBox(tabReminder);
        checkBoxRemind->setObjectName("checkBoxRemind");
        checkBoxRemind->setChecked(true);

        verticalLayout_3->addWidget(checkBoxRemind);

        verticalSpacer2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer2);

        tabWidgetView->addTab(tabReminder, QString());

        verticalLayout->addWidget(tabWidgetView);

        buttonBox = new QDialogButtonBox(EclipsesConfigDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EclipsesConfigDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, EclipsesConfigDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EclipsesConfigDialog, qOverload<>(&QDialog::reject));

        tabWidgetView->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(EclipsesConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *EclipsesConfigDialog)
    {
        EclipsesConfigDialog->setWindowTitle(QCoreApplication::translate("EclipsesConfigDialog", "Eclipses Configuration", nullptr));
        groupBoxOptions->setTitle(QCoreApplication::translate("EclipsesConfigDialog", "View &Options", nullptr));
        checkBoxEnableLunarEclipses->setText(QCoreApplication::translate("EclipsesConfigDialog", "Enable &Lunar Eclipses", nullptr));
        checkBoxShowEclipseControlWidget->setText(QCoreApplication::translate("EclipsesConfigDialog", "Show Eclipse Control &Widget", nullptr));
        groupBoxVisualization->setTitle(QCoreApplication::translate("EclipsesConfigDialog", "&Eclipse Elements", nullptr));
        checkBoxShowNorthernPenumbra->setText(QCoreApplication::translate("EclipsesConfigDialog", "&Northern Penumbra", nullptr));
        checkBoxShowUmbra->setText(QCoreApplication::translate("EclipsesConfigDialog", "&Umbra", nullptr));
        checkBoxShowMaximum->setText(QCoreApplication::translate("EclipsesConfigDialog", "Position of Eclipse &Maximum", nullptr));
        checkBoxShowCentralLine->setText(QCoreApplication::translate("EclipsesConfigDialog", "Central &Line", nullptr));
        checkBoxShowFullPenumbra->setText(QCoreApplication::translate("EclipsesConfigDialog", "Full &Penumbra", nullptr));
        checkBoxShowSunBoundaries->setText(QCoreApplication::translate("EclipsesConfigDialog", "Sunrise and Sunset &Boundaries", nullptr));
        checkBoxShowSouthernPenumbra->setText(QCoreApplication::translate("EclipsesConfigDialog", "&Southern Penumbra", nullptr));
        checkBoxShow60MagPenumbra->setText(QCoreApplication::translate("EclipsesConfigDialog", "Penumbra with 60% Ma&gnitude", nullptr));
        tabWidgetView->setTabText(tabWidgetView->indexOf(tabView), QCoreApplication::translate("EclipsesConfigDialog", "&View", nullptr));
        checkBoxRemind->setText(QCoreApplication::translate("EclipsesConfigDialog", "Remind about eclipse events", nullptr));
        tabWidgetView->setTabText(tabWidgetView->indexOf(tabReminder), QCoreApplication::translate("EclipsesConfigDialog", "&Reminder", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EclipsesConfigDialog: public Ui_EclipsesConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ECLIPSESCONFIGDIALOG_H
