/********************************************************************************
** Form generated from reading UI file 'LegendWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LEGENDWIDGET_H
#define UI_LEGENDWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "MarbleLegendBrowser.h"

QT_BEGIN_NAMESPACE

class Ui_LegendWidget
{
public:
    QVBoxLayout *verticalLayout;
    MarbleLegendBrowser *m_marbleLegendBrowser;

    void setupUi(QWidget *LegendWidget)
    {
        if (LegendWidget->objectName().isEmpty())
            LegendWidget->setObjectName("LegendWidget");
        LegendWidget->resize(187, 332);
        verticalLayout = new QVBoxLayout(LegendWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_marbleLegendBrowser = new MarbleLegendBrowser(LegendWidget);
        m_marbleLegendBrowser->setObjectName("m_marbleLegendBrowser");
        m_marbleLegendBrowser->setUrl(QUrl(QString::fromUtf8("about:blank")));

        verticalLayout->addWidget(m_marbleLegendBrowser);


        retranslateUi(LegendWidget);

        QMetaObject::connectSlotsByName(LegendWidget);
    } // setupUi

    void retranslateUi(QWidget *LegendWidget)
    {
        LegendWidget->setWindowTitle(QCoreApplication::translate("LegendWidget", "Legend", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LegendWidget: public Ui_LegendWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LEGENDWIDGET_H
