/********************************************************************************
** Form generated from reading UI file 'MapThemeDownloadDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAPTHEMEDOWNLOADDIALOG_H
#define UI_MAPTHEMEDOWNLOADDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QListView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_MapThemeDownloadDialog
{
public:
    QVBoxLayout *verticalLayout;
    QListView *listView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *MapThemeDownloadDialog)
    {
        if (MapThemeDownloadDialog->objectName().isEmpty())
            MapThemeDownloadDialog->setObjectName("MapThemeDownloadDialog");
        MapThemeDownloadDialog->resize(683, 420);
        verticalLayout = new QVBoxLayout(MapThemeDownloadDialog);
        verticalLayout->setObjectName("verticalLayout");
        listView = new QListView(MapThemeDownloadDialog);
        listView->setObjectName("listView");
        listView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        verticalLayout->addWidget(listView);

        buttonBox = new QDialogButtonBox(MapThemeDownloadDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(MapThemeDownloadDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, MapThemeDownloadDialog, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, MapThemeDownloadDialog, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(MapThemeDownloadDialog);
    } // setupUi

    void retranslateUi(QDialog *MapThemeDownloadDialog)
    {
        MapThemeDownloadDialog->setWindowTitle(QCoreApplication::translate("MapThemeDownloadDialog", "Install Maps", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MapThemeDownloadDialog: public Ui_MapThemeDownloadDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAPTHEMEDOWNLOADDIALOG_H
