/********************************************************************************
** Form generated from reading UI file 'DownloadOsmDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOWNLOADOSMDIALOG_H
#define UI_DOWNLOADOSMDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DownloadOsmDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QFrame *line;
    QProgressBar *progressBar;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DownloadOsmDialog)
    {
        if (DownloadOsmDialog->objectName().isEmpty())
            DownloadOsmDialog->setObjectName("DownloadOsmDialog");
        DownloadOsmDialog->resize(461, 323);
        verticalLayout = new QVBoxLayout(DownloadOsmDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");

        verticalLayout->addLayout(horizontalLayout);

        line = new QFrame(DownloadOsmDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        progressBar = new QProgressBar(DownloadOsmDialog);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(0);

        verticalLayout->addWidget(progressBar);

        buttonBox = new QDialogButtonBox(DownloadOsmDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DownloadOsmDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, DownloadOsmDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, DownloadOsmDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(DownloadOsmDialog);
    } // setupUi

    void retranslateUi(QDialog *DownloadOsmDialog)
    {
        DownloadOsmDialog->setWindowTitle(QCoreApplication::translate("DownloadOsmDialog", "Dialog", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DownloadOsmDialog: public Ui_DownloadOsmDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DOWNLOADOSMDIALOG_H
