/****************************************************************************
** Meta object code from reading C++ file 'Coordinate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/lib/marble/declarative/Coordinate.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Coordinate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10CoordinateE_t {};
} // unnamed namespace

template <> constexpr inline auto Coordinate::qt_create_metaobjectdata<qt_meta_tag_ZN10CoordinateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Coordinate",
        "QML.Element",
        "auto",
        "longitudeChanged",
        "",
        "latitudeChanged",
        "altitudeChanged",
        "defaultNotationChanged",
        "Notation",
        "defaultNotation",
        "toGeoString",
        "Coordinate::Notation",
        "notation",
        "precision",
        "distance",
        "longitude",
        "latitude",
        "bearing",
        "altitude",
        "Decimal",
        "DMS",
        "DM",
        "UTM",
        "Astro"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'longitudeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'latitudeChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'altitudeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultNotationChanged'
        QtMocHelpers::SignalData<void(enum Notation)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'toGeoString'
        QtMocHelpers::MethodData<QString(Coordinate::Notation, int) const>(10, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 },
        }}),
        // Method 'toGeoString'
        QtMocHelpers::MethodData<QString(Coordinate::Notation) const>(10, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'toGeoString'
        QtMocHelpers::MethodData<QString() const>(10, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
        // Method 'distance'
        QtMocHelpers::MethodData<qreal(qreal, qreal) const>(14, 4, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 15 }, { QMetaType::QReal, 16 },
        }}),
        // Method 'bearing'
        QtMocHelpers::MethodData<qreal(qreal, qreal) const>(17, 4, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QReal, 15 }, { QMetaType::QReal, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'longitude'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'latitude'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'altitude'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'defaultNotation'
        QtMocHelpers::PropertyData<enum Notation>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Notation'
        QtMocHelpers::EnumData<enum Notation>(8, 8, QMC::EnumFlags{}).add({
            {   19, Notation::Decimal },
            {   20, Notation::DMS },
            {   21, Notation::DM },
            {   22, Notation::UTM },
            {   23, Notation::Astro },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Coordinate, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Coordinate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CoordinateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CoordinateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10CoordinateE_t>.metaTypes,
    nullptr
} };

void Coordinate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Coordinate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->longitudeChanged(); break;
        case 1: _t->latitudeChanged(); break;
        case 2: _t->altitudeChanged(); break;
        case 3: _t->defaultNotationChanged((*reinterpret_cast<std::add_pointer_t<enum Notation>>(_a[1]))); break;
        case 4: { QString _r = _t->toGeoString((*reinterpret_cast<std::add_pointer_t<Coordinate::Notation>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->toGeoString((*reinterpret_cast<std::add_pointer_t<Coordinate::Notation>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->toGeoString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { qreal _r = _t->distance((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 8: { qreal _r = _t->bearing((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Coordinate::*)()>(_a, &Coordinate::longitudeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Coordinate::*)()>(_a, &Coordinate::latitudeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Coordinate::*)()>(_a, &Coordinate::altitudeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Coordinate::*)(Notation )>(_a, &Coordinate::defaultNotationChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->longitude(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->latitude(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->altitude(); break;
        case 3: *reinterpret_cast<enum Notation*>(_v) = _t->defaultNotation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLongitude(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setLatitude(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setAltitude(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setDefaultNotation(*reinterpret_cast<enum Notation*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Coordinate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Coordinate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CoordinateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Coordinate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Coordinate::longitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Coordinate::latitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Coordinate::altitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Coordinate::defaultNotationChanged(Notation _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
