/****************************************************************************
** Meta object code from reading C++ file 'Routing.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/lib/marble/declarative/Routing.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Routing.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble7RoutingE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::Routing::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble7RoutingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::Routing",
        "QML.Element",
        "auto",
        "marbleMapChanged",
        "",
        "routingProfileChanged",
        "hasRouteChanged",
        "hasWaypointsChanged",
        "routingModelChanged",
        "waypointDelegateChanged",
        "QQmlComponent*",
        "waypointDelegate",
        "routeRequestModelChanged",
        "RouteRequestModel*",
        "routeRequestModel",
        "addVia",
        "lon",
        "lat",
        "addViaAtIndex",
        "index",
        "addViaByPlacemark",
        "Placemark*",
        "placemark",
        "addViaByPlacemarkAtIndex",
        "setVia",
        "removeVia",
        "swapVias",
        "index1",
        "index2",
        "reverseRoute",
        "clearRoute",
        "updateRoute",
        "openRoute",
        "filename",
        "saveRoute",
        "waypointModel",
        "setWaypointDelegate",
        "addSearchResultPlacemark",
        "clearSearchResultPlacemarks",
        "updateWaypointItems",
        "updateSearchResultPlacemarks",
        "waypointCount",
        "marbleMap",
        "MarbleMap*",
        "routingProfile",
        "RoutingProfile",
        "hasRoute",
        "hasWaypoints",
        "routingModel",
        "RoutingModel*",
        "alternativeRoutesModel",
        "AlternativeRoutesModel*",
        "Motorcar",
        "Bicycle",
        "Pedestrian"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'marbleMapChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'routingProfileChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasRouteChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasWaypointsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'routingModelChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'waypointDelegateChanged'
        QtMocHelpers::SignalData<void(QQmlComponent *)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'routeRequestModelChanged'
        QtMocHelpers::SignalData<void(RouteRequestModel *)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'addVia'
        QtMocHelpers::SlotData<void(qreal, qreal)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'addViaAtIndex'
        QtMocHelpers::SlotData<void(int, qreal, qreal)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'addViaByPlacemark'
        QtMocHelpers::SlotData<void(Placemark *)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'addViaByPlacemarkAtIndex'
        QtMocHelpers::SlotData<void(int, Placemark *)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setVia'
        QtMocHelpers::SlotData<void(int, qreal, qreal)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 },
        }}),
        // Slot 'removeVia'
        QtMocHelpers::SlotData<void(int)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'swapVias'
        QtMocHelpers::SlotData<void(int, int)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Int, 28 },
        }}),
        // Slot 'reverseRoute'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearRoute'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateRoute'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openRoute'
        QtMocHelpers::SlotData<void(const QString &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'saveRoute'
        QtMocHelpers::SlotData<void(const QString &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'waypointModel'
        QtMocHelpers::SlotData<QObject *()>(35, 4, QMC::AccessPublic, QMetaType::QObjectStar),
        // Slot 'setWaypointDelegate'
        QtMocHelpers::SlotData<void(QQmlComponent *)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'addSearchResultPlacemark'
        QtMocHelpers::SlotData<int(Placemark *)>(37, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'clearSearchResultPlacemarks'
        QtMocHelpers::SlotData<void()>(38, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateWaypointItems'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSearchResultPlacemarks'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'waypointCount'
        QtMocHelpers::MethodData<int() const>(41, 4, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'marbleMap'
        QtMocHelpers::PropertyData<MarbleMap*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'routingProfile'
        QtMocHelpers::PropertyData<enum RoutingProfile>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'hasRoute'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'hasWaypoints'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'routingModel'
        QtMocHelpers::PropertyData<RoutingModel*>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'waypointDelegate'
        QtMocHelpers::PropertyData<QQmlComponent*>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'routeRequestModel'
        QtMocHelpers::PropertyData<RouteRequestModel*>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'alternativeRoutesModel'
        QtMocHelpers::PropertyData<AlternativeRoutesModel*>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RoutingProfile'
        QtMocHelpers::EnumData<enum RoutingProfile>(45, 45, QMC::EnumFlags{}).add({
            {   52, RoutingProfile::Motorcar },
            {   53, RoutingProfile::Bicycle },
            {   54, RoutingProfile::Pedestrian },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Routing, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::Routing::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble7RoutingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble7RoutingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble7RoutingE_t>.metaTypes,
    nullptr
} };

void Marble::Routing::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Routing *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->marbleMapChanged(); break;
        case 1: _t->routingProfileChanged(); break;
        case 2: _t->hasRouteChanged(); break;
        case 3: _t->hasWaypointsChanged(); break;
        case 4: _t->routingModelChanged(); break;
        case 5: _t->waypointDelegateChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 6: _t->routeRequestModelChanged((*reinterpret_cast<std::add_pointer_t<RouteRequestModel*>>(_a[1]))); break;
        case 7: _t->addVia((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 8: _t->addViaAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 9: _t->addViaByPlacemark((*reinterpret_cast<std::add_pointer_t<Placemark*>>(_a[1]))); break;
        case 10: _t->addViaByPlacemarkAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Placemark*>>(_a[2]))); break;
        case 11: _t->setVia((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 12: _t->removeVia((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->swapVias((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->reverseRoute(); break;
        case 15: _t->clearRoute(); break;
        case 16: _t->updateRoute(); break;
        case 17: _t->openRoute((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->saveRoute((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: { QObject* _r = _t->waypointModel();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setWaypointDelegate((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 21: { int _r = _t->addSearchResultPlacemark((*reinterpret_cast<std::add_pointer_t<Placemark*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->clearSearchResultPlacemarks(); break;
        case 23: _t->updateWaypointItems(); break;
        case 24: _t->updateSearchResultPlacemarks(); break;
        case 25: { int _r = _t->waypointCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< RouteRequestModel* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Placemark* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Placemark* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Placemark* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Routing::*)()>(_a, &Routing::marbleMapChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Routing::*)()>(_a, &Routing::routingProfileChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Routing::*)()>(_a, &Routing::hasRouteChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Routing::*)()>(_a, &Routing::hasWaypointsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Routing::*)()>(_a, &Routing::routingModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Routing::*)(QQmlComponent * )>(_a, &Routing::waypointDelegateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Routing::*)(RouteRequestModel * )>(_a, &Routing::routeRequestModelChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AlternativeRoutesModel* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RouteRequestModel* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RoutingModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<MarbleMap**>(_v) = _t->marbleMap(); break;
        case 1: *reinterpret_cast<enum RoutingProfile*>(_v) = _t->routingProfile(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasRoute(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasWaypoints(); break;
        case 4: *reinterpret_cast<RoutingModel**>(_v) = _t->routingModel(); break;
        case 5: *reinterpret_cast<QQmlComponent**>(_v) = _t->waypointDelegate(); break;
        case 6: *reinterpret_cast<RouteRequestModel**>(_v) = _t->routeRequestModel(); break;
        case 7: *reinterpret_cast<AlternativeRoutesModel**>(_v) = _t->alternativeRoutesModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMarbleMap(*reinterpret_cast<MarbleMap**>(_v)); break;
        case 1: _t->setRoutingProfile(*reinterpret_cast<enum RoutingProfile*>(_v)); break;
        case 5: _t->setWaypointDelegate(*reinterpret_cast<QQmlComponent**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::Routing::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::Routing::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble7RoutingE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Marble::Routing::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Marble::Routing::marbleMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::Routing::routingProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::Routing::hasRouteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::Routing::hasWaypointsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::Routing::routingModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Marble::Routing::waypointDelegateChanged(QQmlComponent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Marble::Routing::routeRequestModelChanged(RouteRequestModel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
