/********************************************************************************
** Form generated from reading UI file 'CloudRoutesDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLOUDROUTESDIALOG_H
#define UI_CLOUDROUTESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CloudRoutesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *labelNoRoute;
    QListView *listView;
    QHBoxLayout *horizontalLayout;
    QProgressBar *progressBar;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CloudRoutesDialog)
    {
        if (CloudRoutesDialog->objectName().isEmpty())
            CloudRoutesDialog->setObjectName("CloudRoutesDialog");
        CloudRoutesDialog->resize(512, 384);
        verticalLayout = new QVBoxLayout(CloudRoutesDialog);
        verticalLayout->setObjectName("verticalLayout");
        labelNoRoute = new QLabel(CloudRoutesDialog);
        labelNoRoute->setObjectName("labelNoRoute");
        labelNoRoute->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(labelNoRoute);

        listView = new QListView(CloudRoutesDialog);
        listView->setObjectName("listView");

        verticalLayout->addWidget(listView);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        progressBar = new QProgressBar(CloudRoutesDialog);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(0);
        progressBar->setTextVisible(true);
        progressBar->setInvertedAppearance(false);

        horizontalLayout->addWidget(progressBar);

        buttonBox = new QDialogButtonBox(CloudRoutesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(CloudRoutesDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::clicked, CloudRoutesDialog, qOverload<>(&QDialog::close));

        QMetaObject::connectSlotsByName(CloudRoutesDialog);
    } // setupUi

    void retranslateUi(QDialog *CloudRoutesDialog)
    {
        CloudRoutesDialog->setWindowTitle(QCoreApplication::translate("CloudRoutesDialog", "Cloud Routes", nullptr));
        labelNoRoute->setText(QCoreApplication::translate("CloudRoutesDialog", "No route available.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CloudRoutesDialog: public Ui_CloudRoutesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CLOUDROUTESDIALOG_H
