/********************************************************************************
** Form generated from reading UI file 'EclipsesBrowserDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ECLIPSESBROWSERDIALOG_H
#define UI_ECLIPSESBROWSERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_EclipsesBrowserDialog
{
public:
    QVBoxLayout *verticalLayout;
    QWidget *widget;
    QHBoxLayout *horizontalLayout;
    QLabel *labelEclipses;
    QSpinBox *spinBoxYear;
    QSpacerItem *horizontalSpacer1;
    QPushButton *buttonSettings;
    QTreeView *treeView;
    QWidget *widgetButtons;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *buttonClose;
    QSpacerItem *horizontalSpacer2;
    QPushButton *buttonShow;

    void setupUi(QDialog *EclipsesBrowserDialog)
    {
        if (EclipsesBrowserDialog->objectName().isEmpty())
            EclipsesBrowserDialog->setObjectName("EclipsesBrowserDialog");
        EclipsesBrowserDialog->resize(600, 202);
        EclipsesBrowserDialog->setModal(false);
        verticalLayout = new QVBoxLayout(EclipsesBrowserDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, -1, -1, 4);
        widget = new QWidget(EclipsesBrowserDialog);
        widget->setObjectName("widget");
        horizontalLayout = new QHBoxLayout(widget);
#ifndef Q_OS_MACOS
        horizontalLayout->setSpacing(6);
#endif
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        labelEclipses = new QLabel(widget);
        labelEclipses->setObjectName("labelEclipses");
        labelEclipses->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(labelEclipses);

        spinBoxYear = new QSpinBox(widget);
        spinBoxYear->setObjectName("spinBoxYear");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(spinBoxYear->sizePolicy().hasHeightForWidth());
        spinBoxYear->setSizePolicy(sizePolicy);
        spinBoxYear->setBaseSize(QSize(0, 0));
        QFont font;
        font.setBold(true);
        spinBoxYear->setFont(font);
        spinBoxYear->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        spinBoxYear->setButtonSymbols(QAbstractSpinBox::PlusMinus);
        spinBoxYear->setAccelerated(true);
        spinBoxYear->setCorrectionMode(QAbstractSpinBox::CorrectToPreviousValue);
        spinBoxYear->setMinimum(-100000);
        spinBoxYear->setMaximum(100000);
        spinBoxYear->setValue(1);

        horizontalLayout->addWidget(spinBoxYear);

        horizontalSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer1);

        buttonSettings = new QPushButton(widget);
        buttonSettings->setObjectName("buttonSettings");

        horizontalLayout->addWidget(buttonSettings);


        verticalLayout->addWidget(widget);

        treeView = new QTreeView(EclipsesBrowserDialog);
        treeView->setObjectName("treeView");
        treeView->setRootIsDecorated(false);
        treeView->setHeaderHidden(false);
        treeView->header()->setCascadingSectionResizes(true);
        treeView->header()->setMinimumSectionSize(100);
        treeView->header()->setDefaultSectionSize(100);
        treeView->header()->setHighlightSections(false);
        treeView->header()->setStretchLastSection(true);

        verticalLayout->addWidget(treeView);

        widgetButtons = new QWidget(EclipsesBrowserDialog);
        widgetButtons->setObjectName("widgetButtons");
        horizontalLayout_3 = new QHBoxLayout(widgetButtons);
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        buttonClose = new QPushButton(widgetButtons);
        buttonClose->setObjectName("buttonClose");

        horizontalLayout_3->addWidget(buttonClose);

        horizontalSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer2);

        buttonShow = new QPushButton(widgetButtons);
        buttonShow->setObjectName("buttonShow");
        buttonShow->setEnabled(false);

        horizontalLayout_3->addWidget(buttonShow);


        verticalLayout->addWidget(widgetButtons);


        retranslateUi(EclipsesBrowserDialog);

        buttonClose->setDefault(true);


        QMetaObject::connectSlotsByName(EclipsesBrowserDialog);
    } // setupUi

    void retranslateUi(QDialog *EclipsesBrowserDialog)
    {
        EclipsesBrowserDialog->setWindowTitle(QCoreApplication::translate("EclipsesBrowserDialog", "Eclipse Browser", nullptr));
        labelEclipses->setText(QCoreApplication::translate("EclipsesBrowserDialog", "Show eclipses for year:", nullptr));
        spinBoxYear->setSuffix(QString());
        buttonSettings->setText(QCoreApplication::translate("EclipsesBrowserDialog", "&Settings\342\200\246", nullptr));
        buttonClose->setText(QCoreApplication::translate("EclipsesBrowserDialog", "&Close", nullptr));
        buttonShow->setText(QCoreApplication::translate("EclipsesBrowserDialog", "&Go To Selected Eclipse", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EclipsesBrowserDialog: public Ui_EclipsesBrowserDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ECLIPSESBROWSERDIALOG_H
