/****************************************************************************
** Meta object code from reading C++ file 'Tracking.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/lib/marble/declarative/Tracking.h"
#include "MarbleQuickItem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Tracking.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble8TrackingE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::Tracking::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble8TrackingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::Tracking",
        "QML.Element",
        "auto",
        "mapChanged",
        "",
        "showTrackChanged",
        "positionSourceChanged",
        "positionMarkerChanged",
        "hasLastKnownPositionChanged",
        "lastKnownPositionChanged",
        "autoCenterChanged",
        "autoZoomChanged",
        "positionMarkerTypeChanged",
        "distanceChanged",
        "saveTrack",
        "fileName",
        "openTrack",
        "clearTrack",
        "updatePositionMarker",
        "updateLastKnownPosition",
        "setHasLastKnownPosition",
        "map",
        "MarbleQuickItem*",
        "showTrack",
        "autoCenter",
        "autoZoom",
        "positionSource",
        "PositionSource*",
        "positionMarker",
        "hasLastKnownPosition",
        "lastKnownPosition",
        "Coordinate*",
        "positionMarkerType",
        "PositionMarkerType",
        "distance",
        "None",
        "Circle",
        "Arrow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mapChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTrackChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionSourceChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionMarkerChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasLastKnownPositionChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastKnownPositionChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoCenterChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoZoomChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionMarkerTypeChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'distanceChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveTrack'
        QtMocHelpers::SlotData<void(const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'openTrack'
        QtMocHelpers::SlotData<void(const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'clearTrack'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updatePositionMarker'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLastKnownPosition'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setHasLastKnownPosition'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'map'
        QtMocHelpers::PropertyData<MarbleQuickItem*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'showTrack'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'autoCenter'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'autoZoom'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'positionSource'
        QtMocHelpers::PropertyData<PositionSource*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'positionMarker'
        QtMocHelpers::PropertyData<QObject*>(28, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'hasLastKnownPosition'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'lastKnownPosition'
        QtMocHelpers::PropertyData<Coordinate*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'positionMarkerType'
        QtMocHelpers::PropertyData<enum PositionMarkerType>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'distance'
        QtMocHelpers::PropertyData<double>(34, QMetaType::Double, QMC::DefaultPropertyFlags, 9),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PositionMarkerType'
        QtMocHelpers::EnumData<enum PositionMarkerType>(33, 33, QMC::EnumFlags{}).add({
            {   35, PositionMarkerType::None },
            {   36, PositionMarkerType::Circle },
            {   37, PositionMarkerType::Arrow },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Tracking, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::Tracking::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble8TrackingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble8TrackingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble8TrackingE_t>.metaTypes,
    nullptr
} };

void Marble::Tracking::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Tracking *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mapChanged(); break;
        case 1: _t->showTrackChanged(); break;
        case 2: _t->positionSourceChanged(); break;
        case 3: _t->positionMarkerChanged(); break;
        case 4: _t->hasLastKnownPositionChanged(); break;
        case 5: _t->lastKnownPositionChanged(); break;
        case 6: _t->autoCenterChanged(); break;
        case 7: _t->autoZoomChanged(); break;
        case 8: _t->positionMarkerTypeChanged(); break;
        case 9: _t->distanceChanged(); break;
        case 10: _t->saveTrack((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->openTrack((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->clearTrack(); break;
        case 13: _t->updatePositionMarker(); break;
        case 14: _t->updateLastKnownPosition(); break;
        case 15: _t->setHasLastKnownPosition(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::mapChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::showTrackChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::positionSourceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::positionMarkerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::hasLastKnownPositionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::lastKnownPositionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::autoCenterChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::autoZoomChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::positionMarkerTypeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tracking::*)()>(_a, &Tracking::distanceChanged, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Coordinate* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MarbleQuickItem* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PositionSource* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<MarbleQuickItem**>(_v) = _t->map(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showTrack(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->autoCenter(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->autoZoom(); break;
        case 4: *reinterpret_cast<PositionSource**>(_v) = _t->positionSource(); break;
        case 5: *reinterpret_cast<QObject**>(_v) = _t->positionMarker(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasLastKnownPosition(); break;
        case 7: *reinterpret_cast<Coordinate**>(_v) = _t->lastKnownPosition(); break;
        case 8: *reinterpret_cast<enum PositionMarkerType*>(_v) = _t->positionMarkerType(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->distance(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMap(*reinterpret_cast<MarbleQuickItem**>(_v)); break;
        case 1: _t->setShowTrack(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setAutoCenter(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setAutoZoom(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setPositionSource(*reinterpret_cast<PositionSource**>(_v)); break;
        case 5: _t->setPositionMarker(*reinterpret_cast<QObject**>(_v)); break;
        case 7: _t->setLastKnownPosition(*reinterpret_cast<Coordinate**>(_v)); break;
        case 8: _t->setPositionMarkerType(*reinterpret_cast<enum PositionMarkerType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::Tracking::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::Tracking::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble8TrackingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::Tracking::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Marble::Tracking::mapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::Tracking::showTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::Tracking::positionSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::Tracking::positionMarkerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::Tracking::hasLastKnownPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Marble::Tracking::lastKnownPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Marble::Tracking::autoCenterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Marble::Tracking::autoZoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Marble::Tracking::positionMarkerTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Marble::Tracking::distanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
