/****************************************************************************
** Meta object code from reading C++ file 'OfflineDataModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/lib/marble/declarative/OfflineDataModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OfflineDataModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16OfflineDataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto OfflineDataModel::qt_create_metaobjectdata<qt_meta_tag_ZN16OfflineDataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OfflineDataModel",
        "countChanged",
        "",
        "installationProgressed",
        "newstuffindex",
        "progress",
        "installationFinished",
        "installationFailed",
        "error",
        "uninstallationFinished",
        "setVehicleTypeFilter",
        "VehicleTypes",
        "filter",
        "install",
        "index",
        "uninstall",
        "cancel",
        "handleInstallationProgress",
        "handleInstallationFinished",
        "handleInstallationFailed",
        "handleUninstallationFinished",
        "count",
        "VehicleType",
        "None",
        "Motorcar",
        "Bicycle",
        "Pedestrian",
        "Any"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'installationProgressed'
        QtMocHelpers::SignalData<void(int, qreal)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QReal, 5 },
        }}),
        // Signal 'installationFinished'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'installationFailed'
        QtMocHelpers::SignalData<void(int, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'uninstallationFinished'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setVehicleTypeFilter'
        QtMocHelpers::SlotData<void(VehicleTypes)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'install'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'handleInstallationProgress'
        QtMocHelpers::SlotData<void(int, qreal)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::QReal, 5 },
        }}),
        // Slot 'handleInstallationFinished'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'handleInstallationFailed'
        QtMocHelpers::SlotData<void(int, const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'handleUninstallationFinished'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'VehicleType'
        QtMocHelpers::EnumData<enum VehicleType>(22, 22, QMC::EnumFlags{}).add({
            {   23, VehicleType::None },
            {   24, VehicleType::Motorcar },
            {   25, VehicleType::Bicycle },
            {   26, VehicleType::Pedestrian },
            {   27, VehicleType::Any },
        }),
        // flag 'VehicleTypes'
        QtMocHelpers::EnumData<VehicleTypes>(11, 22, QMC::EnumIsFlag).add({
            {   23, VehicleType::None },
            {   24, VehicleType::Motorcar },
            {   25, VehicleType::Bicycle },
            {   26, VehicleType::Pedestrian },
            {   27, VehicleType::Any },
        }),
    };
    return QtMocHelpers::metaObjectData<OfflineDataModel, qt_meta_tag_ZN16OfflineDataModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OfflineDataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16OfflineDataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16OfflineDataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16OfflineDataModelE_t>.metaTypes,
    nullptr
} };

void OfflineDataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OfflineDataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->installationProgressed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 2: _t->installationFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->installationFailed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->uninstallationFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setVehicleTypeFilter((*reinterpret_cast<std::add_pointer_t<VehicleTypes>>(_a[1]))); break;
        case 6: _t->install((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->uninstall((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->cancel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->handleInstallationProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 10: _t->handleInstallationFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->handleInstallationFailed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->handleUninstallationFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OfflineDataModel::*)()>(_a, &OfflineDataModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OfflineDataModel::*)(int , qreal )>(_a, &OfflineDataModel::installationProgressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OfflineDataModel::*)(int )>(_a, &OfflineDataModel::installationFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OfflineDataModel::*)(int , const QString & )>(_a, &OfflineDataModel::installationFailed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OfflineDataModel::*)(int )>(_a, &OfflineDataModel::uninstallationFinished, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->count(); break;
        default: break;
        }
    }
}

const QMetaObject *OfflineDataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OfflineDataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16OfflineDataModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int OfflineDataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void OfflineDataModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OfflineDataModel::installationProgressed(int _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OfflineDataModel::installationFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OfflineDataModel::installationFailed(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void OfflineDataModel::uninstallationFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
