/********************************************************************************
** Form generated from reading UI file 'PrintOptions.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRINTOPTIONS_H
#define UI_PRINTOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PrintOptions
{
public:
    QGridLayout *gridLayout_3;
    QGroupBox *mapGroupBox;
    QGridLayout *gridLayout;
    QCheckBox *mapCheckBox;
    QSpacerItem *horizontalSpacer;
    QCheckBox *backgroundCheckBox;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *legendCheckBox;
    QSpacerItem *verticalSpacer;
    QGroupBox *routeGroupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *routeSummaryCheckBox;
    QCheckBox *drivingInstructionsCheckBox;
    QCheckBox *drivingInstructionsAdviceCheckBox;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *PrintOptions)
    {
        if (PrintOptions->objectName().isEmpty())
            PrintOptions->setObjectName("PrintOptions");
        PrintOptions->resize(333, 136);
        gridLayout_3 = new QGridLayout(PrintOptions);
        gridLayout_3->setObjectName("gridLayout_3");
        mapGroupBox = new QGroupBox(PrintOptions);
        mapGroupBox->setObjectName("mapGroupBox");
        gridLayout = new QGridLayout(mapGroupBox);
        gridLayout->setObjectName("gridLayout");
        mapCheckBox = new QCheckBox(mapGroupBox);
        mapCheckBox->setObjectName("mapCheckBox");
        mapCheckBox->setChecked(true);

        gridLayout->addWidget(mapCheckBox, 0, 0, 1, 2);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        backgroundCheckBox = new QCheckBox(mapGroupBox);
        backgroundCheckBox->setObjectName("backgroundCheckBox");

        gridLayout->addWidget(backgroundCheckBox, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        legendCheckBox = new QCheckBox(mapGroupBox);
        legendCheckBox->setObjectName("legendCheckBox");
        legendCheckBox->setChecked(false);

        gridLayout->addWidget(legendCheckBox, 2, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 1);


        gridLayout_3->addWidget(mapGroupBox, 0, 0, 1, 1);

        routeGroupBox = new QGroupBox(PrintOptions);
        routeGroupBox->setObjectName("routeGroupBox");
        gridLayout_2 = new QGridLayout(routeGroupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        routeSummaryCheckBox = new QCheckBox(routeGroupBox);
        routeSummaryCheckBox->setObjectName("routeSummaryCheckBox");

        gridLayout_2->addWidget(routeSummaryCheckBox, 0, 0, 1, 1);

        drivingInstructionsCheckBox = new QCheckBox(routeGroupBox);
        drivingInstructionsCheckBox->setObjectName("drivingInstructionsCheckBox");

        gridLayout_2->addWidget(drivingInstructionsCheckBox, 1, 0, 1, 1);

        drivingInstructionsAdviceCheckBox = new QCheckBox(routeGroupBox);
        drivingInstructionsAdviceCheckBox->setObjectName("drivingInstructionsAdviceCheckBox");

        gridLayout_2->addWidget(drivingInstructionsAdviceCheckBox, 2, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 3, 0, 1, 1);


        gridLayout_3->addWidget(routeGroupBox, 0, 1, 1, 1);


        retranslateUi(PrintOptions);
        QObject::connect(mapCheckBox, &QCheckBox::toggled, backgroundCheckBox, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(PrintOptions);
    } // setupUi

    void retranslateUi(QWidget *PrintOptions)
    {
        PrintOptions->setWindowTitle(QCoreApplication::translate("PrintOptions", "Marble", nullptr));
        mapGroupBox->setTitle(QCoreApplication::translate("PrintOptions", "Map", nullptr));
        mapCheckBox->setText(QCoreApplication::translate("PrintOptions", "Visible Globe Region", nullptr));
        backgroundCheckBox->setText(QCoreApplication::translate("PrintOptions", "Outer Space", nullptr));
        legendCheckBox->setText(QCoreApplication::translate("PrintOptions", "Legend", nullptr));
        routeGroupBox->setTitle(QCoreApplication::translate("PrintOptions", "Route", nullptr));
        routeSummaryCheckBox->setText(QCoreApplication::translate("PrintOptions", "Route Summary", nullptr));
        drivingInstructionsCheckBox->setText(QCoreApplication::translate("PrintOptions", "Driving Instructions", nullptr));
        drivingInstructionsAdviceCheckBox->setText(QCoreApplication::translate("PrintOptions", "Footer", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PrintOptions: public Ui_PrintOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PRINTOPTIONS_H
