/********************************************************************************
** Form generated from reading UI file 'Speedometer.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPEEDOMETER_H
#define UI_SPEEDOMETER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLCDNumber>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Speedometer
{
public:
    QHBoxLayout *horizontalLayout;
    QLCDNumber *speed;
    QLabel *speedUnit;

    void setupUi(QWidget *Speedometer)
    {
        if (Speedometer->objectName().isEmpty())
            Speedometer->setObjectName("Speedometer");
        Speedometer->setEnabled(true);
        Speedometer->resize(223, 126);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Speedometer->sizePolicy().hasHeightForWidth());
        Speedometer->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(Speedometer);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        speed = new QLCDNumber(Speedometer);
        speed->setObjectName("speed");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(speed->sizePolicy().hasHeightForWidth());
        speed->setSizePolicy(sizePolicy1);
        speed->setFrameShape(QFrame::NoFrame);
        speed->setDigitCount(3);

        horizontalLayout->addWidget(speed);

        speedUnit = new QLabel(Speedometer);
        speedUnit->setObjectName("speedUnit");

        horizontalLayout->addWidget(speedUnit);


        retranslateUi(Speedometer);

        QMetaObject::connectSlotsByName(Speedometer);
    } // setupUi

    void retranslateUi(QWidget *Speedometer)
    {
        speedUnit->setText(QCoreApplication::translate("Speedometer", "km/h", nullptr));
        (void)Speedometer;
    } // retranslateUi

};

namespace Ui {
    class Speedometer: public Ui_Speedometer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SPEEDOMETER_H
