/********************************************************************************
** Form generated from reading UI file 'EclipsesReminderDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ECLIPSESREMINDERDIALOG_H
#define UI_ECLIPSESREMINDERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EclipsesReminderDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *labelText;
    QListWidget *listWidgetEclipses;
    QCheckBox *checkBoxDoNotRemind;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EclipsesReminderDialog)
    {
        if (EclipsesReminderDialog->objectName().isEmpty())
            EclipsesReminderDialog->setObjectName("EclipsesReminderDialog");
        EclipsesReminderDialog->resize(425, 254);
        verticalLayout = new QVBoxLayout(EclipsesReminderDialog);
        verticalLayout->setObjectName("verticalLayout");
        labelText = new QLabel(EclipsesReminderDialog);
        labelText->setObjectName("labelText");
        labelText->setWordWrap(true);

        verticalLayout->addWidget(labelText);

        listWidgetEclipses = new QListWidget(EclipsesReminderDialog);
        listWidgetEclipses->setObjectName("listWidgetEclipses");

        verticalLayout->addWidget(listWidgetEclipses);

        checkBoxDoNotRemind = new QCheckBox(EclipsesReminderDialog);
        checkBoxDoNotRemind->setObjectName("checkBoxDoNotRemind");

        verticalLayout->addWidget(checkBoxDoNotRemind);

        buttonBox = new QDialogButtonBox(EclipsesReminderDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EclipsesReminderDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, EclipsesReminderDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EclipsesReminderDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(EclipsesReminderDialog);
    } // setupUi

    void retranslateUi(QDialog *EclipsesReminderDialog)
    {
        EclipsesReminderDialog->setWindowTitle(QCoreApplication::translate("EclipsesReminderDialog", "Eclipse Event", nullptr));
        labelText->setText(QCoreApplication::translate("EclipsesReminderDialog", "<html><head/><body><p>Marble has detected that the following <span style=\" font-weight:600;\">eclipse events</span> will occur in the near future. If you want more information on a specific event, select it and click OK.</p></body></html>", nullptr));
        checkBoxDoNotRemind->setText(QCoreApplication::translate("EclipsesReminderDialog", "Do not remind me about eclipse events again", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EclipsesReminderDialog: public Ui_EclipsesReminderDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ECLIPSESREMINDERDIALOG_H
