/********************************************************************************
** Form generated from reading UI file 'MapWizard.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAPWIZARD_H
#define UI_MAPWIZARD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <QtWidgets/QWizard>
#include <QtWidgets/QWizardPage>

QT_BEGIN_NAMESPACE

class Ui_MapWizard
{
public:
    QWizardPage *wizardPageIntro;
    QVBoxLayout *verticalLayout_14;
    QLabel *labelIntroInfo;
    QRadioButton *radioButtonWms;
    QRadioButton *radioButtonWmts;
    QRadioButton *radioButtonBitmap;
    QRadioButton *radioButtonStaticUrl;
    QWizardPage *wizardPageWms;
    QVBoxLayout *verticalLayout;
    QLabel *labelOwsServiceHeader;
    QSpacerItem *verticalSpacer_10;
    QGridLayout *gridLayout;
    QLabel *labelWmsServer;
    QComboBox *comboBoxWmsServer;
    QLabel *labelWmsUrl;
    QLineEdit *lineEditWmsUrl;
    QSpacerItem *verticalSpacer_9;
    QHBoxLayout *horizontalLayout_2;
    QProgressBar *progressBarWmsCapabilities;
    QWizardPage *wizardPageWmsAvailableMaps;
    QVBoxLayout *verticalLayout_7;
    QLabel *labelWmsTitle;
    QTabWidget *tabWidgetLayers;
    QWidget *tabLayerSelection;
    QVBoxLayout *verticalLayout_12;
    QHBoxLayout *horizontalLayout_6;
    QLabel *labelWmsMaps;
    QSpacerItem *horizontalSpacer_4;
    QLabel *labelWmsSearch;
    QLineEdit *lineEditWmsSearch;
    QListView *listViewWmsLayers;
    QGridLayout *gridLayout_3;
    QCheckBox *checkBoxWmsMultipleSelections;
    QCheckBox *checkBoxWmsBackdrop;
    QLabel *labelWmsTileProjection;
    QComboBox *comboBoxWmsMaps;
    QSpacerItem *horizontalSpacer_3;
    QLabel *labelWmsTileFormat;
    QComboBox *comboBoxWmsFormat;
    QProgressBar *progressBarWmsLayers;
    QWidget *tabLayerInfo;
    QVBoxLayout *verticalLayout_9;
    QTextEdit *textEditWmsLayerInfo;
    QWidget *tabServiceInfo;
    QVBoxLayout *verticalLayout_10;
    QTextEdit *textEditWmsServiceInfo;
    QWidget *tabCustomizeBackdrop;
    QVBoxLayout *verticalLayout_13;
    QHBoxLayout *horizontalLayout_7;
    QRadioButton *radioButtonOpenStreetMap;
    QComboBox *comboBox;
    QHBoxLayout *horizontalLayout_8;
    QRadioButton *radioButtonXYZServer;
    QLineEdit *lineEditXYZServer;
    QHBoxLayout *horizontalLayout_9;
    QRadioButton *radioButtonColor;
    QLabel *labelBackgroundColor;
    QPushButton *pushButtonColor;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer_3;
    QWizardPage *wizardPageBitmap;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QLabel *labelSource;
    QLineEdit *lineEditSource;
    QPushButton *pushButtonSource;
    QSpacerItem *verticalSpacer;
    QWizardPage *wizardPageStaticUrl;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_4;
    QSpacerItem *verticalSpacer_6;
    QFormLayout *formLayout_4;
    QLabel *labelStaticUrlServer;
    QComboBox *comboBoxStaticUrlServer;
    QSpacerItem *verticalSpacer_2;
    QWizardPage *wizardPageMetadata;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_6;
    QGridLayout *gridLayout_2;
    QLabel *labelMapTitle;
    QLineEdit *lineEditTitle;
    QLabel *labelMapTheme;
    QLineEdit *lineEditTheme;
    QLabel *labelMapDesc;
    QTextEdit *textEditDesc;
    QLabel *labelMapIcon;
    QHBoxLayout *horizontalLayout_4;
    QLabel *labelPreview;
    QVBoxLayout *verticalLayout_11;
    QSpacerItem *verticalSpacer_5;
    QPushButton *pushButtonPreview;
    QSpacerItem *horizontalSpacer_2;
    QWizardPage *wizardPageLegend;
    QVBoxLayout *verticalLayout_6;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelLegend_2;
    QLineEdit *lineEditLegend_2;
    QPushButton *pushButtonLegend_2;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_8;
    QLabel *labelLegendImage;
    QWizardPage *wizardPageSummary;
    QVBoxLayout *verticalLayout_5;
    QLabel *label_7;
    QGridLayout *gridLayout_4;
    QLabel *labelSumName;
    QLabel *labelSumMName;
    QLabel *labelSumTheme;
    QLabel *labelSumMTheme;
    QLabel *labelSumMPreview;
    QHBoxLayout *horizontalLayout_5;
    QLabel *labelThumbnail;
    QPushButton *pushButtonPreviewMap;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWizard *MapWizard)
    {
        if (MapWizard->objectName().isEmpty())
            MapWizard->setObjectName("MapWizard");
        MapWizard->resize(600, 392);
        MapWizard->setMinimumSize(QSize(600, 392));
        MapWizard->setWizardStyle(QWizard::ClassicStyle);
        wizardPageIntro = new QWizardPage();
        wizardPageIntro->setObjectName("wizardPageIntro");
        verticalLayout_14 = new QVBoxLayout(wizardPageIntro);
        verticalLayout_14->setObjectName("verticalLayout_14");
        labelIntroInfo = new QLabel(wizardPageIntro);
        labelIntroInfo->setObjectName("labelIntroInfo");
        labelIntroInfo->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        labelIntroInfo->setWordWrap(true);

        verticalLayout_14->addWidget(labelIntroInfo);

        radioButtonWms = new QRadioButton(wizardPageIntro);
        radioButtonWms->setObjectName("radioButtonWms");
        radioButtonWms->setChecked(true);

        verticalLayout_14->addWidget(radioButtonWms);

        radioButtonWmts = new QRadioButton(wizardPageIntro);
        radioButtonWmts->setObjectName("radioButtonWmts");
        radioButtonWmts->setChecked(false);

        verticalLayout_14->addWidget(radioButtonWmts);

        radioButtonBitmap = new QRadioButton(wizardPageIntro);
        radioButtonBitmap->setObjectName("radioButtonBitmap");

        verticalLayout_14->addWidget(radioButtonBitmap);

        radioButtonStaticUrl = new QRadioButton(wizardPageIntro);
        radioButtonStaticUrl->setObjectName("radioButtonStaticUrl");

        verticalLayout_14->addWidget(radioButtonStaticUrl);

        MapWizard->setPage(0, wizardPageIntro);
        wizardPageWms = new QWizardPage();
        wizardPageWms->setObjectName("wizardPageWms");
        verticalLayout = new QVBoxLayout(wizardPageWms);
        verticalLayout->setObjectName("verticalLayout");
        labelOwsServiceHeader = new QLabel(wizardPageWms);
        labelOwsServiceHeader->setObjectName("labelOwsServiceHeader");
        labelOwsServiceHeader->setWordWrap(true);

        verticalLayout->addWidget(labelOwsServiceHeader);

        verticalSpacer_10 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_10);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        labelWmsServer = new QLabel(wizardPageWms);
        labelWmsServer->setObjectName("labelWmsServer");
        labelWmsServer->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(labelWmsServer, 0, 0, 1, 1);

        comboBoxWmsServer = new QComboBox(wizardPageWms);
        comboBoxWmsServer->addItem(QString());
        comboBoxWmsServer->setObjectName("comboBoxWmsServer");

        gridLayout->addWidget(comboBoxWmsServer, 0, 1, 1, 1);

        labelWmsUrl = new QLabel(wizardPageWms);
        labelWmsUrl->setObjectName("labelWmsUrl");
        labelWmsUrl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(labelWmsUrl, 1, 0, 1, 1);

        lineEditWmsUrl = new QLineEdit(wizardPageWms);
        lineEditWmsUrl->setObjectName("lineEditWmsUrl");

        gridLayout->addWidget(lineEditWmsUrl, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer_9 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_9);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        progressBarWmsCapabilities = new QProgressBar(wizardPageWms);
        progressBarWmsCapabilities->setObjectName("progressBarWmsCapabilities");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(progressBarWmsCapabilities->sizePolicy().hasHeightForWidth());
        progressBarWmsCapabilities->setSizePolicy(sizePolicy);
        progressBarWmsCapabilities->setMaximum(0);
        progressBarWmsCapabilities->setValue(-1);
        progressBarWmsCapabilities->setTextVisible(true);

        horizontalLayout_2->addWidget(progressBarWmsCapabilities);


        verticalLayout->addLayout(horizontalLayout_2);

        MapWizard->addPage(wizardPageWms);
        wizardPageWmsAvailableMaps = new QWizardPage();
        wizardPageWmsAvailableMaps->setObjectName("wizardPageWmsAvailableMaps");
        verticalLayout_7 = new QVBoxLayout(wizardPageWmsAvailableMaps);
        verticalLayout_7->setObjectName("verticalLayout_7");
        labelWmsTitle = new QLabel(wizardPageWmsAvailableMaps);
        labelWmsTitle->setObjectName("labelWmsTitle");

        verticalLayout_7->addWidget(labelWmsTitle);

        tabWidgetLayers = new QTabWidget(wizardPageWmsAvailableMaps);
        tabWidgetLayers->setObjectName("tabWidgetLayers");
        tabLayerSelection = new QWidget();
        tabLayerSelection->setObjectName("tabLayerSelection");
        tabLayerSelection->setEnabled(true);
        verticalLayout_12 = new QVBoxLayout(tabLayerSelection);
        verticalLayout_12->setObjectName("verticalLayout_12");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(-1, -1, -1, 6);
        labelWmsMaps = new QLabel(tabLayerSelection);
        labelWmsMaps->setObjectName("labelWmsMaps");
        labelWmsMaps->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_6->addWidget(labelWmsMaps);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_4);

        labelWmsSearch = new QLabel(tabLayerSelection);
        labelWmsSearch->setObjectName("labelWmsSearch");
        labelWmsSearch->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_6->addWidget(labelWmsSearch);

        lineEditWmsSearch = new QLineEdit(tabLayerSelection);
        lineEditWmsSearch->setObjectName("lineEditWmsSearch");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lineEditWmsSearch->sizePolicy().hasHeightForWidth());
        lineEditWmsSearch->setSizePolicy(sizePolicy1);

        horizontalLayout_6->addWidget(lineEditWmsSearch);


        verticalLayout_12->addLayout(horizontalLayout_6);

        listViewWmsLayers = new QListView(tabLayerSelection);
        listViewWmsLayers->setObjectName("listViewWmsLayers");

        verticalLayout_12->addWidget(listViewWmsLayers);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        checkBoxWmsMultipleSelections = new QCheckBox(tabLayerSelection);
        checkBoxWmsMultipleSelections->setObjectName("checkBoxWmsMultipleSelections");

        gridLayout_3->addWidget(checkBoxWmsMultipleSelections, 0, 0, 1, 2);

        checkBoxWmsBackdrop = new QCheckBox(tabLayerSelection);
        checkBoxWmsBackdrop->setObjectName("checkBoxWmsBackdrop");

        gridLayout_3->addWidget(checkBoxWmsBackdrop, 0, 3, 1, 2);

        labelWmsTileProjection = new QLabel(tabLayerSelection);
        labelWmsTileProjection->setObjectName("labelWmsTileProjection");

        gridLayout_3->addWidget(labelWmsTileProjection, 1, 0, 1, 1);

        comboBoxWmsMaps = new QComboBox(tabLayerSelection);
        comboBoxWmsMaps->setObjectName("comboBoxWmsMaps");

        gridLayout_3->addWidget(comboBoxWmsMaps, 1, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(13, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 1, 2, 1, 1);

        labelWmsTileFormat = new QLabel(tabLayerSelection);
        labelWmsTileFormat->setObjectName("labelWmsTileFormat");

        gridLayout_3->addWidget(labelWmsTileFormat, 1, 3, 1, 1);

        comboBoxWmsFormat = new QComboBox(tabLayerSelection);
        comboBoxWmsFormat->setObjectName("comboBoxWmsFormat");

        gridLayout_3->addWidget(comboBoxWmsFormat, 1, 4, 1, 1);


        verticalLayout_12->addLayout(gridLayout_3);

        progressBarWmsLayers = new QProgressBar(tabLayerSelection);
        progressBarWmsLayers->setObjectName("progressBarWmsLayers");
        sizePolicy.setHeightForWidth(progressBarWmsLayers->sizePolicy().hasHeightForWidth());
        progressBarWmsLayers->setSizePolicy(sizePolicy);
        progressBarWmsLayers->setMaximum(0);
        progressBarWmsLayers->setValue(-1);
        progressBarWmsLayers->setTextVisible(true);

        verticalLayout_12->addWidget(progressBarWmsLayers);

        tabWidgetLayers->addTab(tabLayerSelection, QString());
        tabLayerInfo = new QWidget();
        tabLayerInfo->setObjectName("tabLayerInfo");
        tabLayerInfo->setEnabled(false);
        verticalLayout_9 = new QVBoxLayout(tabLayerInfo);
        verticalLayout_9->setObjectName("verticalLayout_9");
        textEditWmsLayerInfo = new QTextEdit(tabLayerInfo);
        textEditWmsLayerInfo->setObjectName("textEditWmsLayerInfo");

        verticalLayout_9->addWidget(textEditWmsLayerInfo);

        tabWidgetLayers->addTab(tabLayerInfo, QString());
        tabServiceInfo = new QWidget();
        tabServiceInfo->setObjectName("tabServiceInfo");
        tabServiceInfo->setEnabled(false);
        verticalLayout_10 = new QVBoxLayout(tabServiceInfo);
        verticalLayout_10->setObjectName("verticalLayout_10");
        textEditWmsServiceInfo = new QTextEdit(tabServiceInfo);
        textEditWmsServiceInfo->setObjectName("textEditWmsServiceInfo");

        verticalLayout_10->addWidget(textEditWmsServiceInfo);

        tabWidgetLayers->addTab(tabServiceInfo, QString());
        tabCustomizeBackdrop = new QWidget();
        tabCustomizeBackdrop->setObjectName("tabCustomizeBackdrop");
        verticalLayout_13 = new QVBoxLayout(tabCustomizeBackdrop);
        verticalLayout_13->setSpacing(12);
        verticalLayout_13->setObjectName("verticalLayout_13");
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        radioButtonOpenStreetMap = new QRadioButton(tabCustomizeBackdrop);
        radioButtonOpenStreetMap->setObjectName("radioButtonOpenStreetMap");
        radioButtonOpenStreetMap->setCheckable(true);
        radioButtonOpenStreetMap->setChecked(true);

        horizontalLayout_7->addWidget(radioButtonOpenStreetMap);

        comboBox = new QComboBox(tabCustomizeBackdrop);
        comboBox->addItem(QString());
        comboBox->setObjectName("comboBox");
        sizePolicy.setHeightForWidth(comboBox->sizePolicy().hasHeightForWidth());
        comboBox->setSizePolicy(sizePolicy);

        horizontalLayout_7->addWidget(comboBox);


        verticalLayout_13->addLayout(horizontalLayout_7);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        radioButtonXYZServer = new QRadioButton(tabCustomizeBackdrop);
        radioButtonXYZServer->setObjectName("radioButtonXYZServer");
        radioButtonXYZServer->setEnabled(false);

        horizontalLayout_8->addWidget(radioButtonXYZServer);

        lineEditXYZServer = new QLineEdit(tabCustomizeBackdrop);
        lineEditXYZServer->setObjectName("lineEditXYZServer");
        lineEditXYZServer->setEnabled(false);

        horizontalLayout_8->addWidget(lineEditXYZServer);


        verticalLayout_13->addLayout(horizontalLayout_8);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        radioButtonColor = new QRadioButton(tabCustomizeBackdrop);
        radioButtonColor->setObjectName("radioButtonColor");
        radioButtonColor->setEnabled(true);

        horizontalLayout_9->addWidget(radioButtonColor);

        labelBackgroundColor = new QLabel(tabCustomizeBackdrop);
        labelBackgroundColor->setObjectName("labelBackgroundColor");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(labelBackgroundColor->sizePolicy().hasHeightForWidth());
        labelBackgroundColor->setSizePolicy(sizePolicy2);
        labelBackgroundColor->setMinimumSize(QSize(0, 0));
        labelBackgroundColor->setMargin(3);

        horizontalLayout_9->addWidget(labelBackgroundColor);

        pushButtonColor = new QPushButton(tabCustomizeBackdrop);
        pushButtonColor->setObjectName("pushButtonColor");
        pushButtonColor->setEnabled(true);

        horizontalLayout_9->addWidget(pushButtonColor);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_5);


        verticalLayout_13->addLayout(horizontalLayout_9);

        verticalSpacer_3 = new QSpacerItem(20, 131, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_13->addItem(verticalSpacer_3);

        tabWidgetLayers->addTab(tabCustomizeBackdrop, QString());

        verticalLayout_7->addWidget(tabWidgetLayers);

        MapWizard->addPage(wizardPageWmsAvailableMaps);
        wizardPageBitmap = new QWizardPage();
        wizardPageBitmap->setObjectName("wizardPageBitmap");
        verticalLayout_2 = new QVBoxLayout(wizardPageBitmap);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_2 = new QLabel(wizardPageBitmap);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout_2->addWidget(label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        labelSource = new QLabel(wizardPageBitmap);
        labelSource->setObjectName("labelSource");
        labelSource->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(labelSource);

        lineEditSource = new QLineEdit(wizardPageBitmap);
        lineEditSource->setObjectName("lineEditSource");

        horizontalLayout->addWidget(lineEditSource);

        pushButtonSource = new QPushButton(wizardPageBitmap);
        pushButtonSource->setObjectName("pushButtonSource");

        horizontalLayout->addWidget(pushButtonSource);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        MapWizard->addPage(wizardPageBitmap);
        wizardPageStaticUrl = new QWizardPage();
        wizardPageStaticUrl->setObjectName("wizardPageStaticUrl");
        verticalLayout_3 = new QVBoxLayout(wizardPageStaticUrl);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_4 = new QLabel(wizardPageStaticUrl);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        verticalLayout_3->addWidget(label_4);

        verticalSpacer_6 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_6);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        labelStaticUrlServer = new QLabel(wizardPageStaticUrl);
        labelStaticUrlServer->setObjectName("labelStaticUrlServer");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, labelStaticUrlServer);

        comboBoxStaticUrlServer = new QComboBox(wizardPageStaticUrl);
        comboBoxStaticUrlServer->setObjectName("comboBoxStaticUrlServer");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(comboBoxStaticUrlServer->sizePolicy().hasHeightForWidth());
        comboBoxStaticUrlServer->setSizePolicy(sizePolicy3);
        comboBoxStaticUrlServer->setEditable(true);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, comboBoxStaticUrlServer);


        verticalLayout_3->addLayout(formLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        MapWizard->addPage(wizardPageStaticUrl);
        wizardPageMetadata = new QWizardPage();
        wizardPageMetadata->setObjectName("wizardPageMetadata");
        verticalLayout_4 = new QVBoxLayout(wizardPageMetadata);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label_6 = new QLabel(wizardPageMetadata);
        label_6->setObjectName("label_6");
        label_6->setWordWrap(true);

        verticalLayout_4->addWidget(label_6);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        labelMapTitle = new QLabel(wizardPageMetadata);
        labelMapTitle->setObjectName("labelMapTitle");
        labelMapTitle->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(labelMapTitle, 0, 0, 1, 1);

        lineEditTitle = new QLineEdit(wizardPageMetadata);
        lineEditTitle->setObjectName("lineEditTitle");

        gridLayout_2->addWidget(lineEditTitle, 0, 1, 1, 2);

        labelMapTheme = new QLabel(wizardPageMetadata);
        labelMapTheme->setObjectName("labelMapTheme");
        labelMapTheme->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(labelMapTheme, 1, 0, 1, 1);

        lineEditTheme = new QLineEdit(wizardPageMetadata);
        lineEditTheme->setObjectName("lineEditTheme");

        gridLayout_2->addWidget(lineEditTheme, 1, 1, 1, 2);

        labelMapDesc = new QLabel(wizardPageMetadata);
        labelMapDesc->setObjectName("labelMapDesc");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(labelMapDesc->sizePolicy().hasHeightForWidth());
        labelMapDesc->setSizePolicy(sizePolicy4);
        labelMapDesc->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout_2->addWidget(labelMapDesc, 2, 0, 1, 1);

        textEditDesc = new QTextEdit(wizardPageMetadata);
        textEditDesc->setObjectName("textEditDesc");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(textEditDesc->sizePolicy().hasHeightForWidth());
        textEditDesc->setSizePolicy(sizePolicy5);

        gridLayout_2->addWidget(textEditDesc, 2, 1, 1, 2);

        labelMapIcon = new QLabel(wizardPageMetadata);
        labelMapIcon->setObjectName("labelMapIcon");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(labelMapIcon->sizePolicy().hasHeightForWidth());
        labelMapIcon->setSizePolicy(sizePolicy6);
        labelMapIcon->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout_2->addWidget(labelMapIcon, 3, 0, 1, 2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        labelPreview = new QLabel(wizardPageMetadata);
        labelPreview->setObjectName("labelPreview");
        labelPreview->setEnabled(true);

        horizontalLayout_4->addWidget(labelPreview);

        verticalLayout_11 = new QVBoxLayout();
        verticalLayout_11->setObjectName("verticalLayout_11");
        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_11->addItem(verticalSpacer_5);

        pushButtonPreview = new QPushButton(wizardPageMetadata);
        pushButtonPreview->setObjectName("pushButtonPreview");

        verticalLayout_11->addWidget(pushButtonPreview);


        horizontalLayout_4->addLayout(verticalLayout_11);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout_4, 3, 2, 1, 1);


        verticalLayout_4->addLayout(gridLayout_2);

        MapWizard->addPage(wizardPageMetadata);
        wizardPageLegend = new QWizardPage();
        wizardPageLegend->setObjectName("wizardPageLegend");
        verticalLayout_6 = new QVBoxLayout(wizardPageLegend);
        verticalLayout_6->setObjectName("verticalLayout_6");
        label_3 = new QLabel(wizardPageLegend);
        label_3->setObjectName("label_3");

        verticalLayout_6->addWidget(label_3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        labelLegend_2 = new QLabel(wizardPageLegend);
        labelLegend_2->setObjectName("labelLegend_2");

        horizontalLayout_3->addWidget(labelLegend_2);

        lineEditLegend_2 = new QLineEdit(wizardPageLegend);
        lineEditLegend_2->setObjectName("lineEditLegend_2");

        horizontalLayout_3->addWidget(lineEditLegend_2);

        pushButtonLegend_2 = new QPushButton(wizardPageLegend);
        pushButtonLegend_2->setObjectName("pushButtonLegend_2");

        horizontalLayout_3->addWidget(pushButtonLegend_2);


        verticalLayout_6->addLayout(horizontalLayout_3);

        scrollArea = new QScrollArea(wizardPageLegend);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        scrollArea->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 66, 36));
        verticalLayout_8 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_8->setObjectName("verticalLayout_8");
        labelLegendImage = new QLabel(scrollAreaWidgetContents);
        labelLegendImage->setObjectName("labelLegendImage");
        labelLegendImage->setAlignment(Qt::AlignCenter);

        verticalLayout_8->addWidget(labelLegendImage);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_6->addWidget(scrollArea);

        MapWizard->addPage(wizardPageLegend);
        wizardPageSummary = new QWizardPage();
        wizardPageSummary->setObjectName("wizardPageSummary");
        verticalLayout_5 = new QVBoxLayout(wizardPageSummary);
        verticalLayout_5->setObjectName("verticalLayout_5");
        label_7 = new QLabel(wizardPageSummary);
        label_7->setObjectName("label_7");
        label_7->setWordWrap(true);

        verticalLayout_5->addWidget(label_7);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        labelSumName = new QLabel(wizardPageSummary);
        labelSumName->setObjectName("labelSumName");
        QFont font;
        font.setBold(true);
        labelSumName->setFont(font);

        gridLayout_4->addWidget(labelSumName, 0, 0, 1, 1);

        labelSumMName = new QLabel(wizardPageSummary);
        labelSumMName->setObjectName("labelSumMName");

        gridLayout_4->addWidget(labelSumMName, 0, 1, 1, 2);

        labelSumTheme = new QLabel(wizardPageSummary);
        labelSumTheme->setObjectName("labelSumTheme");
        labelSumTheme->setFont(font);

        gridLayout_4->addWidget(labelSumTheme, 1, 0, 1, 1);

        labelSumMTheme = new QLabel(wizardPageSummary);
        labelSumMTheme->setObjectName("labelSumMTheme");

        gridLayout_4->addWidget(labelSumMTheme, 1, 1, 1, 2);

        labelSumMPreview = new QLabel(wizardPageSummary);
        labelSumMPreview->setObjectName("labelSumMPreview");
        labelSumMPreview->setFont(font);

        gridLayout_4->addWidget(labelSumMPreview, 2, 0, 1, 2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(30);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        labelThumbnail = new QLabel(wizardPageSummary);
        labelThumbnail->setObjectName("labelThumbnail");
        labelThumbnail->setAlignment(Qt::AlignCenter);

        horizontalLayout_5->addWidget(labelThumbnail);

        pushButtonPreviewMap = new QPushButton(wizardPageSummary);
        pushButtonPreviewMap->setObjectName("pushButtonPreviewMap");

        horizontalLayout_5->addWidget(pushButtonPreviewMap);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);


        gridLayout_4->addLayout(horizontalLayout_5, 2, 2, 1, 1);


        verticalLayout_5->addLayout(gridLayout_4);

        MapWizard->addPage(wizardPageSummary);
#if QT_CONFIG(shortcut)
        labelSource->setBuddy(lineEditSource);
        labelMapTitle->setBuddy(lineEditTitle);
        labelMapDesc->setBuddy(textEditDesc);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(radioButtonWms, radioButtonBitmap);
        QWidget::setTabOrder(radioButtonBitmap, radioButtonStaticUrl);
        QWidget::setTabOrder(radioButtonStaticUrl, comboBoxWmsServer);
        QWidget::setTabOrder(comboBoxWmsServer, lineEditWmsUrl);
        QWidget::setTabOrder(lineEditWmsUrl, tabWidgetLayers);
        QWidget::setTabOrder(tabWidgetLayers, lineEditWmsSearch);
        QWidget::setTabOrder(lineEditWmsSearch, listViewWmsLayers);
        QWidget::setTabOrder(listViewWmsLayers, checkBoxWmsMultipleSelections);
        QWidget::setTabOrder(checkBoxWmsMultipleSelections, comboBoxWmsMaps);
        QWidget::setTabOrder(comboBoxWmsMaps, comboBoxWmsFormat);
        QWidget::setTabOrder(comboBoxWmsFormat, lineEditSource);
        QWidget::setTabOrder(lineEditSource, pushButtonSource);
        QWidget::setTabOrder(pushButtonSource, comboBoxStaticUrlServer);
        QWidget::setTabOrder(comboBoxStaticUrlServer, lineEditTitle);
        QWidget::setTabOrder(lineEditTitle, lineEditTheme);
        QWidget::setTabOrder(lineEditTheme, textEditDesc);
        QWidget::setTabOrder(textEditDesc, pushButtonPreview);
        QWidget::setTabOrder(pushButtonPreview, lineEditLegend_2);
        QWidget::setTabOrder(lineEditLegend_2, pushButtonLegend_2);
        QWidget::setTabOrder(pushButtonLegend_2, scrollArea);
        QWidget::setTabOrder(scrollArea, pushButtonPreviewMap);
        QWidget::setTabOrder(pushButtonPreviewMap, textEditWmsServiceInfo);
        QWidget::setTabOrder(textEditWmsServiceInfo, textEditWmsLayerInfo);

        retranslateUi(MapWizard);

        tabWidgetLayers->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MapWizard);
    } // setupUi

    void retranslateUi(QWizard *MapWizard)
    {
        MapWizard->setWindowTitle(QCoreApplication::translate("MapWizard", "Map Theme Creation Wizard", nullptr));
        labelIntroInfo->setText(QCoreApplication::translate("MapWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Welcome to the Map Creation Wizard!</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">We will guide you through the process of creating a map theme for Marble. In the end you will have your own map that you can view in Marble.</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-l"
                        "eft:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please choose the source that you want to use for the data of your map theme:</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonWms->setToolTip(QCoreApplication::translate("MapWizard", "Connects to a server on the Internet. The map data is queried via the WMS protocol.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonWms->setText(QCoreApplication::translate("MapWizard", "Web Map Service (WMS)", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonWmts->setToolTip(QCoreApplication::translate("MapWizard", "Connects to a server on the Internet. The map data is queried via the WMS protocol.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonWmts->setText(QCoreApplication::translate("MapWizard", "Web Map Tile Service (WMTS)", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonBitmap->setToolTip(QCoreApplication::translate("MapWizard", "You need to provide a bitmap image of a world map that is stored on disk.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonBitmap->setText(QCoreApplication::translate("MapWizard", "A single image showing the whole world", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonStaticUrl->setToolTip(QCoreApplication::translate("MapWizard", "Connects to a server on the Internet. The map data is queried via a static URL.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonStaticUrl->setText(QCoreApplication::translate("MapWizard", "Online map providing indexed tiles (e.g. Open Street Map)", nullptr));
        labelOwsServiceHeader->setText(QCoreApplication::translate("MapWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">WMS Server</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please choose a <a href=\"https://en.wikipedia.org/wiki/Web_Map_Service\"><span style=\" text-decoration: underline; color:#0057ae;\">WMS</span></a> server or enter a custom server URL.</p></body></html>", nullptr));
        labelWmsServer->setText(QCoreApplication::translate("MapWizard", "WMS Server:", nullptr));
        comboBoxWmsServer->setItemText(0, QCoreApplication::translate("MapWizard", "Custom", nullptr));

        labelWmsUrl->setText(QCoreApplication::translate("MapWizard", "URL:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditWmsUrl->setToolTip(QCoreApplication::translate("MapWizard", "Enter the base Url of the WMS service (e.g. <i>https://www.wms.nrw.de/geobasis/wms_nw_dop_overlay</i>)", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditWmsUrl->setText(QCoreApplication::translate("MapWizard", "https://", nullptr));
        lineEditWmsUrl->setPlaceholderText(QCoreApplication::translate("MapWizard", "Custom", nullptr));
        labelWmsTitle->setText(QCoreApplication::translate("MapWizard", "Wms-Service:", nullptr));
        labelWmsMaps->setText(QCoreApplication::translate("MapWizard", "Choose your Layer(s):", nullptr));
        labelWmsSearch->setText(QCoreApplication::translate("MapWizard", "Search:", nullptr));
#if QT_CONFIG(tooltip)
        listViewWmsLayers->setToolTip(QCoreApplication::translate("MapWizard", "The order in which multiple layers are selected directly affects their rendering order.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxWmsMultipleSelections->setToolTip(QCoreApplication::translate("MapWizard", "Enable this to select multiple layers without keyboard shortcuts (Shift, Ctrl, Ctrl+A, \342\200\246)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxWmsMultipleSelections->setText(QCoreApplication::translate("MapWizard", "Multiple Selections", nullptr));
        checkBoxWmsBackdrop->setText(QCoreApplication::translate("MapWizard", "Custom Backdrop", nullptr));
        labelWmsTileProjection->setText(QCoreApplication::translate("MapWizard", "Tile Projection:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxWmsMaps->setToolTip(QCoreApplication::translate("MapWizard", "Indicates the projection in which the tiles are rendered.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelWmsTileFormat->setText(QCoreApplication::translate("MapWizard", "Tile Format:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxWmsFormat->setToolTip(QCoreApplication::translate("MapWizard", "Indicates the file format of the tiles.", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidgetLayers->setTabText(tabWidgetLayers->indexOf(tabLayerSelection), QCoreApplication::translate("MapWizard", "Layer Selection", nullptr));
        tabWidgetLayers->setTabText(tabWidgetLayers->indexOf(tabLayerInfo), QCoreApplication::translate("MapWizard", "Layer Info", nullptr));
        tabWidgetLayers->setTabText(tabWidgetLayers->indexOf(tabServiceInfo), QCoreApplication::translate("MapWizard", "Service Info", nullptr));
        radioButtonOpenStreetMap->setText(QCoreApplication::translate("MapWizard", "Preset Layers", nullptr));
        comboBox->setItemText(0, QCoreApplication::translate("MapWizard", "OpenStreetMap", nullptr));

        radioButtonXYZServer->setText(QCoreApplication::translate("MapWizard", "XYZ Server Url", nullptr));
#if QT_CONFIG(tooltip)
        lineEditXYZServer->setToolTip(QCoreApplication::translate("MapWizard", "The XYZ server needs to provide map tiles in Mercator projection.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditXYZServer->setText(QCoreApplication::translate("MapWizard", "https://", nullptr));
        radioButtonColor->setText(QCoreApplication::translate("MapWizard", "Color", nullptr));
        labelBackgroundColor->setText(QCoreApplication::translate("MapWizard", "#87CEFA", nullptr));
        pushButtonColor->setText(QCoreApplication::translate("MapWizard", "Select Color", nullptr));
        tabWidgetLayers->setTabText(tabWidgetLayers->indexOf(tabCustomizeBackdrop), QCoreApplication::translate("MapWizard", "Customize Backdrop", nullptr));
        label_2->setText(QCoreApplication::translate("MapWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">World Map Bitmap Image</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-weight:600;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please choose the location of a world map that is stored in a single image file (JPG, PNG, etc.). It needs to be provided in <a href=\"https://en.wikipedia.org/wiki/Equirectangular_projection\"><span st"
                        "yle=\" text-decoration: underline; color:#0057ae;\">Equirectangular projection</span></a>, so the shape should look like this (size ratio: 2:1):</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\":/data/svg/worldmap.svg\" width=\"150\" /></p></body></html>", nullptr));
        labelSource->setText(QCoreApplication::translate("MapWizard", "Source Image:", nullptr));
        pushButtonSource->setText(QCoreApplication::translate("MapWizard", "\342\200\246", nullptr));
        label_4->setText(QCoreApplication::translate("MapWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Bitstream Vera Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">URL Scheme for Indexed Tiles</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif';\">Please enter the URL used for downloading individual tiles. Use the placeholders </span><span style=\" font-family:'Sans Serif'; font-style:italic;\">{x}</span><span style=\" font-family:'Sans Serif';\">, </span><span style=\" font-family:'Sans Serif'; font-style:italic;\">{y}</span><s"
                        "pan style=\" font-family:'Sans Serif';\">, and </span><span style=\" font-family:'Sans Serif'; font-style:italic;\">{zoomLevel}</span><span style=\" font-family:'Sans Serif';\"> to reference a tile from the index.</span></p></body></html>", nullptr));
        labelStaticUrlServer->setText(QCoreApplication::translate("MapWizard", "URL Scheme:", nullptr));
        label_6->setText(QCoreApplication::translate("MapWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Bitstream Vera Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">General Information</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif';\">Please specify a title, a name and an icon for your new map. Add a description to let users know what your map is about. </span></p></body></html>", nullptr));
        labelMapTitle->setText(QCoreApplication::translate("MapWizard", "Map Title:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditTitle->setToolTip(QCoreApplication::translate("MapWizard", "A short concise name for your map theme.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelMapTheme->setText(QCoreApplication::translate("MapWizard", "Map Name:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditTheme->setToolTip(QCoreApplication::translate("MapWizard", "The lowercase map theme id.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        lineEditTheme->setWhatsThis(QCoreApplication::translate("MapWizard", "The folder name of your new theme.", nullptr));
#endif // QT_CONFIG(whatsthis)
        labelMapDesc->setText(QCoreApplication::translate("MapWizard", "Description:", nullptr));
#if QT_CONFIG(tooltip)
        textEditDesc->setToolTip(QCoreApplication::translate("MapWizard", "A short description of your map theme. Here you can provide information about the purpose, origin, copyright and license of the data used in your map theme.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textEditDesc->setWhatsThis(QCoreApplication::translate("MapWizard", "It will appear in a tool tip and may contain HTML formatting.", nullptr));
#endif // QT_CONFIG(whatsthis)
        labelMapIcon->setText(QCoreApplication::translate("MapWizard", "Preview Image:", nullptr));
        labelPreview->setText(QCoreApplication::translate("MapWizard", "preview image", nullptr));
        pushButtonPreview->setText(QCoreApplication::translate("MapWizard", "Change\342\200\246", nullptr));
        label_3->setText(QCoreApplication::translate("MapWizard", "<b>Optional: Addition of a Map Key</b>", nullptr));
        labelLegend_2->setText(QCoreApplication::translate("MapWizard", "Legend Image:", nullptr));
        pushButtonLegend_2->setText(QCoreApplication::translate("MapWizard", "\342\200\246", nullptr));
        labelLegendImage->setText(QString());
        label_7->setText(QCoreApplication::translate("MapWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Summary</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Congratulations! You have entered all the data that is necessary to create your map theme. Check the summary below carefully and press the &quot;Finish&quot; button to create the theme. </p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please consider contributing the map theme back to the Marble commu"
                        "nity if the license and the terms of use allow for it.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p></body></html>", nullptr));
        labelSumName->setText(QCoreApplication::translate("MapWizard", "Map Name:", nullptr));
        labelSumMName->setText(QCoreApplication::translate("MapWizard", "Map name goes here.", nullptr));
        labelSumTheme->setText(QCoreApplication::translate("MapWizard", "Map Theme:", nullptr));
        labelSumMTheme->setText(QCoreApplication::translate("MapWizard", "Map theme goes here.", nullptr));
        labelSumMPreview->setText(QCoreApplication::translate("MapWizard", "Preview Image:", nullptr));
        labelThumbnail->setText(QCoreApplication::translate("MapWizard", "Thumbnail", nullptr));
        pushButtonPreviewMap->setText(QCoreApplication::translate("MapWizard", "Preview Map", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MapWizard: public Ui_MapWizard {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAPWIZARD_H
