/********************************************************************************
** Form generated from reading UI file 'CurrentLocationWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CURRENTLOCATIONWIDGET_H
#define UI_CURRENTLOCATIONWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CurrentLocationWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *projectionLabel_3;
    QComboBox *positionTrackingComboBox;
    QHBoxLayout *horizontalLayout;
    QCheckBox *showTrackCheckBox;
    QToolButton *clearTrackButton;
    QToolButton *openTrackButton;
    QToolButton *saveTrackButton;
    QLabel *locationLabel;
    QSpacerItem *verticalSpacer;
    QLabel *recenterLabel;
    QComboBox *recenterComboBox;
    QCheckBox *autoZoomCheckBox;

    void setupUi(QWidget *CurrentLocationWidget)
    {
        if (CurrentLocationWidget->objectName().isEmpty())
            CurrentLocationWidget->setObjectName("CurrentLocationWidget");
        CurrentLocationWidget->resize(259, 268);
        verticalLayout = new QVBoxLayout(CurrentLocationWidget);
        verticalLayout->setObjectName("verticalLayout");
        projectionLabel_3 = new QLabel(CurrentLocationWidget);
        projectionLabel_3->setObjectName("projectionLabel_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(projectionLabel_3->sizePolicy().hasHeightForWidth());
        projectionLabel_3->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(projectionLabel_3);

        positionTrackingComboBox = new QComboBox(CurrentLocationWidget);
        positionTrackingComboBox->addItem(QString());
        positionTrackingComboBox->setObjectName("positionTrackingComboBox");

        verticalLayout->addWidget(positionTrackingComboBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        showTrackCheckBox = new QCheckBox(CurrentLocationWidget);
        showTrackCheckBox->setObjectName("showTrackCheckBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(showTrackCheckBox->sizePolicy().hasHeightForWidth());
        showTrackCheckBox->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(showTrackCheckBox);

        clearTrackButton = new QToolButton(CurrentLocationWidget);
        clearTrackButton->setObjectName("clearTrackButton");
        sizePolicy.setHeightForWidth(clearTrackButton->sizePolicy().hasHeightForWidth());
        clearTrackButton->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/16x16/edit-clear-list.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        clearTrackButton->setIcon(icon);
        clearTrackButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(clearTrackButton);

        openTrackButton = new QToolButton(CurrentLocationWidget);
        openTrackButton->setObjectName("openTrackButton");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/16x16/document-open.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        openTrackButton->setIcon(icon1);

        horizontalLayout->addWidget(openTrackButton);

        saveTrackButton = new QToolButton(CurrentLocationWidget);
        saveTrackButton->setObjectName("saveTrackButton");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/16x16/document-save.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        saveTrackButton->setIcon(icon2);

        horizontalLayout->addWidget(saveTrackButton);


        verticalLayout->addLayout(horizontalLayout);

        locationLabel = new QLabel(CurrentLocationWidget);
        locationLabel->setObjectName("locationLabel");
        locationLabel->setEnabled(false);
        locationLabel->setAutoFillBackground(false);
        locationLabel->setFrameShape(QFrame::StyledPanel);
        locationLabel->setFrameShadow(QFrame::Sunken);
        locationLabel->setTextFormat(Qt::RichText);
        locationLabel->setWordWrap(true);

        verticalLayout->addWidget(locationLabel);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        recenterLabel = new QLabel(CurrentLocationWidget);
        recenterLabel->setObjectName("recenterLabel");
        recenterLabel->setEnabled(false);
        sizePolicy.setHeightForWidth(recenterLabel->sizePolicy().hasHeightForWidth());
        recenterLabel->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(recenterLabel);

        recenterComboBox = new QComboBox(CurrentLocationWidget);
        recenterComboBox->addItem(QString());
        recenterComboBox->addItem(QString());
        recenterComboBox->addItem(QString());
        recenterComboBox->setObjectName("recenterComboBox");
        recenterComboBox->setEnabled(false);

        verticalLayout->addWidget(recenterComboBox);

        autoZoomCheckBox = new QCheckBox(CurrentLocationWidget);
        autoZoomCheckBox->setObjectName("autoZoomCheckBox");
        autoZoomCheckBox->setEnabled(false);

        verticalLayout->addWidget(autoZoomCheckBox);

#if QT_CONFIG(shortcut)
        projectionLabel_3->setBuddy(positionTrackingComboBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CurrentLocationWidget);

        QMetaObject::connectSlotsByName(CurrentLocationWidget);
    } // setupUi

    void retranslateUi(QWidget *CurrentLocationWidget)
    {
        CurrentLocationWidget->setWindowTitle(QCoreApplication::translate("CurrentLocationWidget", "Current Location", nullptr));
        projectionLabel_3->setText(QCoreApplication::translate("CurrentLocationWidget", "Position Tracking", nullptr));
        positionTrackingComboBox->setItemText(0, QCoreApplication::translate("CurrentLocationWidget", "Disabled", nullptr));

        showTrackCheckBox->setText(QCoreApplication::translate("CurrentLocationWidget", "Show Track", nullptr));
        clearTrackButton->setText(QCoreApplication::translate("CurrentLocationWidget", "Clear Track", nullptr));
        openTrackButton->setText(QCoreApplication::translate("CurrentLocationWidget", "\342\200\246", nullptr));
        saveTrackButton->setText(QCoreApplication::translate("CurrentLocationWidget", "\342\200\246", nullptr));
        locationLabel->setText(QCoreApplication::translate("CurrentLocationWidget", "No position available.", nullptr));
#if QT_CONFIG(tooltip)
        recenterLabel->setToolTip(QCoreApplication::translate("CurrentLocationWidget", "Select the method to use to re-center your GPS location on map.", "Select the method to use to recenter your GPS location on map."));
#endif // QT_CONFIG(tooltip)
        recenterLabel->setText(QCoreApplication::translate("CurrentLocationWidget", "Map Adjustment", nullptr));
        recenterComboBox->setItemText(0, QCoreApplication::translate("CurrentLocationWidget", "Disabled", "Disable Auto Recenter"));
        recenterComboBox->setItemText(1, QCoreApplication::translate("CurrentLocationWidget", "Keep at Center", "Always keep gps location at the center of the map"));
        recenterComboBox->setItemText(2, QCoreApplication::translate("CurrentLocationWidget", "When required", "Auto center when required"));

#if QT_CONFIG(tooltip)
        autoZoomCheckBox->setToolTip(QCoreApplication::translate("CurrentLocationWidget", "Auto Zoom to appropriate zoom level", "Auto Zoom to appropriate zoom level"));
#endif // QT_CONFIG(tooltip)
        autoZoomCheckBox->setText(QCoreApplication::translate("CurrentLocationWidget", "Auto Zoom", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CurrentLocationWidget: public Ui_CurrentLocationWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CURRENTLOCATIONWIDGET_H
