/****************************************************************************
** Meta object code from reading C++ file 'MonavConfigWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.07.80/src/plugins/runner/monav/MonavConfigWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MonavConfigWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble17MonavConfigWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MonavConfigWidget::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble17MonavConfigWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MonavConfigWidget",
        "retrieveMapList",
        "",
        "QNetworkReply*",
        "reply",
        "retrieveData",
        "updateComboBoxes",
        "updateStates",
        "updateRegions",
        "downloadMap",
        "updateProgressBar",
        "bytesReceived",
        "bytesTotal",
        "mapInstalled",
        "exitStatus",
        "updateTransportTypeFilter",
        "filter",
        "removeMap",
        "index",
        "upgradeMap",
        "cancelOperation"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'retrieveMapList'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'retrieveData'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateComboBoxes'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStates'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRegions'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'downloadMap'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateProgressBar'
        QtMocHelpers::SlotData<void(qint64, qint64)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 11 }, { QMetaType::LongLong, 12 },
        }}),
        // Slot 'mapInstalled'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'updateTransportTypeFilter'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'removeMap'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'upgradeMap'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'cancelOperation'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonavConfigWidget, qt_meta_tag_ZN6Marble17MonavConfigWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MonavConfigWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<RoutingRunnerPlugin::ConfigWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17MonavConfigWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17MonavConfigWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble17MonavConfigWidgetE_t>.metaTypes,
    nullptr
} };

void Marble::MonavConfigWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MonavConfigWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->retrieveMapList((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 1: _t->retrieveData(); break;
        case 2: _t->updateComboBoxes(); break;
        case 3: _t->updateStates(); break;
        case 4: _t->updateRegions(); break;
        case 5: _t->downloadMap(); break;
        case 6: _t->updateProgressBar((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 7: _t->mapInstalled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->updateTransportTypeFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->removeMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->upgradeMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->cancelOperation(); break;
        default: ;
        }
    }
}

const QMetaObject *Marble::MonavConfigWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MonavConfigWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17MonavConfigWidgetE_t>.strings))
        return static_cast<void*>(this);
    return RoutingRunnerPlugin::ConfigWidget::qt_metacast(_clname);
}

int Marble::MonavConfigWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = RoutingRunnerPlugin::ConfigWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
