/********************************************************************************
** Form generated from reading UI file 'ExternalEditor.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTERNALEDITOR_H
#define UI_EXTERNALEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ExternalEditor
{
public:
    QVBoxLayout *verticalLayout_2;
    QFormLayout *formLayout;
    QLabel *label_2;
    QComboBox *editorComboBox;
    QCheckBox *saveDefaultCheckBox;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QLabel *screenshotLabel;
    QLabel *descriptionLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ExternalEditor)
    {
        if (ExternalEditor->objectName().isEmpty())
            ExternalEditor->setObjectName("ExternalEditor");
        ExternalEditor->resize(387, 465);
        verticalLayout_2 = new QVBoxLayout(ExternalEditor);
        verticalLayout_2->setObjectName("verticalLayout_2");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(ExternalEditor);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        editorComboBox = new QComboBox(ExternalEditor);
        editorComboBox->addItem(QString());
        editorComboBox->addItem(QString());
        editorComboBox->addItem(QString());
        editorComboBox->setObjectName("editorComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, editorComboBox);

        saveDefaultCheckBox = new QCheckBox(ExternalEditor);
        saveDefaultCheckBox->setObjectName("saveDefaultCheckBox");
        saveDefaultCheckBox->setChecked(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, saveDefaultCheckBox);


        verticalLayout_2->addLayout(formLayout);

        groupBox = new QGroupBox(ExternalEditor);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        screenshotLabel = new QLabel(groupBox);
        screenshotLabel->setObjectName("screenshotLabel");
        screenshotLabel->setMinimumSize(QSize(360, 280));
        screenshotLabel->setFrameShape(QFrame::Box);
        screenshotLabel->setPixmap(QPixmap(QString::fromUtf8(":/data/editors/potlatch.png")));

        verticalLayout->addWidget(screenshotLabel);

        descriptionLabel = new QLabel(groupBox);
        descriptionLabel->setObjectName("descriptionLabel");
        descriptionLabel->setMinimumSize(QSize(0, 50));
        descriptionLabel->setWordWrap(true);

        verticalLayout->addWidget(descriptionLabel);


        verticalLayout_2->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(ExternalEditor);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(ExternalEditor);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ExternalEditor, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ExternalEditor, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ExternalEditor);
    } // setupUi

    void retranslateUi(QDialog *ExternalEditor)
    {
        ExternalEditor->setWindowTitle(QCoreApplication::translate("ExternalEditor", "External Map Editor Selection", nullptr));
        label_2->setText(QCoreApplication::translate("ExternalEditor", "External Map Editor", nullptr));
        editorComboBox->setItemText(0, QCoreApplication::translate("ExternalEditor", "Web browser (iD)", nullptr));
        editorComboBox->setItemText(1, QCoreApplication::translate("ExternalEditor", "Merkaartor", nullptr));
        editorComboBox->setItemText(2, QCoreApplication::translate("ExternalEditor", "JOSM", nullptr));

#if QT_CONFIG(tooltip)
        saveDefaultCheckBox->setToolTip(QCoreApplication::translate("ExternalEditor", "Deactivate to be prompted for a map editor selection next time again. Otherwise, your choice is remembered and will be used automatically in the future. If you want to alter the default map editor later, you can do so in the Marble Settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        saveDefaultCheckBox->setText(QCoreApplication::translate("ExternalEditor", "Make my selection the default map editor", nullptr));
        groupBox->setTitle(QCoreApplication::translate("ExternalEditor", "Editor Details", nullptr));
#if QT_CONFIG(tooltip)
        screenshotLabel->setToolTip(QCoreApplication::translate("ExternalEditor", "Editor Preview", nullptr));
#endif // QT_CONFIG(tooltip)
        screenshotLabel->setText(QString());
        descriptionLabel->setText(QCoreApplication::translate("ExternalEditor", "iD is an OpenStreetMap editor for quick editing tasks and beginners. It requires a web browser.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ExternalEditor: public Ui_ExternalEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EXTERNALEDITOR_H
