/********************************************************************************
** Form generated from reading UI file 'navigation.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NAVIGATION_H
#define UI_NAVIGATION_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QWidget>
#include "ArrowDiscWidget.h"
#include "NavigationButton.h"
#include "NavigationSlider.h"

QT_BEGIN_NAMESPACE

class Ui_Navigation
{
public:
    Marble::ArrowDiscWidget *arrowDisc;
    Marble::NavigationButton *homeButton;
    Marble::NavigationButton *zoomInButton;
    Marble::NavigationButton *zoomOutButton;
    Marble::NavigationSlider *zoomSlider;

    void setupUi(QWidget *Navigation)
    {
        if (Navigation->objectName().isEmpty())
            Navigation->setObjectName("Navigation");
        Navigation->resize(70, 360);
        arrowDisc = new Marble::ArrowDiscWidget(Navigation);
        arrowDisc->setObjectName("arrowDisc");
        arrowDisc->setGeometry(QRect(0, 0, 70, 70));
        homeButton = new Marble::NavigationButton(Navigation);
        homeButton->setObjectName("homeButton");
        homeButton->setGeometry(QRect(18, 70, 34, 40));
        homeButton->setStyleSheet(QString::fromUtf8(""));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/marble/navigation/navigational_homebutton.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon.addFile(QString::fromUtf8(":/marble/navigation/navigational_homebutton_hover.png"), QSize(), QIcon::Mode::Active, QIcon::State::Off);
        icon.addFile(QString::fromUtf8(":/marble/navigation/navigational_homebutton_press.png"), QSize(), QIcon::Mode::Selected, QIcon::State::Off);
        homeButton->setProperty("icon", QVariant(icon));
        homeButton->setProperty("iconSize", QVariant(QSize(34, 40)));
        zoomInButton = new Marble::NavigationButton(Navigation);
        zoomInButton->setObjectName("zoomInButton");
        zoomInButton->setGeometry(QRect(18, 109, 34, 36));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_plus.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon1.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_press_plus.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        icon1.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_hover_plus.png"), QSize(), QIcon::Mode::Active, QIcon::State::Off);
        icon1.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_press_plus.png"), QSize(), QIcon::Mode::Selected, QIcon::State::Off);
        zoomInButton->setProperty("icon", QVariant(icon1));
        zoomInButton->setProperty("iconSize", QVariant(QSize(34, 36)));
        zoomOutButton = new Marble::NavigationButton(Navigation);
        zoomOutButton->setObjectName("zoomOutButton");
        zoomOutButton->setGeometry(QRect(18, 305, 34, 36));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_minus.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon2.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_press_minus.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        icon2.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_hover_minus.png"), QSize(), QIcon::Mode::Active, QIcon::State::Off);
        icon2.addFile(QString::fromUtf8(":/marble/navigation/navigational_zoom_press_minus.png"), QSize(), QIcon::Mode::Selected, QIcon::State::Off);
        zoomOutButton->setProperty("icon", QVariant(icon2));
        zoomOutButton->setProperty("iconSize", QVariant(QSize(34, 36)));
        zoomSlider = new Marble::NavigationSlider(Navigation);
        zoomSlider->setObjectName("zoomSlider");
        zoomSlider->setGeometry(QRect(18, 145, 34, 160));

        retranslateUi(Navigation);

        QMetaObject::connectSlotsByName(Navigation);
    } // setupUi

    void retranslateUi(QWidget *Navigation)
    {
        Navigation->setWindowTitle(QCoreApplication::translate("Navigation", "Navigation", nullptr));
        homeButton->setProperty("text", QVariant(QString()));
        zoomInButton->setProperty("text", QVariant(QString()));
        zoomOutButton->setProperty("text", QVariant(QString()));
    } // retranslateUi

};

namespace Ui {
    class Navigation: public Ui_Navigation {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NAVIGATION_H
