/********************************************************************************
** Form generated from reading UI file 'YoursConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_YOURSCONFIGWIDGET_H
#define UI_YOURSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_YoursConfigWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *transport;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *fastest;
    QRadioButton *shortest;

    void setupUi(QWidget *YoursConfigWidget)
    {
        if (YoursConfigWidget->objectName().isEmpty())
            YoursConfigWidget->setObjectName("YoursConfigWidget");
        YoursConfigWidget->resize(273, 196);
        formLayout = new QFormLayout(YoursConfigWidget);
        formLayout->setObjectName("formLayout");
        label = new QLabel(YoursConfigWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        transport = new QComboBox(YoursConfigWidget);
        transport->setObjectName("transport");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, transport);

        groupBox = new QGroupBox(YoursConfigWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        fastest = new QRadioButton(groupBox);
        fastest->setObjectName("fastest");

        verticalLayout_2->addWidget(fastest);

        shortest = new QRadioButton(groupBox);
        shortest->setObjectName("shortest");

        verticalLayout_2->addWidget(shortest);


        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, groupBox);


        retranslateUi(YoursConfigWidget);

        QMetaObject::connectSlotsByName(YoursConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *YoursConfigWidget)
    {
        label->setText(QCoreApplication::translate("YoursConfigWidget", "Transport:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("YoursConfigWidget", "Method", nullptr));
        fastest->setText(QCoreApplication::translate("YoursConfigWidget", "Fastest", nullptr));
        shortest->setText(QCoreApplication::translate("YoursConfigWidget", "Shortest", nullptr));
        (void)YoursConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class YoursConfigWidget: public Ui_YoursConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_YOURSCONFIGWIDGET_H
