/********************************************************************************
** Form generated from reading UI file 'OsmTagEditorWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OSMTAGEDITORWIDGET_H
#define UI_OSMTAGEDITORWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OsmTagEditorWidgetPrivate
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QTreeWidget *m_currentTagsList;
    QVBoxLayout *verticalLayout;
    QPushButton *m_addTagButton;
    QPushButton *m_removeTagButton;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_2;
    QTreeWidget *m_recommendedTagsList;

    void setupUi(QWidget *OsmTagEditorWidgetPrivate)
    {
        if (OsmTagEditorWidgetPrivate->objectName().isEmpty())
            OsmTagEditorWidgetPrivate->setObjectName("OsmTagEditorWidgetPrivate");
        OsmTagEditorWidgetPrivate->resize(1121, 756);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OsmTagEditorWidgetPrivate->sizePolicy().hasHeightForWidth());
        OsmTagEditorWidgetPrivate->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(OsmTagEditorWidgetPrivate);
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(OsmTagEditorWidgetPrivate);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        m_currentTagsList = new QTreeWidget(OsmTagEditorWidgetPrivate);
        m_currentTagsList->setObjectName("m_currentTagsList");

        verticalLayout_2->addWidget(m_currentTagsList);


        horizontalLayout->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_addTagButton = new QPushButton(OsmTagEditorWidgetPrivate);
        m_addTagButton->setObjectName("m_addTagButton");
        m_addTagButton->setMaximumSize(QSize(40, 16777215));

        verticalLayout->addWidget(m_addTagButton);

        m_removeTagButton = new QPushButton(OsmTagEditorWidgetPrivate);
        m_removeTagButton->setObjectName("m_removeTagButton");
        m_removeTagButton->setMaximumSize(QSize(40, 16777215));

        verticalLayout->addWidget(m_removeTagButton);


        horizontalLayout->addLayout(verticalLayout);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_2 = new QLabel(OsmTagEditorWidgetPrivate);
        label_2->setObjectName("label_2");

        verticalLayout_3->addWidget(label_2);

        m_recommendedTagsList = new QTreeWidget(OsmTagEditorWidgetPrivate);
        m_recommendedTagsList->setObjectName("m_recommendedTagsList");

        verticalLayout_3->addWidget(m_recommendedTagsList);


        horizontalLayout->addLayout(verticalLayout_3);


        retranslateUi(OsmTagEditorWidgetPrivate);

        QMetaObject::connectSlotsByName(OsmTagEditorWidgetPrivate);
    } // setupUi

    void retranslateUi(QWidget *OsmTagEditorWidgetPrivate)
    {
        label->setText(QCoreApplication::translate("OsmTagEditorWidgetPrivate", "Current Tags", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = m_currentTagsList->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("OsmTagEditorWidgetPrivate", "Value", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("OsmTagEditorWidgetPrivate", "Key", nullptr));
        m_addTagButton->setText(QCoreApplication::translate("OsmTagEditorWidgetPrivate", "<<", nullptr));
        m_removeTagButton->setText(QCoreApplication::translate("OsmTagEditorWidgetPrivate", ">>", nullptr));
        label_2->setText(QCoreApplication::translate("OsmTagEditorWidgetPrivate", "Related Tags", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = m_recommendedTagsList->headerItem();
        ___qtreewidgetitem1->setText(1, QCoreApplication::translate("OsmTagEditorWidgetPrivate", "Value", nullptr));
        ___qtreewidgetitem1->setText(0, QCoreApplication::translate("OsmTagEditorWidgetPrivate", "Key", nullptr));
        (void)OsmTagEditorWidgetPrivate;
    } // retranslateUi

};

namespace Ui {
    class OsmTagEditorWidgetPrivate: public Ui_OsmTagEditorWidgetPrivate {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OSMTAGEDITORWIDGET_H
